#!/usr/bin/python 
# -*- coding: utf-8 -*-

# Vermessung102-numpy-Beispiele.py
# für Vermessung und Kataster
# copyright  2024, Norbert Fuhrmann, 50169 Kerpen
# Version 1.02, 15.11.2024
# www.grenzuntersuchung.de

import sys
import time
import pyvermessung as ve
import numpy as np
import tabulate

#************************************************************************

"""
start_time = time.time()
# Code
end_time = time.time()
execution_time = end_time - start_time
print(f"Ausführungszeit: {execution_time} Sekunden")
"""

# Aktualisierte Ausgabe in IDLE und extern in separaten Dateien "output.txt"
# im Programmverzeichnis


class Extern:
    def __init__(self, filename):
        self.terminal = sys.stdout
        self.log = open(filename, "w", encoding="utf-8")

    def write(self, message):
        self.terminal.write(message)
        self.log.write(message)
        self.log.flush()  # Sicherstellen, dass die Datei sofort geschrieben wird

    def flush(self):
        pass

sys.stdout = Extern("output.txt")

# ************************************************************************

# Allgemeine Ausgabefunktionen


def f2(a):          # String mit 2 Stellen nach dem Komma
    b = str(round(a, 2))
    return b


def f3(a):          # String mit 3 Stellen nach dem Komma
    b = str(round(a, 3))
    return b


def f4(a):          # String mit 4 Stellen nach dem Komma
    b = str(round(a, 4))
    return b


def f6(a):          # String mit 6 Stellen nach dem Komma
    b = str(round(a, 6))
    return b


def z3(a):          # String mit 3 Stellen nach dem Komma und Zeilenvorschub
    b = str(round(a, 3)) + "\n"
    return b


def z4(a):          # String mit 4 Stellen nach dem Komma und Zeilenvorschub
    b = str(round(a, 3)) + "\n"
    return b


def z6(a):          # String mit 6 Stellen nach dem Komma und Zeilenvorschub
    b = str(round(a, 3)) + "\n"
    return b


# String mit 3 Stellen nach dem Komma für ArrayS
np.set_printoptions(precision=3, suppress=True)


def L1():
    print("\u2581" * 65)   # Zeichenfolge als Linie


def L2():
    print("\u2582" * 65)   # Zeichenfolge als Linie


print("\n" + "\u2582" * 18 + "  𝗩𝗲𝗿𝗺𝗲𝘀𝘀𝘂𝗻𝗴-𝗻𝘂𝗺𝗽𝘆-𝗕𝗲𝗶𝘀𝗽𝗶𝗲𝗹𝗲.𝗽𝘆  " + "\u2582" * 17)

print("\n\u00A9 2024, Norbert Fuhrmann, 50169 Kerpen")
print(time.strftime("\nErgebnisse: Berechnet am %d.%m.%Y um %H:%M:%S Uhr"))
print(time.strftime("\nVermessung102-numpy-Beispiele.py"))
print("\nBeispielprogramm in der Reihenfolge der Nummerierung der\nFunktionen \
in dem Modul pyvermesung.py für Python/NumPy:\
\n\nDie einzelnen Aufrufe dienen hier gleichzeitig als Beispiele\n\
für die Ein- und Ausgaben der jeweiligen Funktionen.")

# Beispiele

print("\n\nOrthogonale Punkte")

# ************************************************************************
# 1 *****
L2()
print("\n1 *****  Rechter Winkel am Anfangspunkt\n\
        (Orthogon. Punkt 1)")
L1()

print("\n1. Beispiel:\n   Anfangspunkt y1 = 0; x1 = 0 \n   \
Endpunkt y2 = 3; x2 = 3\n   Seitlicher Abstand ayi = 2")

print("\n\u2794 Aufruf: yi, xi, sger = ve.orthogonal(y1, x1, y2, x2, ayi)")

y1 = 0
x1 = 0
y2 = 3
x2 = 3
ayi = 2

yi, xi, sger = ve.orthogonal(y1, x1, y2, x2, ayi)

print(f"\nErgebnis mit 3 Nachkommastellen: \nyi = {f3(yi)}, xi = {f3(xi)}, \
sger = {f3(sger)}")
L1()

print("\n2. Beispiel:  y1, x1 = 6, 1; y2, x2 = 8, 5; ayi = -3")
y1, x1 = 6, 1
y2, x2 = 8, 5
ayi = -3
yi, xi, sger = ve.orthogonal(y1, x1, y2, x2, ayi)
print(f"Ergebnis: yi = {f3(yi)}, xi = {f3(xi)}, sger = {f3(sger)}")


# ************************************************************************
# 2 *****
L2()
print("\n2 *****  Rechter Winkel auf gerader Linie\n\
        (Orthogon. Punkt 2)")
L1()

print("\n1. Beispiel: \n  Anfangspunkt y1 = 0; x1 = 0 \n  Endpunkt y2 = 3; \
x2 = 3 \n    Seitl. Abstand ayi = 3, Abstand auf der Linie  axi = 2")

print("\n\u2794 Aufruf: yi, xi, sger = \n\
ve.orthogonal(y1, x1, y2, x2, ayi, axi)")

y1 = 0
x1 = 0
y2 = 3
x2 = 3
ayi = 3
axi = 2

yi, xi, sger = ve.orthogonal(y1, x1, y2, x2, ayi, axi)
print(f"\nErgebnis mit 3 Nachkommastellen: \nyi = {f3(yi)}, xi = {f3(xi)}\
, sger = {f3(sger)}")
L1()

print("\n2. Beispiel:  y1, x1 = 6, 1; y2, x2 = 8, 5; ayi, axi = -3, 2")
y1, x1 = 6, 1
y2, x2 = 8, 5
ayi, axi = -3, 2
yi, xi, sger = ve.orthogonal(y1, x1, y2, x2, ayi, axi)
print(f"Ergebnis: yi = {f3(yi)}, xi = {f3(xi)}, sger = {f3(sger)}")

# ************************************************************************
# 3 *****
L2()
print("\n3 ***** Seitwärtsliegender Punkt auf Gerade mit\n\
        Fehlerverteilung (Orthogon. Punkt 3)")
L1()

print("\nBeispiel: \n   Anfangspunkt y1 = 0; x1 = 0 \n \
  Endpunkt y2 = 3; x2 = 3;\n\
   Abstand auf Linie axi = 2; seitl. Abstand ayi = 3 \n   Endmaß = 4.23")
print("\n\u2794 Aufruf: yi, xi, sger = \n\
           ve.orthogonal(y1, x1, y2, x2, ayi, axi, sgem)")

y1 = 0
x1 = 0
y2 = 3
x2 = 3
axi = 2
ayi = 3
sgem = 4.23

yi, xi, sger = ve.orthogonal(y1, x1, y2, x2, ayi, axi, sgem)
print(f"\nErgebnis: yi = {f3(yi)}, xi = {f3(xi)}, sger = {f3(sger)}, \
sgem = {f3(sgem)}")

# ************************************************************************
# 4 *****
L2()
print("\n4 *****  Seitwärtsliegende Punkte auf Gerade \n\
         (Orthogon. Punkte 4 ohne Fehlerverteilung)")
L1()
print("\nEingabeformat als Array:\
\nkoordinaten = [   # Pktn. (num), y, x\
\n1, y1, x1,        # Anfangspunkt\
\n2, y2, x2,        # Endpunkt \
\n3, ay1, ax1,      # lokale Daten\
\n... \
\ni, ayi, axi, \
\n... \
\nn, ayn, axn   \
]")

print("\nBeispiel:\
\nkoordinaten = [\
\n1, 100, 200, \
\n2, 300, 400, \
\n3,   1,   2, \
\n4, -10,  20, \
\n5,  50, -50\
 ]")

print("\n\u2794 Aufruf: koord1 = ve.orthogonal4(koordinaten)")

koordinaten = [
    1, 100., 200.,
    2, 300., 400.,
    3, 1., 2.,
    4, -10., 20.,
    5, 50., -50.
]
koord1 = ve.orthogonal4(koordinaten)
print("\nErgebnis:")
np.set_printoptions(precision=4, suppress=True)
print(tabulate.tabulate(koord1, floatfmt=(".0f", ".3f", ".3f", ".3f", ".3f"),
                        headers=["PktNr", "y", "x", "ay", "ax"]))
print("\nAusgabe-Array: koord1 =\n", koord1)

# ************************************************************************
# 5 *****
L2()
print("\n5 *****  Seitwärtsliegende Punkte auf gerader Linie\n\
         mit Fehlerverteilung ")
L1()
print("\nEingabeformat als Array:\
\nkoordinaten = [   # Pktn. (num), y, x\
\n1, y1, x1,        # Anfangspunkt\
\n2, y2, x2,        # Endpunkt \
\n3, ay1, ax1,      # lokale Daten\
\n... \
\ni, ayi, axi, \
\n... \
\nn, ayn, axn   \
], sgem")

print("\nBeispiel:\
\nkoordinaten = [\
\n1, 100, 200, \
\n2, 300, 400, \
\n3,   1,   2, \
\n4, -10,  20, \
\n5,  50, -50  \
], 283")

print("\n\u2794 Aufruf: koord1, fs = ve.orthogonal5(koordinaten, sgem)")

koordinaten = [
    1, 100., 200.,
    2, 300., 400.,
    3, 1., 2.,
    4, -10., 20.,
    5, 50., -50.
]
sgem = 283
koord1, fs = ve.orthogonal5(koordinaten, sgem)
print("\nErgebnis:")
print(tabulate.tabulate(koord1, floatfmt=(".0f", ".3f", ".3f", ".3f", ".3f"),
                        headers=["PktNr", "y", "x", "ay", "ax"]))
f = fs[0]
print("fs = Soll(s)- Ist(s) = ", f3(f))
print("\nAusgabe-Array: koord1 =\n", koord1)

# ************************************************************************
# 6 *****
L2()

print("\n6 *****  Richtungswinkel und Entfernung aus Koordinaten")
L1()
print("\nEingabeformat:\
\n  Koordinaten = \
\n  y1, x1   (Anfangspunkt)\
\n  y2, x2   (Endpunkt)")

print("\n1. Beispiel: \n  y1 = 1, x1 = 2 \n  y2 = 4, x2 = 6")

print("\n\u2794 Aufruf: t_gon, s = ve.richtung(y1, x1, y2, x2)")

y1 = 1
x1 = 2
y2 = 4
x2 = 6
t_gon, s = ve.richtung(y1, x1, y2, x2)
print(f"\nErgebnis: Richtungswinkel = {f4(t_gon)} gon, Strecke = {f3(s)}")
L1()

print("\n2. Beispiel: y1, x1 = 6, 0; y2, x2 = 4, 6")
y1, x1 = 6, 0
y2, x2 = 4, 6
t_gon, s = ve.richtung(y1, x1, y2, x2)
print(f"Ergebnis: Richtungswinkel = {f4(t_gon)} gon, Strecke = {f3(s)}")

# ************************************************************************
# 7 *****
L2()
print("\n7 *****  Richtungswinkel und Entfernung aus Koordinaten-\n\
         differenzen")
L1()

print("\nEingabeformat:\
\n  Koordinatenunterschiede = dy, dx")

print("\n1. Beispiel: y2 - y1 = dy = 3;   x2 - x1 = dx = 4")
dy = 3
dx = 4
t_gon, s = ve.richtung(dy, dx)

print("\n\u2794 Aufruf: t_gon, s = ve.richtung(dy, dx)")

print(f"\nErgebnis: Richtungswinkel = {f4(t_gon)} gon, \
Strecke = {f3(s)}")
L1()

print("\n2. Beispiel: dy = -3; dx = 4")
dy = -3
dx = 4
t_gon, s = ve.richtung(dy, dx)
print(f"Ergebnis: Richtungswinkel = {f4(t_gon)} gon, Strecke = {f3(s)}")

# ************************************************************************
# 8 *****
L2()
print("\n8 *****  Richtungsfunktionen")
L1()

print("\nBeispiel: \
\n  y1 = 1; x1 = 2\
\n  y2 = 4; x2 = 6.01; sgem = 5.03")
print("\n\u2794 Aufruf: \nsint, cost, sger, massstab = \
ve.richtung3(y1, x1, y2, x2, sgem)")

y1, x1, y2, x2, sgem = 1, 2, 4, 6.01, 5.03
sint, cost, sger, massstab = ve.richtung3(y1, x1, y2, x2, sgem)
print("\nErgebnis:")
print(f"Richtungsfunktionen sin = {f6(sint)}, cos = {f6(cost)} (ohne Maßstab)")
print(f"Strecke gerechnet= {f3(sger)}, Maßstab (sgem/sger) = {f6(massstab)}")
print(f"fs = Strecke(gerechnet) - Strecke(gemessen) = {f3(sger - sgem)}")

# ************************************************************************
# 9, 10 *****
L2()
print("\n9, 10 *****  Polarer Punkt")
L1()

print("\n1. Beispiel: \
\n  y1 = 1, x1 = 1, t1 = 50, axi = 2")

print("\n\u2794 Aufruf: \nyi, xi = ve.polar(y1, x1, t1, axi)")

y1 = 1
x1 = 1
t1 = 50
axi = 2
yi, xi = ve.polar(y1, x1, t1, axi)
print("\nErgebnis: Polarer Punkt \nyi, xi = ", yi, xi)

L1()
print("\n\u2794 Aufruf: yi, xi, yF, xF  =  ve.polar(y1, x1, t1, ayi, axi)")

print("\n2. Beispiel:  y1, x1 = 1, 1; t1 = 50; ayi, axi = 1, 2")
y1, x1, t1, ayi, axi = 1, 1, 50, 1, 2
yi, xi, yF, xF = ve.polar(y1, x1, t1, ayi, axi)
print("Ergebnis: yi, xi, yF, xF = ", f3(yi), f3(xi), f3(yF), f3(xF))

# ************************************************************************
# 11 *****
L2()
print("\n11 *****  Polarer Punkt mit Anschlusswinkel")
L1()

print("\n1. Beispiel: \
\n  y1 = 1, x1 = 1, t1 = 50\
\n  alphai = 25, axi = 2, ayi = 1")

print("\n\u2794 Aufruf: \nyi, xi, yF, xF  = \
ve.polar(y1, x1, t1, alphai, ayi, axi)")

y1, x1, t1, alphai, ayi, axi, = 1, 1, 50, 25, 1, 2
yi, xi, yF, xF = ve.polar(y1, x1, t1, alphai, ayi, axi)
print("\nErgebnis:\nyi, xi, yF, xY = ", f3(yi), f3(xi), f3(yF), f3(xF))
L1()

print("\n2. Beispiel: y1, x1 = 1, 1; t1 = 50; \
alphai = 365; ayi, axi = -2, 6")
y1, x1, t1, alphai, ayi, axi = 1, 1, 50, 365, -2, 6
yi, xi, yF, xF = ve.polar(y1, x1, t1, alphai, ayi, axi)
print("Ergebnis: yi, xi, yF, xY = ", f3(yi), f3(xi), f3(yF), f3(xF))

# ************************************************************************
# 12 (Array)*****
L2()
print("\n12 *****  Polare Punkte mit Anschlusswinkel")
L1()

print("\nEingabeformat:\
\nkoordinaten = [ # Pktn. (num), y, x\
\n1, y1, x1,        # Anfangspunkt\
\n2, y2, x2,        # Endpunkt,   \
\n3, alpha1, ax1,   # lokale Daten\
\n... \
\ni, alphai, axi, \
\n... \
\nn, alphan, axn   \
], alpha0")

print("\nBeispiel:\
\nkoordinaten = [\
\n1, 100, 200, \
\n2, 300, 400, \
\n3, 111,  12, \
\n4, 144,  20, \
\n5, 350,  48\
 ], 40.023")

print("\n\u2794 Aufruf: koord2 = ve.polar4(koordinaten, alpha0)")

koordinaten = [
    1, 100., 200.,
    2, 300., 400.,
    3, 111., 12.,
    4, 144., 20.,
    5, 350., 50.
]
alpha0 = 40.023
koord2 = ve.polar4(koordinaten, alpha0)
print("\nErgebnis:")
print(tabulate.tabulate(koord2, floatfmt=(".0f", ".3f", ".3f", ".4f", ".4f", ".3f"),
                        headers=["PktNr", "y", "x", "alphai", "alphai\n(red.)", "axi"]))
print("\nAusgabe-Array: koord2 =\n", koord2)

# ************************************************************************
# 13 *****
L2()
print("\n13 *****  Abstand, Lot von Richtung")
L1()

print("\nBeispiel: \
\n  y1 = 2, x1 = 1, t1 = 50 \
\n  yi = 3, xi = 7")

print("\n\u2794 Aufruf: \nyF, xF, ayi, axi, yisp, xisp = \
ve.lot(y1, x1, t1, yi, xi)")

y1 = 2
x1 = 1
t1 = 50
yi = 3
xi = 7
yF, xF, ayi, axi, yisp, xisp = ve.lot(y1, x1, t1, yi, xi)
print(f"\nErgebnis:\nLotfußpunkt yF = {f3(yF)}, xF = {f3(xF)}\
\nElemente ayi = {f3(ayi)}, axi = {f3(axi)} und yisp \
= {f3(yisp)}, xisp = {f3(xisp)}\n")

# ************************************************************************
# 14 *****
L2()
print("\n14 *****  Lot, Lotfußpunkt, orthogonales Element")
L1()

print("\n1. Beispiel:\
\n  y1 = 2, x1 = 1, y2 = 5, x2 = 4 \
\n  yi = 3, xi = 7")

print("\n\u2794 Aufruf: \nyF, xF, ayi, axi, yisp, xisp =  \
ve.lot(y1, x1, y2, x2, yi, xi)")

y1 = 2
x1 = 1
y2 = 5
x2 = 4
yi = 3
xi = 7
yF, xF, ayi, axi, yisp, xisp = ve.lot(y1, x1, y2, x2, yi, xi)
print(f"\nErgebnis:\nLotfußpunkt yF = {f3(yF)}, xF = {f3(xF)}\
\nElemente ayi = {f3(ayi)}, axi = {f3(axi)} und yisp = \
{f3(yisp)}, xisp = {f3(xisp)}\n")

print("\n2. Beispiel: y1 = 2, x1 = 1, y2 = 4, x2 = 1; \
yi = 0, xi = 0")

y1, x1, y2, x2, yi, xi = 2, 1, 4, 1, 0, 0
yF, xF, ayi, axi, yisp, xisp = ve.lot(y1, x1, y2, x2, yi, xi)
print(f"Ergebnis:\nLotfußpunkt yF = {f3(yF)}, xF = {f3(xF)}\
\nElemente ayi = {f3(ayi)}, axi = {f3(axi)} und yisp = \
{f3(yisp)}, xisp = {f3(xisp)}")


# ************************************************************************
# 15 (Array) *****
L2()
print("\n15 *****  Lote, Fußpunkte, orthogonale Elemente über array")
L1()

print("\nEingabeformat:\
\nkoordinaten = [ # Pktn. (num), y, x\
\n1, y1, x1,      # Anfangspunkt\
\n2, y2, x2,      # Endpunkt,\
\n3, y3, x3,      # lokale Daten\
\n... \
\ni, yi, xi,\
\n... \
\nn, yn, xn\
\n]")

print("\nBeispiel:\
\nkoordinaten = [\
\n1, 100., 100.\
\n2, 900., 900.\
\n3, 201,  203.\
\n4, 300.2, 300.3\
\n5, 400.1, 400.3\
\n]")

print("\n\u2794 Aufruf: koord3 = ve.lot3(koordinaten)")

koordinaten = [
    1, 100., 100.,
    2, 900., 900.,
    3, 201, 203.,
    4, 300.2, 300.3,
    5, 400.1, 400.3
]
koord3 = ve.lot3(koordinaten)
print("\nErgebnis:")
print(tabulate.tabulate(koord3, floatfmt=(".0f", ".3f", ".3f", ".3f", ".3f", ".3f", ".3f"),
                        headers=["PktNr", "y", "x", "yF", "xF", "ay", "ax"]))
np.set_printoptions(precision=3, suppress=True)
print("\nAusgabe-Array: koord3 =\n", koord3)

# ************************************************************************
# 16 *****
L2()
print("\n16 *****  Strecke in n+1 gleiche Teile teilen")
L1()

print("\nBeispiel:\n  y1, x1 = 10000, 10000 Anfangspunkt\n\
  y2, x2 = 10500, 10500 Endpunkt\n  n = 4 Anzahl der Zwischenpunkte")

print("\n\u2794 Aufruf: koord4, si, sger =\n\
          ve.teilstrecken(y1, x1, y2, x2, n)")

y1, x1 = 10000, 10000
y2, x2 = 10500, 10500
n = 4
koord4, si, sger = ve.teilstrecken(y1, x1, y2, x2, n)
print(f"\nErgebnis:\nTeilstrecke = {f3(si)}, Gesamtstrecke = {f3(sger)}\n")
print(tabulate.tabulate(koord4, headers=["Pktnr", "y", "x", "ayi", "axi"]))
print("\nAusgabe-Array: koord4 =\n", koord4)

# ************************************************************************
# 17 *****
L2()
print("\n17 *****  Polar, Punkt mit Anschlusswinkel, Strecke")
L1()

print("\n1. Beispiel: \
\n  y1 = 1, x1 = 1 \
\n  y2 = 4, x2 = 4 \
\n  y3 = 4, x3 = 1 ")

print("\n\u2794 Aufruf:\nt2, s2, alpha, s3 = \
ve.polarwinkel1(y1, x1, y2, x2, y3, x3)")

y1, x1 = 1, 1
y2, x2 = 4, 4
y3, x3 = 4, 1

t2, s2, alpha, s3 = ve.polarwinkel1(y1, x1, y2, x2, y3, x3)
print("\nErgebnis:\nPolarer Anschlusswinkel t2, Strecke \
s2, alpha, s3 =\n", t2, s2, alpha, s3)
L1()

print("\n2. Beispiel: y1, x1 = 10, 1; y2, x2 = 8, 8; y3, x3 = 13, 4 ")
y1, x1 = 10, 1
y2, x2 = 8, 8
y3, x3 = 13, 4
t2, s2, alpha, s3 = ve.polarwinkel1(y1, x1, y2, x2, y3, x3)
print("Ergebnis: t2, s2, alpha, s3 =\n", t2, s2, "\n", alpha, s3)

# ************************************************************************
# 18 (Array) *****
L2()
print("\n18 *****  Polar, Punkt mit Anschlusswinkel, Strecken")
L1()

print("\nBeispiel:\
\nkoordinaten = [\
\n1, 100, 100, \
\n2, 400, 400.486, \
\n3, 251,  202, \
\n4, 144,  254, \
\n5, 350,  445\
 ]")

print("\n\u2794 Aufruf: koord5 =  ve.polarwinkel2(koordinaten)")

koordinaten = [
    1, 100., 100.,
    2, 400., 400.486,
    3, 351., 202.,
    4, 144., 254.,
    5, 350., 445.
]
koord5 = ve.polarwinkel2(koordinaten)
print("\nErgebnis:")


def format_array(koord5, precisions):
    formatted_data = []
    for row in koord5:
        formatted_row = []
        for value, precision in zip(row, precisions):
            formatted_value = f"{value:.{precision}f}"
            formatted_row.append(formatted_value)
        formatted_data.append(formatted_row)
    return formatted_data


precisions = [0, 3, 3, 4, 4, 3]
formatted_data2 = format_array(koord5, precisions)
print(tabulate.tabulate(formatted_data2,
                        floatfmt=(".0f", ".3f", ".3f", ".4f", ".4f", ".3f"),
                        headers=["PktNr", "y", "x", "t", "alpha", "s"]))

# String mit 4 Stellen nach dem Komma für ArrayS
np.set_printoptions(precision=4, suppress=True)
print("\nAusgabe-Array koord5 =\n", koord5)

# ************************************************************************
# 19 *****
L2()
print("\n19 *****  Strecke halbieren, Mittelsenkrechte")
L1()

print("\n1. Beispiel:\
\n  y1, x1 = 1, 1\n  y2, x2 = 3, 3")

print("\n\u2794 Aufruf: yM, xM, tM, sM =\
\nmittelsenkrechte(y1, x1, y2, x2)")

y1, x1 = 1, 1
y2, x2 = 3, 3

yM, xM, tM, sM = ve.mittelsenkrechte(y1, x1, y2, x2)
print("\nErgebnis:\nyM, xM, tM, sM  = ", yM, xM, tM, sM)
L1()

print("\n2. Beispiel: y1, x1 = 3, 1;  y2, x2 = 1, 3")
y1, x1 = 3, 1
y2, x2 = 1, 3
yM, xM, tM, sM = ve.mittelsenkrechte(y1, x1, y2, x2)
print("Ergebnis: yM, xM, tM, sM  = ", yM, xM, tM, sM)
L1()

print("\n3. Beispiel: y1, x1 = 3, 1;  y2, x2 = 1, 1")
y1, x1 = 3, 1
y2, x2 = 1, 1
yM, xM, tM, sM = ve.mittelsenkrechte(y1, x1, y2, x2)
print("Ergebnis: yM, xM, tM, sM  = ", yM, xM, tM, sM)


# ************************************************************************
# 20 *****
L2()
print("\n20  *****    Transformation")
L1()

print("\n1. Beispiel: \
\n  yA, xA = 1, 3.5; yE, xE = 6, 2\
\n  ayA, axA = -1.7, 1; ayE, axE = 1.5, 5.3\n  ayi, axi = 2, 3.5")

print("\n\u2794 Aufruf: yi, xi, fs = \n\
ve.transformation1(yA, xA, yE, xE, ayA, axA, ayE, axE, ayi, axi)")

yA, xA = 1, 3.5
yE, xE = 6, 2
ayA, axA = -1.7, 1
ayE, axE = 1.5, 5.3
ayi, axi = 2, 3.5

yi, xi, fs = ve.transformation1(yA, xA, yE, xE, ayA, axA, ayE, axE, ayi, axi)
print(f"\nErgebnis:\nyi, xi = {f3(yi)}, {f3(xi)}; fs = {f3(fs)}")
L1()

print("\n2. Beispiel: yA, xA = 100, 129; yE, xE = 174, 150; ayA, axA = -10, 12\n\
axE = 26, 80; ayi, axi = 30, 5")
yA, xA = 100, 129
yE, xE = 174, 150
ayA, axA = -10, 12
ayE, axE = 26, 80
ayi, axi = 30, 5
yi, xi, fs = ve.transformation1(yA, xA, yE, xE, ayA, axA, ayE, axE, ayi, axi)
print(f"Ergebnis: yi, xi = {f3(yi)}, {f3(xi)}; fs = {f3(fs)}")

# ************************************************************************
# 21 *****
L2()
print("\n21  *****    Transformation über Array")
L1()

print("\nBeispiel:\n\
transkoordinaten = [\
\n1001, 100., 200., 500.09,   600.05,  #Anfangspunkt\
\n1002, 300., 400.,  700.2,   800.00,  #Endpunkt\
\n3,       0,    0,  546,     675.345,\
\n4,       0,    0,  999,     767,\
\n5,       0,    0,  786.234, 678\
\n]")

print("\n\u2794 Aufruf: koord6, fs =  ve.transformation2(transkoordinaten)")

transkoordinaten = [
    1001, 100., 200., 500.09, 600.05,  # Anfangspunkt
    1002, 300., 400., 700.2, 800.00,  # Endpunkt
    3, 0, 0, 546, 675.345,
    4, 0, 0, 999, 767,
    5, 0, 0, 786.234, 678
]
koord6, fs = ve.transformation2(transkoordinaten)
print("\nErgebnis:")
print(tabulate.tabulate(koord6, floatfmt=(".0f", ".3f", ".3f", ".3f", ".3f"),
                        headers=["PktNr", "y", "x", "ay", "ax"]))
print("\nfs = ", fs)
# String mit 3 Stellen nach dem Komma für ArrayS
np.set_printoptions(precision=4, suppress=True)
print("\nAusgabe-Array koord6 =\n", koord6)

# ************************************************************************
#  22, 23, 24 *****
L2()
print("\n22, 23, 24 *****   Geradenschnitte")
L1()

y1, x1 = 2, 1
y2, x2 = 8, 9
y3, x3 = 1, 8
y4, x4 = 9, 2


print("\nBeispiele:")
print("  y1, x1 = 2, 1 \n  y2, x2 = 8, 9 \n  y3, x3 = 1, 8 \n\
  y4, x4 = 9, 2 \n  t1, t3 = 40.96655, 140.96655")


print("\n\u2794 Aufruf und Ergebnisse:\nEinfacher Geradenschnitt\n\
yS, xS, alpha = ve.geradenschnitt(y1, x1, y2, x2, y3, x3, y4, x4)")
yS, xS, alpha = ve.geradenschnitt(y1, x1, y2, x2, y3, x3, y4, x4)
print("yS, xS, alpha = ", f3(yS), f3(xS), f4(alpha))

t1, t3 = 40.96655, 140.96655

print("\n\u2794 Aufruf:\nVorwärtsschnitt mit 2 Richtungswinkel: \n\
yS, xS, alpha = ve.geradenschnitt(y1, x1, t1, y3, x3, t3)")
yS, xS, alpha = ve.geradenschnitt(y1, x1, t1, y3, x3, t3)
print("yS, xS, alpha = ", f3(yS), f3(xS), f4(alpha))

print("\n\u2794 Aufruf:\nVorwärtsschnitt über einen Richtungswinkel: \n\
yS, xS, alpha = ve.geradenschnitt(y1, x1, y2, x2, y3, x3, t3)")
yS, xS, alpha = ve.geradenschnitt(y1, x1, y2, x2, y3, x3, t3)
print("yS, xS, alpha = ", f3(yS), f3(xS), f4(alpha))


print("\nBeispiele:")
print("y1, x1 = 1, 1; y2, x2 = 1, 3; y3, x3 = 2, 3; y4, x4 = 3, 4")

y1, x1 = 1, 1
y2, x2 = 1, 3
y3, x3 = 2, 3
y4, x4 = 3, 4
yS, xS, alpha = ve.geradenschnitt(y1, x1, y2, x2, y3, x3, y4, x4)
print("yS, xS, alpha = ", f3(yS), f3(xS), f4(alpha))

print("\ny1, x1 = 5.5, 3.5; y2, x2 = 4, 5.5; y3, x3 = 7, 1.5; y4, x4 = 8.5, 3")

y1, x1 = 5.5, 3.5
y2, x2 = 4, 5.5
y3, x3 = 7, 1.5
y4, x4 = 8.5, 3
yS, xS, alpha = ve.geradenschnitt(y1, x1, y2, x2, y3, x3, y4, x4)
print("yS, xS, alpha = ", f3(yS), f3(xS), f4(alpha))

print("\ny1, x1 = 5.5, 3.5; y2, x2 = 4, 5.5; y3, x3 = 6, 0.5; t3 = 100")

y1, x1 = 5.5, 3.5
y2, x2 = 4, 5.5
y3, x3 = 6, 0.5
t3 = 100
yS, xS, alpha = ve.geradenschnitt(y1, x1, y2, x2, y3, x3, t3)
print("yS, xS, alpha = ", f3(yS), f3(xS), f4(alpha))

print("\ny1, x1 = 5.5, 3.5; t1 = 159.0334; y3, x3 = 6, 0.5; t3 = 100")

y1, x1 = 5.5, 3.5
t1 = 159.0334
y3, x3 = 6, 0.5
t3 = 100
yS, xS, alpha = ve.geradenschnitt(y1, x1, t1, y3, x3, t3)
print("yS, xS, alpha = ", f3(yS), f3(xS), f4(alpha))

print("\ny1, x1 = 51234, 31234; y2, x2 = 40000, 61234\n\
y3, x3 = 71234, 12345; y4, x4 = 81234, 31234")
y1, x1 = 51234, 31234
y2, x2 = 40000, 61234
y3, x3 = 71234, 12345
y4, x4 = 81234, 31234
yS, xS, alpha = ve.geradenschnitt(y1, x1, y2, x2, y3, x3, y4, x4)
print("yS, xS, alpha = ", f3(yS), f3(xS), f4(alpha))

# ************************************************************************
# 25 *****
L2()
print("\n25 *****   Geradenausgleich")
L1()

print("\nEingabeformat als Array:\
\nkoordinaten = [ # Pktn. (num), y, x\
\n1, y1, x1,      # Anfangspunkt\
\n2, y2, x2,      # Endpunkt \
\n3, y3, x3,      # lokale Daten\
\n... \
\ni, yi, xi, \
\n... \
\nn, yn, xn\
\n]")

print("\nBeispiel:\n\
koordinaten = [\
\n1, 100., 100.,\
\n2, 700., 700.,\
\n3, 102., 99.,\
\n4, 102., 105.,\
\n5, 101., 100.,\
\n6, 101., 105.,\
\n7, 698., 698.5,\
\n]")

print("\n\u2794 Aufruf: \nkoord7 = ve.geradenausgleich(koordinaten)")

koordinaten = [
    1, 100., 100.,
    2, 700., 700.,
    3, 102., 99.,
    4, 102., 105.,
    5, 101., 100.,
    6, 101., 105.,
    7, 698., 698.5,
]
koord7 = ve.geradenausgleich(koordinaten)
print("\nErgebnis:")
# String mit 3 Stellen nach dem Komma für ArrayS
print(tabulate.tabulate(koord7, floatfmt=(".0f", ".3f", ".3f", ".3f", ".3f", ".3f", ".3f"),
                        headers=["PktNr", "y", "x", "Fy", "Fx", "ay", "ax"]))
np.set_printoptions(precision=3, suppress=True)
print("\nAusgabe-Array koord7 =\n", koord7)

# ************************************************************************
# 26 *****
L2()
print("\n26 *****   Parallele zur Geraden")
L1()

print("\n1. Beispiel:\n  y1, x1 = 0, 0 \n  y2, x2 = 2, 2 \n  a = 1")
print("\n\u2794 Aufruf: \ny1p, x1p, y2p, x2p, sger = ve.parallel(y1, x1, y2, x2, a)")

y1, x1 = 0, 0
y2, x2 = 2, 2
a = 1

y1p, x1p, y2p, x2p, sger = ve.parallel(y1, x1, y2, x2, a)
print("\nErgebnis:\ny1p, x1p, y2p, x2p, sger = ",
      f3(y1p), f3(x1p), f3(y2p), f3(x2p), f3(sger))
L1()

print("\n2. Beispiel:\ny1, x1 = 4, 1; y2, x2 = 2.5, 5.5; a = -2")
y1, x1 = 4, 1
y2, x2 = 2.5, 5.5
a = -2
y1p, x1p, y2p, x2p, sger = ve.parallel(y1, x1, y2, x2, a)
print("Ergebnis:\ny1p, x1p, y2p, x2p, sger = ",
      f3(y1p), f3(x1p), f3(y2p), f3(x2p), f3(sger))

# ************************************************************************"
# 27 *****
L2()
print("\n27 *****    Parallelschnitt")
L1()


y1, x1 = 0, 0
y2, x2 = 2, 2
y3, x3 = 0, 2
y4, x4 = 2, 0
a1, a3 = 1, -3
print("\n1. Beispiel:\n  y1, x1 = 0, 0 \n  y2, x2 = 2, 2 \n  y3, x3 = 0, 2\
\n  y4, x4 = 2, 0 \n  a1, a3 = 1, -3")

print("\n\u2794 Aufruf: \nyS, xS, alpha \n\
= ve.parallelschnitt(y1, x1, y2, x2, a1, y3, x3, y4, x4, a3)")

yS, xS, alpha = ve.parallelschnitt(y1, x1, y2, x2, a1, y3, x3, y4, x4, a3)
print("\nErgebnis:\nyS, xS, alpha = ", f3(yS), f3(xS), f4(alpha))
L1()

print("\n2. Beispiel:\ny1, x1 = 2, 1; y2, x2 = 10, 1; y3, x3 = 3, 0\
\ny4, x4 = 3, 10; a1, a3 = -2, 2")

y1, x1 = 2, 1
y2, x2 = 10, 1
y3, x3 = 3, 0
y4, x4 = 3, 10
a1, a3 = -2, 2

yS, xS, alpha = ve.parallelschnitt(y1, x1, y2, x2, a1, y3, x3, y4, x4, a3)
print("Ergebnis:\nyS, xS, alpha = ", f3(yS), f3(xS), f4(alpha))


# ************************************************************************
# 28 *****
L2()
print("\n28 *****    Senkrechtschnitt")
L1()

print("\n\u2794 Aufruf: \nyS, xS = ve.senkrechtschnitt(y1, x1, y2, x2, yi, xi)")

y1, x1 = 1, 1
y2, x2 = 1, 10
yi, xi = 3, 5

yS, xS = ve.senkrechtschnitt(y1, x1, y2, x2, yi, xi)
print("\n1. Beispiel:\n  y1, x1 = 1, 1\n  \
y2, x2 = 1, 10\n  \
yi, xi = 3, 5;\n\nErgebnis: yS, xS = ", f3(yS), f3(xS))
L1()

print("\n2. Beispiel:  y1, x1 = 0, 0; y2, x2 = 4, 4; yi, xi = 0, 4")

y1, x1 = 0, 0
y2, x2 = 4, 4
yi, xi = 0, 4
yS, xS = ve.senkrechtschnitt(y1, x1, y2, x2, yi, xi)
print(f"Ergebnis: yS = {f3(yS)}, xS = {f3(xS)}")

# ************************************************************************
# 29 *****
L2()
print("\n29 *****    Senkrecht-Parallelschnitt")
L1()

print("\nBeispiel:\ny1, x1 = 0, 0\n\
y2, x2 = 4, 4\n  \
y3, x3 = 2, 4\n  \
y4, x4 = 5, 4 \n  \
yi, xi = 0, 4; a = 1")

y1, x1 = 0, 0
y2, x2 = 4, 4
y3, x3 = 0, 4
y4, x4 = 5, 4
yi, xi = 4, 0
a = 1

yS, xS = ve.senkrecht_parallel(y1, x1, y2, x2, y3, x3, y4, x4, yi, xi, a)
print("\n\u2794 Aufruf:\nyS, xS = \
ve.senkrecht_parallel\n(y1, x1, y2, x2, y3, x3, y4, x4, yi, xi, a)")
print("\nErgebnis: yS, xS = ", f3(yS), f3(xS))

# ************************************************************************
# 30 *****
L2()
print("\n30 *****    Doppelter Senkrechtschnitt")
L1()

print("\nBeispiel:\n  y1, x1 = 0, 0\n\
  y2, x2 = 4, 4\n\
  yi, xi = 0, 4\n\
  y3, x3 = 4, 0\n\
  y4, x4 = 4, 4\n\
  yj, xj = 4, 2")

print("\n\u2794 Aufruf:\nyS, xS = ve.doppelt_senkrecht\n\
(y1, x1, y2, x2, yi, xi, y3, x3, y4, x4, yj, xj)")

y1, x1 = 0, 0
y2, x2 = 4, 4
yi, xi = 0, 4
y3, x3 = 4, 0
y4, x4 = 4, 4
yj, xj = 4, 2

yS, xS = ve.doppelt_senkrecht(y1, x1, y2, x2, yi, xi, y3, x3, y4, x4, yj, xj)
print("\nErgebnis: yS, xS = ", f3(yS), f3(xS))

# ************************************************************************
# 31 *****
L2()
print("\n31 *****    Winkelhalbierende")
L1()

print("\n1. Beispiel:\n  y1, x1 = 1, 1; y2, x2 = 3, 4\n\
  y3, x3 = 7, 1; y4, x4 = 5, 4")

print("\n\u2794 Aufruf: yS, xS, tS, alpha = \n\
         winkelhalbierende(y1, x1, y2, x2, y3, x3, y4, x4)")

y1, x1 = 1, 1
y2, x2 = 3, 4
y3, x3 = 7, 1
y4, x4 = 5, 4

yS, xS, tS, alpha = ve.winkelhalbierende(y1, x1, y2, x2, y3, x3, y4, x4)
print(f"Ergebnis:\nyS = {f3(yS)}, xS = {f3(xS)}, tS = {f4(tS)} gon, \
alpha = {f4(alpha)} gon")
L1()

print("\n2. Beispiel: y1, x1 = 4, 1; y2, x2 = 9, 3;\n\
y3, x3 = 13, 10; y4, x4 = 12, 6")

y1, x1 = 4, 1
y2, x2 = 9, 3
y3, x3 = 13, 10
y4, x4 = 12, 6
yS, xS, tS, alpha = ve.winkelhalbierende(y1, x1, y2, x2, y3, x3, y4, x4)
print(f"\nErgebnis:\nyS = {f3(yS)}, xS = {f3(xS)}, \
tS = {f4(tS)} gon, alpha = {f4(alpha)} gon")

# ************************************************************************
# 32, 33 *****
L2()
print("\n32, 33 *****    Kreismittelpunkte")
L1()

print("\n1. Beispiel:\n  y1, x1 = 0, 0\n\
  y2, x2 = 4, 4\n\
  R = 4")

print("\n\u2794 Aufruf: yM, xM = ve.kreis(y1, x1, y2, x2, R)")
y1, x1 = 0, 0
y2, x2 = 4, 4
R = 4

yM, xM = ve.kreis(y1, x1, y2, x2, R)
print(f"\nErgebnis: yM = {f3(yM)}, xM = {f3(xM)}")
L1()

print("\n2. Beispiel: y1, x1 = 0, 0; y2, x2 = 4, 4; R = -4")

y1, x1 = 0, 0
y2, x2 = 4, 4
R = -4
yM, xM = ve.kreis(y1, x1, y2, x2, R)
print(f"Ergebnis: yM = {f3(yM)}, xM = {f3(xM)}")
L1()

print("\n3. Beispiel:\ny1, x1 = 4, -4; y2, x2 = 0, 0 , y3, x3 = 4, 4")

print("\n\u2794 Aufruf: yM, xM, R = ve.kreis(y1, x1, y2, x2, y3, x3)")

y1, x1 = 4, -4
y2, x2 = 0, 0
y3, x3 = 4, 4

yM, xM, R = ve.kreis(y1, x1, y2, x2, y3, x3)
print(f"\nErgebnis:\nyM = {yM}, xM = {xM}, R = {R}")
L1()

print("\n4. Beispiel: y1, x1 = 4, -4; y2, x2 = 8, 0; y3, x3 = 4, 4")

y1, x1 = 4, -4
y2, x2 = 8, 0
y3, x3 = 4, 4
yM, xM, R = ve.kreis(y1, x1, y2, x2, y3, x3)
print(f"Ergebnis:\nyM = {yM}, xM = {xM}, R = {R}")


# ************************************************************************
# 34, 35 *****

L2()
print("\n34, 35 ******    Lot auf Kreis")
L1()

print("\n1. Beispiel:\n  y1, x1 = 0, 0\n\
  y2, x2 = 4, 4\n\
  y3, x3 = 1, 2; R = 4")

print("\n\u2794 Aufruf: \nyF, xF, d = ve.lot_kreis(y1, x1, y2, x2, y3, x3, R)")

y1, x1 = 0, 0
y2, x2 = 4, 4
y3, x3 = 1, 2
R = 4

yF, xF, d = ve.lot_kreis(y1, x1, y2, x2, y3, x3, R)
print(f"\nErgebnis: yF = {f3(yF)}, xF = {f3(xF)}, d = {f3(d)}")
L1()

print("\n2. Beispiel:\ny1, x1; y2, x2 = 4, 4; y3, x3 = 1, 2; R = -4")

y1, x1 = 0, 0
y2, x2 = 4, 4
y3, x3 = 1, 2
R = -4

yF, xF, d = ve.lot_kreis(y1, x1, y2, x2, y3, x3, R)
print(f"Ergebnis: yF = {f3(yF)}, xF = {f3(xF)}, d = {f3(d)}")
L1()

print("\n3. Beispiel:\ny1, x1 = 0, 0 , y2, x2 = 1, 2 , y3, x3 = 4, 4; y4, x4 = 2, 2")

print("\n\u2794 Aufruf: \nyF, xF, d, yM, xM, R =\n\
ve.lot_kreis(y1, x1, y2, x2, y3, x3, y4, x4)")

y1, x1 = 0, 0
y2, x2 = 1, 2
y3, x3 = 4, 4
y4, x4 = 2, 2

yF, xF, d, yM, xM, R = ve.lot_kreis(y1, x1, y2, x2, y3, x3, y4, x4)
print(f"\nErgebnis: yF = {f3(yF)}, xF = {f3(xF)}, d = {f3(d)}\n\
yM = {f3(yM)}, xM = {f3(xM)}, R = {f3(R)}")
L1()

print("\n4. Beispiel:\ny1, x1 = 0, 0; y2, x2 = 3, 1; y3, x3 = 4, 4; y4, x4 = 4, 0")

y1, x1 = 0, 0
y2, x2 = 3, 1
y3, x3 = 4, 4
y4, x4 = 4, 0

yF, xF, d, yM, xM, R = ve.lot_kreis(y1, x1, y2, x2, y3, x3, y4, x4)
print(f"Ergebnis: yF = {f3(yF)}, xF = {f3(xF)}, d = {f3(d)}\n\
yM = {f3(yM)}, xM = {f3(xM)}, R = {f3(R)}")

# ************************************************************************
# 36 *****
L2()
print("\n36 *****     Kreisbogen")
L1()

print("\n1. Beispiel:\n  y1, x1 = 0, 0\n\
  y2, x2 = 4, 4\n  R = 4")

print("\n\u2794 Aufruf:\nyM, xM, yT, xT, t, b, s, alpha = \n\
ve.kreisbogen(y1, x1, y2, x2, R)")

y1, x1 = 0, 0
y2, x2 = 4, 4
R = 4

yM, xM, yT, xT, t, s, b, alpha = ve.kreisbogen(y1, x1, y2, x2, R)
print("\nErgebnis:")
print(f"yM, xM = {f3(yM)}, {f3(xM)}; yT, xT = {f3(yT)}, {f3(xT)}")
print(f"Tangentenlänge(t) = {f3(t)}; Sehne(s) = {f3(s)}; Bogenlänge(b) = {f3(b)}")
print(f"Radius(R) = {f4(R)}; Mittelpunktswinkel (alpha) = {f4(alpha)} gon")

L1()
print("\n2. Beispiel:\ny1, x1 = 165.5, 8; y2, x2 = 123.5, 156; R = 149")

y1, x1 = 165.5, 8; y2, x2 = 123.5, 156; R = 149

yM, xM, yT, xT, t, s, b, alpha = ve.kreisbogen(y1, x1, y2, x2, R)
print("\nErgebnis:")
print(f"yM, xM = {f3(yM)}, {f3(xM)}; yT, xT = {f3(yT)}, {f3(xT)}")
print(f"Tangentenlänge(t) = {f3(t)}; Sehne(s) = {f3(s)}; Bogenlänge(b) = {f3(b)}")
print(f"Radius(R) = {f4(R)}; Mittelpunktswinkel (alpha) = {f4(alpha)} gon")
# ************************************************************************
# 37 *****
L2()
print("\n37 *****     Bogenteilung")
L1()

print("\nBeispiel:\n  y1, x1 = 10000, 10000\n\
  y2, x2 = 10500, 10500\n  R = 500, n = 4")

print("\n\u2794 Aufruf: A, yM, xM, teilbogen, si =\n\
          ve.bogenteilung(y1, x1, y2, x2, R, n)")

y1, x1 = 10000, 10000
y2, x2 = 10500, 10500
R = 500
n = 4

yM, xM, si, teilbogen, elemente = ve.bogenteilung(y1, x1, y2, x2, R, n)
print("\nErgebnis:")
print(tabulate.tabulate(elemente, floatfmt=(".3f", ".3f", ".3f", ".3f"),
                        headers=["y1", "x1", "ayi", "axi"]))

print("\nAusgabe-Array: elemente\n", elemente)
print(f"\nyM = {f3(yM)}, xM = {f3(xM)}, \
Teilbogen = {f3(teilbogen)}, si = {f3(si)}")

# ************************************************************************
# 38 *****
L2()
print("\n38  *****     Kreisbogenschnitt")
L1()

print("\n1. Beispiel:\n  y1, x1 = 0, 0\n\
  y2, x2 = 4, 4\n  R1, R2 = 4, 4")

print("\n\u2794 Aufruf: yS, xS, yF, xF, s1, s2, a =\n \
          ve.kreiskreis(y1, x1, R1, y2, x2, R2)")

y1, x1 = 0, 0
y2, x2 = 4, 4
R1, R2 = 4, 4

yS, xS, yF, xF, s1, s2, a = ve.kreis_kreis(y1, x1, +R1, y2, x2, +R2)
print("\nErgebnis:")
print(f"yS, xS = {f3(yS)}, {f3(xS)}")
print(f"yF, xF = {f3(yF)}, {f3(xF)}")
print(f"s1, s2 = {f3(s1)}, {f3(s2)}, a = {f3(a)}")
L1()

print("\n2. Beispiel: y1, x1 = 2, 2; y2, x2 = 6, 6; R1, R2 = 8, 3 ")

y1, x1 = 2, 2
y2, x2 = 6, 6
R1, R2 = 8, 3
yS, xS, yF, xF, s1, s2, a = ve.kreis_kreis(y1, x1, +R1, y2, x2, +R2)
print("Ergebnis:")
print(f"yS, xS = {f3(yS)}, {f3(xS)}")
print(f"yF, xF = {f3(yF)}, {f3(xF)}")
print(f"s1, s2 = {f3(s1)}, {f3(s2)}, a = {f3(a)}")

# ************************************************************************
# 39 bis 44 *****
L2()
print("\n39 bis 44 *****     Kreisgeradenschnitt")
L1()

print("\nBeispiele:\n  y1, x1 = 1, 1; y2, x2 = 10, 6; y3, x3 = 7, 8.3\n\
  y4, x4 = 8, 6; y5, x5 = 5, 3; R = 3; yM, xM = 5, 6;\n\
  a = -2; t1 = 67.7171 \n\
\nAufrufe und Ergebnisse:")

print("\n\u2794 (39) Aufruf: yS, xS = \nkreis_gerade(y1, x1, t1, yM, xM, R)")

y1, x1 = 1, 1
y2, x2 = 10, 6
y3, x3 = 7, 8.3
y4, x4 = 8, 6
y5, x5 = 5, 3
R = 3
yM, xM = 5, 6
a = -2
t1 = 67.7171

yS, xS = ve.kreis_gerade(y1, x1, t1, yM, xM, R)
print(f"yS, xS = {f3(yS)}, {f3(xS)}")
L1()

print("\n\u2794 (40) Aufruf: yS, xS = \nkreis_gerade(y1, x1, y2, x2, yM, xM, R)")
yS, xS = ve.kreis_gerade(y1, x1, y2, x2, yM, xM, R)
print(f"yS, xS = {f3(yS)}, {f3(xS)}")
L1()

print("\n\u2794 (41) Aufruf: yS, xS = \n\
kreis_gerade(y1, x1, y2, x2, yM, xM, R, a)")
yS, xS = ve.kreis_gerade(y1, x1, y2, x2, yM, xM, R, a)
print(f"yS, xS = {f3(yS)}, {f3(xS)}")
L1()

print("\n\u2794 (42) Aufruf: yS, xS, yM, xM  = \n\
kreis_gerade(y1, x1, y2, x2, y3, x3, y4, x4, R)")
yS, xS, yM, xM = ve.kreis_gerade(y1, x1, y2, x2, y3, x3, y4, x4, R)
print(f"yS, xS = {f3(yS)}, {f3(xS)}; yM, xM = {f3(yM)}, {f3(xM)}")
L1()

print("\n\u2794 (43) Aufruf: yS, xS, yM, xM = \n\
kreis_gerade(y1, x1, y2, x2, y3, x3, y4, x4, R, a)")
yS, xS, yM, xM = ve.kreis_gerade(y1, x1, y2, x2, y3, x3, y4, x4, R, a)
print(f"yS, xS = {f3(yS)}, {f3(xS)}; yM, xM = {f3(yM)}, {f3(xM)}")
L1()

print("\n\u2794 (44) Aufruf: yS, xS, yM, xM, R = \n\
kreis_gerade(y1, x1, y2, x2, y3, x3, y4, x4, y5, x5, a)")
yS, xS, yM, xM, R = ve.kreis_gerade(y1, x1, y2, x2, y3, x3, y4, x4, y5, x5, a)
print(f"yS, xS = {f3(yS)}, {f3(xS)}; yM, xM = {f3(yM)}, {f3(xM)}; R = {f3(R)}")
L1()

y5, x5 = 10, 5.3
print("\nVariation:\n  y5, x5 = 10, 5.3\n")
print("\u2794 (44) Aufruf: yS, xS, yM, xM, R = \
      \nkreis_gerade(y1, x1, y2, x2, y3, x3, y4, x4, y5, x5, a)")
yS, xS, yM, xM, R = ve.kreis_gerade(y1, x1, y2, x2, y3, x3, y4, x4, y5, x5, a)
print(f"yS, xS = {f3(yS)}, {f3(xS)}; yM, xM = {f3(yM)}, {f3(xM)}; R = {f3(R)}")

# ************************************************************************
# 45 *****
L2()
print("\n45  *****      Senkrechtschnitt Kreis")
L1()

print("\n1. Beispiel:\n  y1, x1 = 1, 1; y2, x2 = 5, 3\n\
  yM, xM = 4, 1.5; R = 2")
print("\n\u2794 Aufruf: yS, xS = ve.senkrecht_kreis(y1, x1, y2, x2, yM, xM, R)")

y1, x1 = 1, 1
y2, x2 = 5, 3
yM, xM = 4, 1.5
R = 2

yS, xS = ve.senkrecht_kreis(y1, x1, y2, x2, yM, xM, R)
print("\nErgebnis:")
print(f"yS, xS = {f3(yS)}, {f3(xS)}")
L1()

print("\n2. Beispiel: y1, x1 = 19, 3; y2, x2 = 13, 0; yM, xM = 8, 3; R = 4")

y1, x1 = 19, 3
y2, x2 = 13, 0
yM, xM = 8, 3
R = 4
yS, xS = ve.senkrecht_kreis(y1, x1, y2, x2, yM, xM, R)
print(f"Ergebnis: yS, xS = {f3(yS)}, {f3(xS)}")


# ************************************************************************
# 46, 47 *****
L2()
print("\n46, 47  *****     bewegliche Tangente und Kreismittelpunkt und Radius")
L1()

print("\n1. Beispiel:\n  y1, x1 = 1, 1; yM, xM = 8, 6; R = 5")

print("\n\u2794 Aufruf: yT, xT, t = ve.tangente1(y1, x1, yM, xM, \u00B1R)")

y1, x1 = 1, 1
y3, x3 = 8, 11
y4, x4 = 12.9, 5
yM, xM = 8, 6
R = 5

yT, xT, t = ve.tangente1(y1, x1, yM, xM, R)
print("\nErgebnis:")
print(f"yT, xT = {f3(yT)}, {f3(xT)}; Tangente = {f3(t)}")
L1()

print("\n2. Beispiel:\ny1, x1 = 1, 1; y3, x3 = 8, 11, y4, x4 = 12.9, 5; R = 5")

print("\n\u2794 Aufruf: yT, xT, t, yM, xM = ve.tangente1(y1, x1, y3, x3, y4, x4, \u00B1R)")
yT, xT, t, yM, xM = ve.tangente1(y1, x1, y3, x3, y4, x4, R)
print("Ergebnis:")
print(f"yT, xT = {f3(yT)}, {f3(xT)}; Tangente = {f3(t)}; \
yM, xM = {f3(yM)}, {f3(xM)}")
L1()

print("\n3. Beispiel: y1, x1 = 1, 1; yM, xM = 8, 6; R = -5")

y1, x1 = 1, 1
yM, xM = 8, 6
R = -5
yT, xT, t = ve.tangente1(y1, x1, yM, xM, R)
print(f"Ergebnis: yT, xT = {f3(yT)}, {f3(xT)}; Tangente = {f3(t)}")
L1()

print("\n4. Beispiel: y1, x1 = 1, 1; y3, x3 = 12.9, 5; y4, x4 = 8, 11; R = -5")

y3, x3 = 12.9, 5
y4, x4 = 8, 11
R = -5
yT, xT, t, yM, xM = ve.tangente1(y1, x1, y3, x3, y4, x4, R)
print(f"Ergebnis: yT, xT = {f3(yT)}, {f3(xT)}; Tangente = {f3(t)}")
L1()

print("\n5. Beispiel: y1, x1 = 16, 11; yM, xM = 8, 6; R = -5")

y1, x1 = 16, 11
R = -5
yT, xT, t = ve.tangente1(y1, x1, yM, xM, R)
print(f"Ergebnis: yT, xT = {f3(yT)}, {f3(xT)}; Tangente = {f3(t)}")

# ************************************************************************
# 48 *****
L2()
print("\n48  *****     feste, tangentiale Gerade und 2 Kreispunkte")
L1()

print("\n1. Beispiel:\n  y1, x1 = 1, 5; y2, x2 = 5, 5\n\
  y3 = 10.828427, x3 = 3.828427; y4, x4 = 12, 1")

print("\n\u2794 Aufruf: yT, xT, t, yM, xM, R = \n\
       ve.tangente2(y1,x1, y2, x2, y3, x3, y4, x4)")

y1, x1 = 1, 5
y2, x2 = 5, 5
y3, x3 = 10.828427, 3.828427
y4, x4 = 12, 1

yT, xT, t, yM, xM, R = ve.tangente2(y1, x1, y2, x2, y3, x3, y4, x4)
print("\nErgebnis:")
print(f"yT, xT = {f3(yT)}, {f3(xT)}; yM, xM = {f3(yM)}, \
{f3(xM)}; R, t = {f3(R)}, {f3(t)}")
L1()

print("\n2. Beispiel:\ny1, x1 = 1, 5; y2, x2 = 5, 5\n\
y3 = 10.828427, x3 = 6.171572; y4, x4 = 12, 9")

y1, x1 = 1, 5
y2, x2 = 5, 5
y3, x3 = 10.828427, 6.171572
y4, x4 = 12, 9
yT, xT, t, yM, xM, R = ve.tangente2(y1, x1, y2, x2, y3, x3, y4, x4)
print("Ergebnis:")
print(f"yT, xT = {f3(yT)}, {f3(xT)}; yM, xM = {f3(yM)}, \
{f3(xM)}; R, t = {f3(R)}, {f3(t)}")
L1()

print("\n3. Beispiel:\n\
y1, x1 = 1000, 1000; y2, x2 = 4400, 11000\n\
y3, x3 = 8000, 11000; y4, x4 = 12000, 9000")

y1, x1 = 1000, 1000
y2, x2 = 4400, 11000
y3, x3 = 8000, 11000
y4, x4 = 12000, 9000
yT, xT, t, yM, xM, R = ve.tangente2(y1, x1, y2, x2, y3, x3, y4, x4)
print(f"Ergebnis: yT, xT = {f3(yT)}, {f3(xT)}\n\
yM, xM = {f3(yM)}, {f3(xM)}; R, t = {f3(R)}, {f3(t)}")
L1()

print("\n4. Beispiel:\ny1, x1 = 14000, 1000; y2, x2 = 12000, 12000\n\
y3, x3 = 12000, 9000; y4, x4 = 8000, 11000")

y1, x1 = 14000, 1000
y2, x2 = 12000, 12000
y3, x3 = 12000, 9000
y4, x4 = 8000, 11000
yT, xT, t, yM, xM, R = ve.tangente2(y1, x1, y2, x2, y3, x3, y4, x4)
print(f"Ergebnis: yT, xT = {f3(yT)}, {f3(xT)}\n\
yM, xM = {f3(yM)}, {f3(xM)}; R, t = {f3(R)}, {f3(t)}")
L1()

print("\n5. Beispiel:\ny1, x1 = 18, 5; y2, x2 = 8, 12;\n\
y3, x3 = 8,11; y4, x4 = 5, 10")

y1, x1 = 18, 5
y2, x2 = 8, 12
y3, x3 = 8, 11
y4, x4 = 5, 10
yT, xT, t, yM, xM, R = ve.tangente2(y1, x1, y2, x2, y3, x3, y4, x4)
print(f"Ergebnis: yT, xT = {f3(yT)}, {f3(xT)}\n\
  yM, xM = {f3(yM)}, {f3(xM)}; R, t = {f3(R)}, {f3(t)}")
L1()

print("\n6. Beispiel:\ny1, x1 = -40, 0; y2, x2 = 0, 0\n\
y3, x3 = -10.3,-2.4; y4, x4 = 31, -23")

y1, x1 = -40, 0
y2, x2 = 0, 0
y3, x3 = -10.3, -2.4
y4, x4 = 31, -23
yT, xT, t, yM, xM, R = ve.tangente2(y1, x1, y2, x2, y3, x3, y4, x4)
print(f"Ergebnis: yT, xT = {f3(yT)}, {f3(xT)}\n\
yM, xM = {f3(yM)}, {f3(xM)}; R, t = {f3(R)}, {f3(t)}")
L1()

print("\n7. Beispiel:\ny1, x1 = -116, 10; y2, x2 = -92, 10\n\
y3, x3 = -20,0; y4, x4 = 31, -27")

y1, x1 = -116, 10
y2, x2 = -92, 10
y3, x3 = -20, 0
y4, x4 = 31, -27
yT, xT, t, yM, xM, R = ve.tangente2(y1, x1, y2, x2, y3, x3, y4, x4)
print(f"Ergebnis: yT, xT = {f3(yT)}, {f3(xT)};\n\
yM, xM = {f3(yM)}, {f3(xM)}; R, t = {f3(R)}, {f3(t)}")
L1()

print("\n8. Beispiel:\n  y1, x1 = 0, 0; y2, x2 = 1, 0\n\
  y3, x3 =  0, -0.01; y4, x4 = 0.01, -20")

y1, x1 = 0, 0
y2, x2 = 1, 0
y3, x3 = 0, -0.01
y4, x4 = 0.01, -20
yT, xT, t, yM, xM, R = ve.tangente2(y1, x1, y2, x2, y3, x3, y4, x4)
print(f"Ergebnis: yT, xT = {f3(yT)}, {f3(xT)}\n\
yM, xM = {f3(yM)}, {f3(xM)}; R, t = {f3(R)}, {f3(t)}")
L1()

print("\n9. Beispiel:\ny1, x1 = 0, 0; y2, x2 = 1, 0\n\
y3, x3 = 0 , -10; y4, x4 = 20, -10.01")

y1, x1 = 0, 0
y2, x2 = 1, 0
y3, x3 = 0, -10
y4, x4 = 20, -10.01
yT, xT, t, yM, xM, R = ve.tangente2(y1, x1, y2, x2, y3, x3, y4, x4)
print(f"Ergebnis: yT, xT = {f3(yT)}, {f3(xT)};\n\
yM, xM = {f3(yM)}, {f3(xM)}; R, t = {f3(R)}, {f3(t)}")


# ************************************************************************
# 49 *****
L2()
print("\n49  *****     bewegliche Tangente und 3 Kreispunkte")
L1()

print("\n1. Beispiel:\n  y1, x1 = 1, 5; y3, x3 = 8, 5\n\
  y4, x4 = = 10.828427, 3.828427; y5, x5 = 12, 1")

print("\n\u2794 Aufruf: yT, xT, t, yM, xM, R = \n\
ve.tangente3(y1, x1, y3, x3, y4, x4, y5, x5)")

y1, x1 = 1, 5
y3, x3 = 8, 5
y4, x4 = 10.828427, 3.828427
y5, x5 = 12, 1

yT, xT, t, yM, xM, R = ve.tangente3(y1, x1, y3, x3, y4, x4, y5, x5)
print("\nErgebnis:")
print(f"yT, xT = {f3(yT)}, {f3(xT)}; yM, xM = {f3(yM)}, \
{f3(xM)}; R, t = {f3(R)}, {f3(t)}")
L1()

print("\n2. Beispiel: y1, x1 = 1, 5; y3, x3 = 8, 5\n\
y4, x4 = 10.828427, 6.171572; y5, x5 = 12, 9")

y1, x1 = 1, 5
y3, x3 = 8, 5
y4, x4 = 10.828427, 6.171572
y5, x5 = 12, 9
yT, xT, t, yM, xM, R = ve.tangente3(y1, x1, y3, x3, y4, x4, y5, x5)
print("Ergebnis:")
print(f"yT, xT = {f3(yT)}, {f3(xT)}; yM, xM = {f3(yM)}, \
{f3(xM)}; R, t = {f3(R)}, {f3(t)}")
L1()

print("\n3. Beispiel: y1, x1 = 1, 0; y3, x3 = 3, 2\n\
y4, x4 = 3, 5; y5, x5 = 0, 5")

y1, x1 = 1, 0; y3, x3 = 3, 2; y4, x4 = 3, 5; y5, x5 = 0, 5

yT, xT, t, yM, xM, R = ve.tangente3(y1, x1, y3, x3, y4, x4, y5, x5)
print("Ergebnis:")
print(f"yT, xT = {f3(yT)}, {f3(xT)}; yM, xM = {f3(yM)}, \
{f3(xM)}; R, t = {f3(R)}, {f3(t)}")
L1()

print("\n4. Beispiel: y1, x1 = 0.3, 3.5; y3, x3 = 8, 8.2\n\
y4, x4 = 10, 7.2; y5, x5 = 10, 1.3")

y1, x1 = 0.3, 3.5; y3, x3 = 8, 8.2; y4, x4 = 10, 7.2; y5, x5 = 10, 1.3
yT, xT, t, yM, xM, R = ve.tangente3(y1, x1, y3, x3, y4, x4, y5, x5)
print("Ergebnis:")
print(f"yT, xT = {f3(yT)}, {f3(xT)}; yM, xM = {f3(yM)}, \
{f3(xM)}; R, t = {f3(R)}, {f3(t)}")

# ************************************************************************
# 50 *****
L2()
print("\n50  *****     feste, tangentiale Gerade und Kreispunkt, Radius")
L1()

print("\n1. Beispiel:\n  y1, x1 = 1, 5; y2, x2 = 5, 5; y3, x3 = 12, 1; R = 4")

print("\n\u2794 Aufruf: yT, xT, t, yM, xM = \n\
ve.tangente4(y1, x1, y2, x2, y3, x3, R)")

y1, x1 = 1, 5
y2, x2 = 5, 5
y3, x3 = 12, 1
R = 4

yT, xT, t, yM, xM = ve.tangente4(y1, x1, y2, x2, y3, x3, R)
print("\nErgebnis:")
print(f"yT, xT = {f3(yT)}, {f3(xT)}; yM, xM = {f3(yM)}, \
{f3(xM)}; R, t = {f3(R)}, {f3(t)}")
L1()

print("\n2. Beispiel: y1, x1 = 1, 5; y2, x2 = 5, 5; y3, x3 = 12, 9; R = -4")

y1, x1 = 1, 5
y2, x2 = 5, 5
y3, x3 = 12, 9
R = -4
yT, xT, t, yM, xM = ve.tangente4(y1, x1, y2, x2, y3, x3, R)
print("Ergebnis:")
print(f"yT, xT = {f3(yT)}, {f3(xT)}; yM, xM = {f3(yM)}, \
{f3(xM)}; R, t = {f3(R)}, {f3(t)}")
L1()

print("\n3. Beispiel: y1, x1 = 18, 3; y2, x2 = 1, 9; y3, x3 = 3, 10.3; R = 6")

y1, x1 = 18, 3
y2, x2 = 1, 9
y3, x3 = 3, 10.3
R = 6

yT, xT, t, yM, xM = ve.tangente4(y1, x1, y2, x2, y3, x3, R)
print("Ergebnis:")
print(f"yT, xT = {f3(yT)}, {f3(xT)}; yM, xM = {f3(yM)}, \
{f3(xM)}; R, t = {f3(R)}, {f3(t)}")
L1()

print("\n4. Beispiel: y1, x1 = 18, 3; y2, x2 = 1, 9; y3, x3 = 0, 5.3; R = -6")

y1, x1 = 18, 3
y2, x2 = 1, 9
y3, x3 = 0, 5.3
R = -6
yT, xT, t, yM, xM = ve.tangente4(y1, x1, y2, x2, y3, x3, R)
print("Ergebnis:")
print(f"yT, xT = {f3(yT)}, {f3(xT)}; yM, xM = {f3(yM)}, {f3(xM)}; \
R, t = {f3(R)}, {f3(t)}")

# ************************************************************************
# 51 *****
L2()
print("\n51  *****    Tangenten mit festen Längen und feste, tangentiale Gerade")
L1()

print("\n\u2794 Aufruf: y4, x4, yM, xM, R, R1 = \n\
ve.tangente5(y1, x1, y2, x2, y3, x3, y5, x5) oder")
print("\n\u2794 Aufruf: y4, x4, yM, xM, R, R1 = \n\
ve.tangente5(y1, x1, y2, x2, y3, x3, y5, x5, -1)")

print("\n1. Beispiel:\n  y1, x1 = 6, 0; y2, x2 = 3.65, 3.25\n\
  y3, x3 = 0, 6.3; y5, x5 = 9, 9")

y1, x1 = 6, 0
y2, x2 = 3.65, 3.25
y3, x3 = 0, 6.3
y5, x5 = 9, 9

y4, x4, yM, xM, R, R1 = ve.tangente5(y1, x1, y2, x2, y3, x3, y5, x5)
print("\nErgebnis (rechts):")
print(f"y4, x4 = {f3(y4)}, {f3(x4)}; yM, xM = {f3(yM)}, {f3(xM)}")
print(f"R = {f3(R)}, R1 = {f3(R1)}")

y4, x4, yM, xM, R, R1 = ve.tangente5(y1, x1, y2, x2, y3, x3, y5, x5, -1)
print("\nErgebnis (links):")
print(f"y4, x4 = {f3(y4)}, {f3(x4)}; yM, xM = {f3(yM)}, {f3(xM)}")
print(f"R = {f3(R)}, R1 = {f3(R1)}")
L1()

print("\n2. Beispiel:\ny1, x1 = 5.25, 1; y2, x2 = 4.25, 3.8; \
y3, x3 = 1.5, 10.5; y5, x5 = 11, 10.5")

y1, x1 = 5.25, 1
y2, x2 = 4.25, 3.8
y3, x3 = 1.5, 10.5
y5, x5 = 11, 10.5
y4, x4, yM, xM, R, R1 = ve.tangente5(y1, x1, y2, x2, y3, x3, y5, x5)
print("Ergebnis:")
print(f"y4, x4 = {f3(y4)}, {f3(x4)}; yM, xM = {f3(yM)}, {f3(xM)}")
print(f"R = {f3(R)}, R1 = {f3(R1)}")
L1()

print("\n3. Beispiel:\ny1, x1 = 1.5, 7; y2, x2 = 6.5, 9.85; \
y3, x3 = 1.5, 10.5; y5, x5 = 11, 10.5")

y1, x1 = 1.5, 7
y2, x2 = 6.5, 9.85
y3, x3 = 1.5, 10.5
y5, x5 = 11, 10.5
y4, x4, yM, xM, R, R1 = ve.tangente5(y1, x1, y2, x2, y3, x3, y5, x5)
print("Ergebnis:")
print(f"y4, x4 = {f3(y4)}, {f3(x4)}; yM, xM = {f3(yM)}, {f3(xM)}")
print(f"R = {f3(R)}, R1 = {f3(R1)}")
L1()

print("\n4. Beispiel:\ny1, x1 = 0, 0; y2, x2 = 0, 2; \
y3, x3 = 0, 4; y5, x5 = 4, 4")

y1, x1 = 0, 0
y2, x2 = 0, 2
y3, x3 = 0, 4
y5, x5 = 4, 4
y4, x4, yM, xM, R, R1 = ve.tangente5(y1, x1, y2, x2, y3, x3, y5, x5)
print("Ergebnis (rechts):")
print(f"y4, x4 = {f3(y4)}, {f3(x4)}; yM, xM = {f3(yM)}, {f3(xM)}")
print(f"R = {f3(R)}, R1 = {f3(R1)}")

y4, x4, yM, xM, R, R1 = ve.tangente5(y1, x1, y2, x2, y3, x3, y5, x5, -1)
print("Ergebnis (links):")
print(f"y4, x4 = {f3(y4)}, {f3(x4)}; yM, xM = {f3(yM)}, {f3(xM)}")
print(f"R = {f3(R)}, R1 = {f3(R1)}")
L1()

print("\n5. Beispiel\ny1, x1 = 0, 0; y2, x2 = 2.3, 4.8; \
y3, x3 = 1, 5.75; y5, x5 = 9, 7.5")

y1, x1 = 0, 0
y2, x2 = 2.3, 4.8
y3, x3 = 1, 5.75
y5, x5 = 9, 7.5
y4, x4, yM, xM, R, R1 = ve.tangente5(y1, x1, y2, x2, y3, x3, y5, x5)
print("Ergebnis:")
print(f"y4, x4 = {f3(y4)}, {f3(x4)}; yM, xM = {f3(yM)}, {f3(xM)}")
print(f"R = {f3(R)}, R1 = {f3(R1)}")
L1()

print("\n6. Beispiel:\ny1, x1 = 3.7, 0; y2, x2 = 2.5, 1.8; \
y3, x3 = 1, 5.75; y5, x5 = 9, 7.5")

y1, x1 = 3.7, 0
y2, x2 = 2.5, 1.8
y3, x3 = 1, 5.75
y5, x5 = 9, 7.5
y4, x4, yM, xM, R, R1 = ve.tangente5(y1, x1, y2, x2, y3, x3, y5, x5)
print("Ergebnis:")
print(f"y4, x4 = {f3(y4)}, {f3(x4)}; yM, xM = {f3(yM)}, {f3(xM)}")
print(f"R = {f3(R)}, R1 = {f3(R1)}")

# ************************************************************************
# 52 *****
L2()
print("\n52 *****   Kreis, mit 3 festen, tangentiale Geraden")
L1()

print("\n1. Beispiel:\n  y1, x1 = 0, 0; y2, x2 = 12, 15\n  y3, x3 = 20, -6; \
y4, x4 = 17, 16\n  y5, x5 = 2, 9; y6, x6 = 20, 9")

print("\n\u2794 Aufruf: yT1, xT1, yT2, xT2, yT3, xT3, yM, xM, t1, t2, t3, R, R1 = \n\
ve.tangente6(y1, x1, y2, x2, y3, x3, y4, x4, y5, x5, y6, x6)")

y1, x1 = 0, 0
y2, x2 = 12, 15
y3, x3 = 20, -6
y4, x4 = 17, 16
y5, x5 = 2, 9
y6, x6 = 20, 9
yT1, xT1, yT2, xT2, yT3, xT3, yM, xM, t1, t2, t3, R, R1 = \
    ve.tangente6(y1, x1, y2, x2, y3, x3, y4, x4, y5, x5, y6, x6)
print("\nErgebnis:")
print(f"yT1, xT1 = {f3(yT1)}, {f3(xT1)}; yT2, yT2 = {f3(yT2)}, {f3(xT2)}")
print(f"yT3, xT3 = {f3(yT3)}, {f3(xT3)}; yM, xM = {f3(yM)}, {f3(xM)}")
print(f"t1 = {f3(t1)}, t2 = {f3(t2)}, t3 = {f3(t3)}")
print(f"R = {f3(R)}, R1 = {f3(R1)}")
L1()

print("\n2. Beispiel:\ny1, x1 = 1, 1; y2, x2 = 3.2, 5; y3, x3 = 8.5, 1\n\
y4, x4 = 7.25, 5; y5, x5 = 3, 7.5; y6, x6 = 8, 7.5")

y1, x1 = 1, 1
y2, x2 = 3.2, 5
y3, x3 = 8.5, 1
y4, x4 = 7.25, 5
y5, x5 = 3, 7.5
y6, x6 = 8, 7.5
yT1, xT1, yT2, xT2, yT3, xT3, yM, xM, t1, t2, t3, R, R1 = \
    ve.tangente6(y1, x1, y2, x2, y3, x3, y4, x4, y5, x5, y6, x6)
print("Ergebnis:")
print(f"yT1, xT1 = {f3(yT1)}, {f3(xT1)}; yT2, yT2 = {f3(yT2)}, {f3(xT2)}")
print(f"yT3, xT3 = {f3(yT3)}, {f3(xT3)}; yM, xM = {f3(yM)}, {f3(xM)}")
print(f"t1 = {f3(t1)}, t2 = {f3(t2)}, t3 = {f3(t3)}")
print(f"R = {f3(R)}, R1 = {f3(R1)}")
L1()

print("\n3. Beispiel a:\ny1, x1 = 0, 0; y2, x2 = 0, 8; y3, x3 = 10, 0\n\
y4, x4 = 10, 10; y5, x5 = 0, 8; y6, x6 = 20, 10")

y1, x1 = 0, 0
y2, x2 = 0, 8
y3, x3 = 10, 0
y4, x4 = 10, 10
y5, x5 = 0, 8
y6, x6 = 20, 10
yT1, xT1, yT2, xT2, yT3, xT3, yM, xM, t1, t2, t3, R, R1 = \
    ve.tangente6(y1, x1, y2, x2, y3, x3, y4, x4, y5, x5, y6, x6)
print("Ergebnis:")
print(f"yT1, xT1 = {f3(yT1)}, {f3(xT1)}; yT2, yT2 = {f3(yT2)}, {f3(xT2)}")
print(f"yT3, xT3 = {f3(yT3)}, {f3(xT3)}; yM, xM = {f3(yM)}, {f3(xM)}")
print(f"t1 = {f3(t1)}, t2 = {f3(t2)}, t3 = {f3(t3)}")
print(f"R = {f3(R)}, R1 = {f3(R1)}")
L1()

print("\n3. Beispiel b:\ny1, x1 = 0, 0; y2, x2 = 0, 9; y3, x3 = 10, 0\n\
y4, x4 = 10, 9; y5, x5 = 0, 9; y6, x6 = 20, 9")

y1, x1 = 0, 0
y2, x2 = 0, 9
y3, x3 = 10, 0
y4, x4 = 10, 9
y5, x5 = 0, 9
y6, x6 = 20, 9
yT1, xT1, yT2, xT2, yT3, xT3, yM, xM, t1, t2, t3, R, R1 = \
    ve.tangente6(y1, x1, y2, x2, y3, x3, y4, x4, y5, x5, y6, x6)
print("Ergebnis:")
print(f"yT1, xT1 = {f3(yT1)}, {f3(xT1)}; yT2, yT2 = {f3(yT2)}, {f3(xT2)}")
print(f"yT3, xT3 = {f3(yT3)}, {f3(xT3)}; yM, xM = {f3(yM)}, {f3(xM)}")
print(f"t1 = {f3(t1)}, t2 = {f3(t2)}, t3 = {f3(t3)}")
print(f"R = {f3(R)}, R1 = {f3(R1)}")
L1()

print("\n3. Beispiel c:\ny1, x1 = 0, 0; y2, x2 = 0, 10; y3, x3 = 10, 0\n\
y4, x4 = 10, 9; y5, x5 = 0, 10; y6, x6 = 20, 8")

y1, x1 = 0, 0
y2, x2 = 0, 10
y3, x3 = 10, 0
y4, x4 = 10, 9
y5, x5 = 0, 10
y6, x6 = 20, 8
yT1, xT1, yT2, xT2, yT3, xT3, yM, xM, t1, t2, t3, R, R1 = \
    ve.tangente6(y1, x1, y2, x2, y3, x3, y4, x4, y5, x5, y6, x6)
print("Ergebnis:")
print(f"yT1, xT1 = {f3(yT1)}, {f3(xT1)}; yT2, yT2 = {f3(yT2)}, {f3(xT2)}")
print(f"yT3, xT3 = {f3(yT3)}, {f3(xT3)}; yM, xM = {f3(yM)}, {f3(xM)}")
print(f"t1 = {f3(t1)}, t2 = {f3(t2)}, t3 = {f3(t3)}")
print(f"R = {f3(R)}, R1 = {f3(R1)}")
L1()

print("\n3. Beispiel d:\ny1, x1 = 0, 0; y2, x2 = 0, 10; y3, x3 = 10.001, 0\n\
y4, x4 = 10, 9; y5, x5 = 0, 9; y6, x6 = 20, 9")

y1, x1 = 0, 0
y2, x2 = 0, 10
y3, x3 = 10.001, 0
y4, x4 = 10, 9
y5, x5 = 0, 9
y6, x6 = 20, 9
yT1, xT1, yT2, xT2, yT3, xT3, yM, xM, t1, t2, t3, R, R1 = \
    ve.tangente6(y1, x1, y2, x2, y3, x3, y4, x4, y5, x5, y6, x6)
print("Ergebnis:")
print(f"yT1, xT1 = {f3(yT1)}, {f3(xT1)}; yT2, yT2 = {f3(yT2)}, {f3(xT2)}")
print(f"yT3, xT3 = {f3(yT3)}, {f3(xT3)}; yM, xM = {f3(yM)}, {f3(xM)}")
print(f"t1 = {f3(t1)}, t2 = {f3(t2)}, t3 = {f3(t3)}")
print(f"R = {f3(R)}, R1 = {f3(R1)}")

# ************************************************************************
# 53 *****
L2()
print("\n53  *****    2 feste, tangentiale Geraden und 1 Kreispunkt")
L1()

print("\n1. Beispiel:\n  y1, x1 = 0, 0; y2, x2 = 0, 7  \n\
  y3, x3 = 8.6, 1.5; y4, x4 = 2.8, 7.5\n  y5, x5 = 3, 5.8")

print("\n\u2794 Aufruf:\nyT1, xT1, yT2, xT2, yM, xM, t1, t2, R, R1 = \n\
ve.tangente7(y1, x1, y2, x2, y3, x3, y4, x4, y5, x5)")

y1, x1 = 0, 0
y2, x2 = 0, 7
y3, x3 = 8.6, 1.5
y4, x4 = 2.8, 7.5
y5, x5 = 3, 5.8

yT1, xT1, yT2, xT2, yM, xM, t1, t2, R, R1 = ve.tangente7(
    y1, x1, y2, x2, y3, x3, y4, x4, y5, x5)
print("\nErgebnis:")
print(f"yT1, xT1 = {f3(yT1)}, {f3(xT1)}; yT2, xT2 = {f3(yT2)}, {f3(xT2)}")
print(f"yM, xM = {f3(yM)}, {f3(xM)}; t1 = {f3(t1)}, t2 = {f3(t2)},\
R = {f3(R)}, R1 = {f3(R1)}")
L1()

print("\n2. Beispiel a:\ny1, x1 = 1,4; y2, x2 = 8.75, 10; \
y3, x3 = 12, 0\ny4, x4 = 14.1, 9; y5, x5 = 9.5, 9.2")
y1, x1 = 1, 4
y2, x2 = 8.75, 10
y3, x3 = 12, 0
y4, x4 = 14.1, 9
y5, x5 = 9.5, 9.2
yT1, xT1, yT2, xT2, yM, xM, t1, t2, R, R1 = ve.tangente7(
    y1, x1, y2, x2, y3, x3, y4, x4, y5, x5)
print("Ergebnis:")
print(f"yT1, xT1 = {f3(yT1)}, {f3(xT1)}; yT2, xT2 = {f3(yT2)}, {f3(xT2)}")
print(f"yM, xM = {f3(yM)}, {f3(xM)}; t1 = {f3(t1)}, t2 = {f3(t2)},\
R = {f3(R)}, R1 = {f3(R1)}")
L1()

print("\n2. Beispiel b:\ny1, x1 = 1,4; y2, x2 = 8.75, 10;  \
y3, x3 = 12, 0\ny4, x4 = 14.1, 9; y5, x5 = 12.7, 7")
y1, x1 = 1, 4
y2, x2 = 8.75, 10
y3, x3 = 12, 0
y4, x4 = 14.1, 9
y5, x5 = 12.7, 7
yT1, xT1, yT2, xT2, yM, xM, t1, t2, R, R1 = ve.tangente7(
    y1, x1, y2, x2, y3, x3, y4, x4, y5, x5)
print("Ergebnis:")
print(f"yT1, xT1 = {f3(yT1)}, {f3(xT1)}; yT2, xT2 = {f3(yT2)}, {f3(xT2)}")
print(f"yM, xM = {f3(yM)}, {f3(xM)}; t1 = {f3(t1)}, t2 = {f3(t2)},\
R = {f3(R)}, R1 = {f3(R1)}")
L1()


print("\n3. Beispiel:\ny1, x1 = 0,0; y2, x2 = 6, 0.5;  \
y3, x3 = 12.5, 0\ny4, x4 = 8.5, 0.5; y5, x5 = 7.5, 0.5")

y1, x1 = 0, 0
y2, x2 = 6, 0.5
y3, x3 = 12.5, 0
y4, x4 = 8.5, 0.5
y5, x5 = 7.5, 0.5

yT1, xT1, yT2, xT2, yM, xM, t1, t2, R, R1 = ve.tangente7(
    y1, x1, y2, x2, y3, x3, y4, x4, y5, x5)

print("Ergebnis:")
print(f"yT1, xT1 = {f3(yT1)}, {f3(xT1)}; yT2, xT2 = {f3(yT2)}, {f3(xT2)}")
print(f"yM, xM = {f3(yM)}, {f3(xM)}; t1 = {f3(t1)}, t2 = {f3(t2)},\
R = {f3(R)}, R1 = {f3(R1)}")
L1()

print("\n4. Beispiel:\ny1, x1 = 0, 0; y2, x2 = 6000, 500;  \n\
y3, x3 = 12500, 0\ny4, x4 = 8500, 500; y5, x5 = 7500, 500")

y1, x1 = 0, 0
y2, x2 = 6000, 500
y3, x3 = 12500, 0
y4, x4 = 8500, 500
y5, x5 = 7500, 500
yT1, xT1, yT2, xT2, yM, xM, t1, t2, R, R1 = ve.tangente7(
    y1, x1, y2, x2, y3, x3, y4, x4, y5, x5)
print("Ergebnis:")
print(f"yT1, xT1 = {f3(yT1)}, {f3(xT1)}; yT2, xT2 = {f3(yT2)}, {f3(xT2)}")
print(f"yM, xM = {f3(yM)}, {f3(xM)}; t1 = {f3(t1)}, t2 = {f3(t2)}\n\
R = {f3(R)}, R1 = {f3(R1)}")
L1()

print("\n5. Beispiel:\ny1, x1 = 1, -1; y2, x2 = 0, 0; y3, x3 = 1, 1\n\
y4, x4 = 0, 0; y5, x5 = 2, 1")

y1, x1 = 1, -1
y2, x2 = 0, 0
y3, x3 = 1, 1
y4, x4 = 0, 0
y5, x5 = 2, 1

yT1, xT1, yT2, xT2, yM, xM, t1, t2, R, R1 = ve.tangente7(
    y1, x1, y2, x2, y3, x3, y4, x4, y5, x5)

print("Ergebnis:")
print(f"yT1, xT1 = {f3(yT1)}, {f3(xT1)}; yT2, xT2 = {f3(yT2)}, {f3(xT2)}")
print(f"yM, xM = {f3(yM)}, {f3(xM)}; t1 = {f3(t1)}, t2 = {f3(t2)}\n\
R = {f3(R)}, R1 = {f3(R1)}")
L1()

print("\n6. Beispiel:\ny1, x1 = 0, 0; y2, x2 = 0, 7; y3, x3 = 7, 0\n\
y4, x4 = 7, 7; y5, x5 = 2, 6")

y1, x1 = 0, 0; y2, x2 = 0, 7; y3, x3 = 7, 0; y4, x4 = 7, 7; y5, x5 = 2, 6

yT1, xT1, yT2, xT2, yM, xM, t1, t2, R, R1 = ve.tangente7(
    y1, x1, y2, x2, y3, x3, y4, x4, y5, x5)

print("Ergebnis:")
print(f"yT1, xT1 = {f3(yT1)}, {f3(xT1)}; yT2, xT2 = {f3(yT2)}, {f3(xT2)}")
print(f"yM, xM = {f3(yM)}, {f3(xM)}; t1 = {f3(t1)}, t2 = {f3(t2)}\n\
R = {f3(R)}, R1 = {f3(R1)}")
L1()

print("\n7. Beispiel:\ny1, x1 = 2, 2; y2, x2 = 4, 2; \
y3, x3 = 6, 0\ny4, x4 = 6, 4; y5, x5 = 4, 0")

y1, x1 = 2, 2
y2, x2 = 4, 2
y3, x3 = 6, 0
y4, x4 = 6, 4
y5, x5 = 4, 0

yT1, xT1, yT2, xT2, yM, xM, t1, t2, R, R1 = ve.tangente7(
    y1, x1, y2, x2, y3, x3, y4, x4, y5, x5)
print("\nErgebnis:")
print(f"yT1, xT1 = {f3(yT1)}, {f3(xT1)}; yT2, xT2 = {f3(yT2)}, {f3(xT2)}")
print(f"yM, xM = {f3(yM)}, {f3(xM)}; t1 = {f3(t1)}, t2 = {f3(t2)}")


# ************************************************************************
# 54 *****
L2()

print("\n54  *****    2 feste, tangentiale Geraden und Radius")
L1()
print("\n1. Beispiel:\n  y1, x1 = 3, 1; y2, x2 = 3, 9\n\
  y3, x3 = 12, 0; y4, x4 = 7, 5; R = 2")

print("\n\u2794 Aufruf: yT1, xT1, yT2, xT2, yM, xM, t1, t2 = \n\
ve.tangente8(y1, x1, y2, x2, y3, x3, y4, x4, R)")

y1, x1 = 3, 1
y2, x2 = 3, 9
y3, x3 = 12, 0
y4, x4 = 7, 5
R = 2.

yT1, xT1, yT2, xT2, yM, xM, t1, t2 = ve.tangente8(
    y1, x1, y2, x2, y3, x3, y4, x4, R)
print("\nErgebnis:")
print(f"yT1, xT1 = {f3(yT1)}, {f3(xT1)}; yT2, xT2 = {f3(yT2)}, {f3(xT2)}")
print(f"yM, xM = {f3(yM)}, {f3(xM)}; t1 = {f3(t1)}, t2 = {f3(t2)}")
L1()

print("\n2. Beispiel:\ny1, x1 = 2, 2; y2, x2 = 4, 2; \
y3, x3 = 6, 0\ny4, x4 = 6, 4; R = 2")

y1, x1 = 2, 2
y2, x2 = 4, 2
y3, x3 = 6, 0
y4, x4 = 6, 4
R = 2
yT1, xT1, yT2, xT2, yM, xM, t1, t2 = ve.tangente8(
    y1, x1, y2, x2, y3, x3, y4, x4, R)
print("Ergebnis:")
print(f"yT1, xT1 = {f3(yT1)}, {f3(xT1)}; yT2, xT2 = {f3(yT2)}, {f3(xT2)}")
print(f"yM, xM = {f3(yM)}, {f3(xM)}; t1 = {f3(t1)}, t2 = {f3(t2)}")
L1()

print("\n3. Beispiel:\ny1, x1 = 13, 0; y2, x2 = 7, 3; \
y3, x3 = 13, 11\ny4, x4 = 6, 8; R = 4")

y1, x1 = 13, 0
y2, x2 = 7, 3 
y3, x3 = 13, 11
y4, x4 = 6, 8
R = 4
yT1, xT1, yT2, xT2, yM, xM, t1, t2 = ve.tangente8(
    y1, x1, y2, x2, y3, x3, y4, x4, R)
print("Ergebnis:")
print(f"yT1, xT1 = {f3(yT1)}, {f3(xT1)}; yT2, xT2 = {f3(yT2)}, {f3(xT2)}")
print(f"yM, xM = {f3(yM)}, {f3(xM)}; t1 = {f3(t1)}, t2 = {f3(t2)}")

# ************************************************************************
# 55 *****
L2()
print("\n55  *****    Tangenten außen an 2 Kreisen  ")
L1()

print("\n1. Beispiel a:\n  yM1, xM1 = 4, 4; R1 = 4 \n\
  yM2, xM2 = 12, 6; R2 = 2")

print("\n\u2794 Aufruf: y1, x1, y2, x2, t1 = \n\
ve.tangente9(yM1, xM1, R1, yM2, xM2, R2)")

yM1, xM1 = 4, 4
R1 = 4
yM2, xM2 = 12, 6
R2 = 2

y1, x1, y2, x2, t1 = ve.tangente9(yM1, xM1, R1, yM2, xM2, R2)
print("\nErgebnis:")
print(f"y1, x1 = {f3(y1)}, {f3(x1)}; y2, x2 = {f3(y2)}, \
{f3(x2)}; t1 = {f3(t1)}")
L1()

print("\n1. Beispiel b:\nyM1, xM1 = 12, 6; R1 = -2; \
yM2, xM2 = 4, 4; R2 = -4")

yM1, xM1 = 12, 6
R1 = -2
yM2, xM2 = 4, 4
R2 = -4
y1, x1, y2, x2, t1 = ve.tangente9(yM1, xM1, R1, yM2, xM2, R2)
print("Ergebnis:")
print(f"y1, x1 = {f3(y1)}, {f3(x1)}; y2, x2 = {f3(y2)}, \
{f3(x2)}; t1 = {f3(t1)}")
L1()

print("\n1. Beispiel c:\nyM1, xM1 = 12, 6; R1 = 2; \
yM2, xM2 = 4, 4; R2 = 4")

yM1, xM1 = 12, 6
R1 = 2
yM2, xM2 = 4, 4
R2 = 4
y1, x1, y2, x2, t1 = ve.tangente9(yM1, xM1, R1, yM2, xM2, R2)
print("Ergebnis:")
print(f"y1, x1 = {f3(y1)}, {f3(x1)}; y2, x2 = {f3(y2)}, \
{f3(x2)}; t1 = {f3(t1)}")
L1()

print("\n2. Beispiel a:\nyM1, xM1 = 7, 7; R1 = 6; \
yM2, xM2 = 23, 7; R2 = 4")

yM1, xM1 = 7, 7
R1 = 6
yM2, xM2 = 23, 7
R2 = 4
y1, x1, y2, x2, t1 = ve.tangente9(yM1, xM1, R1, yM2, xM2, R2)
print("Ergebnis:")
print(f"y1, x1 = {f3(y1)}, {f3(x1)}; y2, x2 = {f3(y2)}, \
{f3(x2)}; t1 = {f3(t1)}")
L1()

print("\n2. Beispiel b:\nyM1, xM1 = 23, 7; R1 = 4; \
yM2, xM2 = 7, 7; R2 = 6")

yM1, xM1 = 23, 7
R1 = 4
yM2, xM2 = 7, 7
R2 = 6
y1, x1, y2, x2, t1 = ve.tangente9(yM1, xM1, R1, yM2, xM2, R2)
print("Ergebnis:")
print(f"y1, x1 = {f3(y1)}, {f3(x1)}; y2, x2 = {f3(y2)}, \
{f3(x2)}; t1 = {f3(t1)}")

# ************************************************************************
# 56 *****
L2()
print("\n56  *****    Tangenten innen an 2 Kreisen  ")
L1()

print("\n1. Beispiel a:\n  yM1, xM1 = 4, 4; R1 = 4 \n\
  yM2, xM2 = 12, 6; R2 = -2")

print("\n\u2794 Aufruf: y3, x3, y4, x4, t3 = \n\
ve.tangente10(yM1, xM1, R1, yM2, xM2, R2)")

yM1, xM1 = 4, 4
R1 = 4
yM2, xM2 = 12, 6
R2 = -2

y3, x3, y4, x4, t3 = ve.tangente10(yM1, xM1, R1, yM2, xM2, R2)
print("\nErgebnis:")
print(f"y3, x3 = {f3(y3)}, {f3(x3)}; y4, x4 = {f3(y4)}, \
{f3(x4)}; t3 = {f3(t3)}")
L1()

print("\n1. Beispiel b:\nyM1, xM1 = 12, 6; R1 = 2; \
yM2, xM2 = 4, 4; R2 = -4")

yM1, xM1 = 12, 6
R1 = 2
yM2, xM2 = 4, 4
R2 = -4
y3, x3, y4, x4, t3 = ve.tangente10(yM1, xM1, R1, yM2, xM2, R2)
print("Ergebnis:")
print(f"y3, x3 = {f3(y3)}, {f3(x3)}; y4, x4 = {f3(y4)}, \
{f3(x4)}; t3 = {f3(t3)}")
L1()

print("\n1. Beispiel c:\nyM1, xM1 = 4, 4; R1 = -4; \
yM2, xM2 = 12, 6; R2 = 2")

yM1, xM1 = 4, 4
R1 = -4
yM2, xM2 = 12, 6
R2 = 2
y3, x3, y4, x4, t3 = ve.tangente10(yM1, xM1, R1, yM2, xM2, R2)
print("Ergebnis:")
print(f"y3, x3 = {f3(y3)}, {f3(x3)}; y4, x4 = {f3(y4)}, \
{f3(x4)}; t3 = {f3(t3)}")
L1()

print("\n2. Beispiel:\nyM1, xM1 = 0, 0; R1 = 3; \
yM2, xM2 = 10, 5; R2 = -2")

yM1, xM1 = 0, 0
R1 = 3
yM2, xM2 = 10, 5
R2 = -2
y3, x3, y4, x4, t3 = ve.tangente10(yM1, xM1, R1, yM2, xM2, R2)
print("Ergebnis:")
print(f"y3, x3 = {f3(y3)}, {f3(x3)}; y4, x4 = {f3(y4)}, \
{f3(x4)}; t3 = {f3(t3)}")
L1()

print("\n3. Beispiel:\nyM1, xM1 = 4, 4; R1 = 4; \
yM2, xM2 = 15, 6; R2 = -5")

yM1, xM1 = 4, 4
R1 = 4
yM2, xM2 = 15, 6
R2 = -5
y3, x3, y4, x4, t3 = ve.tangente10(yM1, xM1, R1, yM2, xM2, R2)
print("Ergebnis:")
print(f"y3, x3 = {f3(y3)}, {f3(x3)}; y4, x4 = {f3(y4)}, \
{f3(x4)}; t3 = {f3(t3)}")

# ***********************************************************************
# 57 *****
L2()
print("\n57  *****    Tangential Umkreis 3 Kreise")
L1()

print("\n1. Beispiel:\n  yM1, xM1 = 2, 2; R1 = 2 \n\
  yM2, xM2 = 6, 3; R2 = 1; R3 = 10")

print("\n\u2794 Aufruf: y1, x1, y2, x2, yM3, xM3 = \n\
ve.tangente11(yM1, xM1, R1, yM2, xM2, R2, R3)")

yM1, xM1 = 2, 2
R1 = 2
yM2, xM2 = 6, 3
R2 = 1
R3 = 10

y1, x1, y2, x2, yM3, xM3 = ve.tangente11(yM1, xM1, R1, yM2, xM2, R2, R3)
print("\nErgebnis:")
print(f"y1, x1 = {f3(y1)}, {f3(x1)}; y2, x2 = {f3(y2)}, {f3(x2)}")
print(f"yM3, xM3 = {f3(yM3)}, {f3(xM3)}")
L1()

print("\n2. Beispiel:\n  yM1, xM1 = 2, 2; R1 = 2 \n\
  yM2, xM2 = 6, 3; R2 = 1; R3 = -3")

print("\n\u2794 Aufruf: y3, x3, y4, x4, yM4, xM4 = \n\
ve.tangente11(yM1, xM1, R1, yM2, xM2, R2, R3)")

yM1, xM1 = 2, 2
R1 = 2
yM2, xM2 = 6, 3
R2 = 1
R3 = -3

y1, x1, y2, x2, yM3, xM3 = ve.tangente11(yM1, xM1, R1, yM2, xM2, R2, R3)
print("\nErgebnis:")
print(f"y1, x1 = {f3(y1)}, {f3(x1)}; y2, x2 = {f3(y2)}, {f3(x2)}")
print(f"yM3, xM3 = {f3(yM3)}, {f3(xM3)}")

# ************************************************************************
# 58 *****
L2()
print("\n58  *****    Tangential Um-  und Ankreis, 3 Kreise")
L1()

print("\n1 Beispiel:\n  yM1, xM1 = 4.6, 4.5; R1 = 3.1 \n\
  yM2, xM2 = 11.6, 5.5; R2 = 4; y3, x3 =9, 10.5 ")

print("\n\u2794 Aufruf: y1, x1, y2, x2, yM3, xM3 = \n\
ve.tangente12(yM1, xM1, R1, yM2, xM2, R2, y3, x3)")

yM1, xM1 = 4.6, 4.5
R1 = 3.1
yM2, xM2 = 11.6, 5.5
R2 = 4
y3, x3 = 9, 10.5

yM3, xM3, R3 = ve.tangente12(yM1, xM1, R1, yM2, xM2, R2, y3, x3)
print("\nErgebnis:",yM3, xM3, R3)

print(f"yM3, xM3, R3 = {f3(yM3)}, {f3(xM3)}, {f3(R3)}")
L1()

print("\n2. Beispiel:\n  yM1, xM1 = 4.6, 4.5; R1 = 3.1 \n\
  yM2, xM2 = 11.6, 5.5; R2 = 4; y3, x3 =9, 10.5 ")

print("\n\u2794 Aufruf: y1, x1, y2, x2, yM3, xM3 = \n\
ve.tangente12(yM1, xM1, R1, yM2, xM2, R2, y3, x3)")

yM1, xM1, R1 =  3, 3, 2  # Erster Kreis: Mittelpunkt und Radius
yM2, xM2, R2 = 18.8, 7.3, 3.1
y3, x3 = 8, 1.5  # Punkt auf dem gesuchten Kreis

yM3, xM3, R3 = ve.tangente12(yM1, xM1, R1, yM2, xM2, R2, y3, x3)
print("\nErgebnis:",yM3, xM3, R3)

print(f"yM3, xM3, R3 = {f3(yM3)}, {f3(xM3)}, {f3(R3)}")
L1()

print("\n3. Beispiel:\n  yM1, xM1 = 0, 0; R1 = 1 \n\
  yM2, xM2 = 3, 0; R2 = 1; y3, x3 = 2,1 ")

print("\n\u2794 Aufruf: y1, x1, y2, x2, yM3, xM3 = \n\
ve.tangente12(yM1, xM1, R1, yM2, xM2, R2, y3, x3)")

yM1, xM1, R1 = 0,0,1 # Erster Kreis: Mittelpunkt und Radius
yM2, xM2, R2 = 4, 0, 1
y3, x3 = 2, 1  # Punkt auf dem gesuchten Kreis

yM3, xM3, R3 = ve.tangente12(yM1, xM1, R1, yM2, xM2, R2, y3, x3)
print("\nErgebnis:",yM3, xM3, R3)

print(f"yM3, xM3, R3 = {f3(yM3)}, {f3(xM3)}, {f3(R3)}")

# ************************************************************************
# 59 *****
L2()
print("\n59  *****     tangentiale 3 Kreise, 3 Punkte, Umkreis")
L1()

print("\n1. Beispiel:\n  y1, x1 = 0, 2; y2, x2 = 2, 4; y3, x3 = 4, 2\n\
  y4, x4 = 5 ,3; y5, x5 = 6, 4; y6, x6 = 7, 3; R3 = 20")

print("\n\u2794 Aufruf: y7, x7, R1, y8, x8, R2, yM3, xM3 = \n\
ve.tangente11(y1, x1, y2, x2, y3, x3, y4, x4, y5, x5, y6, x6, R3)")

y1, x1 = 0, 2
y2, x2 = 2, 4
y3, x3 = 4, 2
y4, x4 = 5, 3
y5, x5 = 6, 4
y6, x6 = 7, 3
R3 = 20

y7, x7, R1, y8, x8, R2, yM3, xM3 = ve.tangente13(
    y1, x1, y2, x2, y3, x3, y4, x4, y5, x5, y6, x6, R3)
print("\nErgebnis:")
print(f"y7, x7 = {f3(y7)}, {f3(x7)}; y8, x8 = {f3(y8)}, {f3(x8)}")
print(f"R1 = {f3(R1)},  R2 = {f3(R2)}")
print(f"yM3, xM3 = {f3(yM3)}, {f3(xM3)}")

L1()

print("\n2. Beispiel:\ny1, x1 = 2.5, 6; y2, x2 = 4.3, 5.32; y3, x3 = 5.25, 2\n\
y4, x4 = 7.5, 3; y5, x5 = 8.2, 4.5; y6, x6 = 11.3, 3.8; R3 = 16")

print("\n\u2794 Aufruf: y7, x7, R1, y8, x8, R2 = \n\
ve.tangente11(y1, x1, y2, x2, y3, x3, y4, x4, y5, x5, y6, x6, R3)")

y1, x1 = 2.5, 6
y2, x2 = 4.3, 5.32
y3, x3 = 5.25, 2
y4, x4 = 7.5, 3
y5, x5 = 8.2, 4.5
y6, x6 = 11.3, 3.8
R3 = 16

y7, x7, R1, y8, x8, R2, yM3, xM3 = ve.tangente13(
    y1, x1, y2, x2, y3, x3, y4, x4, y5, x5, y6, x6, R3)
print("\nErgebnis:")
print(f"y7, x7 = {f3(y7)}, {f3(x7)}; y8, x8 = {f3(y8)}, {f3(x8)}")
print(f"R1 = {f3(R1)},  R2 = {f3(R2)}")
print(f"yM3, xM3 = {f3(yM3)}, {f3(xM3)}")
L1()

print("\n3. Beispiel:\ny1, x1 = 1, 6.5; y2, x2 = 3.2, 8; y3, x3 = 7.5, 6.5\n\
y4, x4 = 4.5, 5.5; y5, x5 = 9.3, 2.5; y6, x6 = 6.5, 0.5; R3 = 9")

print("\n\u2794 Aufruf: y7, x7, R1, y8, x8, R2 = \n\
ve.tangente11(y1, x1, y2, x2, y3, x3, y4, x4, y5, x5, y6, x6, R3)")

y1, x1 = 1, 6.5
y2, x2 = 3.2, 8
y3, x3 = 7.5, 6.5
y4, x4 = 4.5, 5.5
y5, x5 = 9.3, 2.5
y6, x6 = 6.5, 0.5
R3 = 9

y7, x7, R1, y8, x8, R2, yM3, xM3 = ve.tangente13(
    y1, x1, y2, x2, y3, x3, y4, x4, y5, x5, y6, x6, R3)
print("\nErgebnis:")
print(f"y7, x7 = {f3(y7)}, {f3(x7)}; y8, x8 = {f3(y8)}, {f3(x8)}")
print(f"R1 = {f3(R1)},  R2 = {f3(R2)}")
print(f"yM3, xM3 = {f3(yM3)}, {f3(xM3)}")

# ************************************************************************
# 60 *****
L2()
print("\n60  *****     tangentiale 3 Kreise, 3 Punkte, Ankreis")
L1()

print("\n1. Beispiel:\n  y1, x1 = 0, 2; y2, x2 = 2, 4; y3, x3 = 4, 2\n\
  y4, x4 = 5, 3; y5, x5 = 6, 4; y6, x6 = 7, 3; R4 = -3")

print("\n\u2794 Aufruf: y9, x9, R1, y10, x10, R2, yM4, xM4 = \n\
ve.tangente11(y1, x1, y2, x2, y3, x3, y4, x4, y5, x5, y6, x6, R4)")

y1, x1 = 0, 2
y2, x2 = 2, 4
y3, x3 = 4, 2
y4, x4 = 5, 3
y5, x5 = 6, 4
y6, x6 = 7, 3
R4 = -3

y9, x9, R1, y10, x10, R2, yM4, xM4 = ve.tangente14(
    y1, x1, y2, x2, y3, x3, y4, x4, y5, x5, y6, x6, R4)
print("\nErgebnis:")
print(f"y9, x9 = {f3(y9)}, {f3(x9)}; y10, x10 = {f3(y10)}, {f3(x10)}")
print(f"R1 = {f3(R1)},  R2 = {f3(R2)}")
print(f"yM4, xM4 = {f3(yM4)}, {f3(xM4)}")
L1()

print("\n2. Beispiel:\ny1, x1 = 2.5, 6; y2, x2 = 4.3, 5.32; y3, x3 = 5.25, 2\n\
y4, x4 = 7.5, 3; y5, x5 = 8.2, 4.5; y6, x6 = 11.3, 3.8; R4 = -3")

y1, x1 = 2.5, 6
y2, x2 = 4.3, 5.32
y3, x3 = 5.25, 2
y4, x4 = 7.5, 3
y5, x5 = 8.2, 4.5
y6, x6 = 11.3, 3.8
R4 = -3

y9, x9, R1, y10, x10, R2, yM4, xM4 = ve.tangente14(
    y1, x1, y2, x2, y3, x3, y4, x4, y5, x5, y6, x6, R4)
print("Ergebnis:")
print(f"y9, x9 = {f3(y9)}, {f3(x9)}; y10, x10 = {f3(y10)}, {f3(x10)}")
print(f"R1 = {f3(R1)},  R2 = {f3(R2)}")
print(f"yM4, xM4 = {f3(yM4)}, {f3(xM4)}")
L1()

print("\n3. Beispiel:\ny1, x1 = 1, 6.5; y2, x2 = 3.2, 8; y3, x3 = 7.5, 6.5\n\
y4, x4 = 4.5, 5.5; y5, x5 = 9.3, 2.5; y6, x6 = 6.5, 0.5; R4 = -9")

y1, x1 = 1, 6.5
y2, x2 = 3.2, 8
y3, x3 = 7.5, 6.5
y4, x4 = 4.5, 5.5
y5, x5 = 9.3, 2.5
y6, x6 = 6.5, 0.5
R4 = -9

y9, x9, R1, y10, x10, R2, yM4, xM4 = ve.tangente14(
    y1, x1, y2, x2, y3, x3, y4, x4, y5, x5, y6, x6, R4)
print("Ergebnis:")
print(f"y9, x9 = {f3(y9)}, {f3(x9)}; y10, x10 = {f3(y10)}, {f3(x10)}")
print(f"R1 = {f3(R1)},  R2 = {f3(R2)}")
print(f"yM4, xM4 = {f3(yM4)}, {f3(xM4)}")
L1()


print("\n4. Beispiel:\ny1, x1 = 0, 2; y2, x2 = 2, 4; y3, x3 = 4, 2\n\
y4, x4 = 5, 3; y5, x5 = 6, 4; y6, x6 = 7, 3; R4 = -20")

y1, x1 = 0, 2
y2, x2 = 2, 4
y3, x3 = 4, 2
y4, x4 = 5, 3
y5, x5 = 6, 4
y6, x6 = 7, 3
R4 = -20

y9, x9, R1, y10, x10, R2, yM4, xM4 = ve.tangente14(
    y1, x1, y2, x2, y3, x3, y4, x4, y5, x5, y6, x6, R4)
print("Ergebnis:")
print(f"y9, x9 = {f3(y9)}, {f3(x9)}; y10, x10 = {f3(y10)}, {f3(x10)}")
print(f"R1 = {f3(R1)},  R2 = {f3(R2)}")
print(f"yM4, xM4 = {f3(yM4)}, {f3(xM4)}")


# ************************************************************************
# 61 *****
L2()
print("\n61  *****     tangentiale Anschlussbögen Umkreis, 3 + 2 Punkte")
L1()

print("\n1. Beispiel:\n  y1, x1 = 0, 0; y2, x2 = 2, 2; y3, x3 = 4, 0\n\
  y4, x4 = 2, 4; y5, x5 = 10, 4")

print("\n\u2794 Aufruf: y7, x7, yM1, xM1, R1, yM3, xM3, R3 = \n\
ve.tangente15(y1, x1, y2, x2, y3, x3, y4, x4, y5, x5)")

y1, x1 = 0, 0
y2, x2 = 2, 2
y3, x3 = 4, 0
y4, x4 = 2, 4
y5, x5 = 10, 4

y7, x7, yM1, xM1, R1, yM3, xM3, R3 =\
    ve.tangente15(y1, x1, y2, x2, y3, x3, y4, x4, y5, x5)
print("\nErgebnis:")
print(f"y7, x7 = {f3(y7)}, {f3(x7)}")
print(f"yM1, xM1 = {f3(yM1)}, {f3(xM1)}; R1 = {f3(R1)}")
print(f"yM3, xM3 = {f3(yM3)}, {f3(xM3)}; R3 = {f3(R3)}")
L1()

print("\n2. Beispiel:\ny1, x1 = 6, 3; y2, x2 = 3, 0; y3, x3 = 0, 3\n\
y4, x4 = 7.5, 4; y5, x5 = 9, 0")

y1, x1 = 6, 3
y2, x2 = 3, 0
y3, x3 = 0, 3
y4, x4 = 7.5, 4
y5, x5 = 9, 0

y7, x7, yM1, xM1, R1, yM3, xM3, R3 =\
    ve.tangente15(y1, x1, y2, x2, y3, x3, y4, x4, y5, x5)
print("\nErgebnis:")
print(f"y7, x7 = {f3(y7)}, {f3(x7)}")
print(f"yM1, xM1 = {f3(yM1)}, {f3(xM1)}; R1 = {f3(R1)}")
print(f"yM3, xM3 = {f3(yM3)}, {f3(xM3)}; R3 = {f3(R3)}")

# ************************************************************************
# 62 *****
L2()
print("\n62  *****     tangentiale Anschlussbögen Ankreis, 3 + 2 Punkte")
L1()

print("\n1. Beispiel:\n  y1, x1 = 0, 0; y2, x2 = 2, 2; y3, x3 = 4, 0\n\
  y4, x4 = 2, 4; y5, x5 = 10, 4")

print("\n\u2794 Aufruf: y8, x8, yM1, xM1, R1, yM3, xM3, -R3 = \n\
ve.tangente16(y1, x1, y2, x2, y3, x3, y4, x4, y5, x5)")

y1, x1 = 0, 0
y2, x2 = 2, 2
y3, x3 = 4, 0
y4, x4 = 2, 4
y5, x5 = 6, 0.5 #10, 4

y8, x8, yM1, xM1, R1, yM3, xM3, R3 =\
    ve.tangente16(y1, x1, y2, x2, y3, x3, y4, x4, y5, x5)
print("\nErgebnis:")
print(f"y8, x8 = {f3(y8)}, {f3(x8)}")
print(f"yM1, xM1 = {f3(yM1)}, {f3(xM1)}; R1 = {f3(R1)}")
print(f"yM3, xM3 = {f3(yM3)}, {f3(xM3)}; R3 = {f3(R3)}")
L1()

print("\n2. Beispiel:\ny1, x1 = 6, 3; y2, x2 = 3, 0; y3, x3 = 0, 3\n\
y4, x4 = 7.5, 4; y5, x5 = 9, 0")

y1, x1 = 6, 3
y2, x2 = 3, 0
y3, x3 = 0, 3
y4, x4 = 6, 1.5
y5, x5 = 7.5, 4

y8, x8, yM1, xM1, R1, yM4, xM4, R3 =\
    ve.tangente16(y1, x1, y2, x2, y3, x3, y4, x4, y5, x5)
print("Ergebnis:")
print(f"y8, x8 = {f3(y8)}, {f3(x8)}")
print(f"yM1, xM1 = {f3(yM1)}, {f3(xM1)}; R1 = {f3(R1)}")
print(f"yM3, xM3 = {f3(yM3)}, {f3(xM3)}; R3 = {f3(R3)}")


# ************************************************************************
# 63 *****
L2()
print("\n63 *****    Paralleler Kreisbogen")
L1()

print("\n1. Beispiel:\n  y1, x1 = 0, 4\n\
  y2, x2 = 6, 4\n\
  R1 = 5, a = -1")

y1, x1 = 0, 4
y2, x2 = 6, 4
R1 = 5
a = -1

y3, x3, y4, x4, yM, xM, R2 = ve.parallelkreis(y1, x1, y2, x2, R1, a)

print("\n\u2794 Aufruf: y3, x3, y4, x4, yM, xM, R2 = \
\n         parallelkreis(y1, x1, y2, x2, R1, a)")
print(f"\nErgebnis: y3 = {f3(y3)}, x3 = {f3(x3)}, \
y4 = {f3(y4)}, x4 = {f3(x4)}")
print(f"yM = {f3(yM)}, xM = {f3(xM)}, R2 = {f3(R2)}")
L1()

print("\n2. Beispiel:\ny1, x1 = 4, 6; y2, x2 = 4, 0; R1 = 5; a = 2")

y1, x1 = 4, 6; y2, x2 = 4, 0; R1 = 5; a = 2

y3, x3, y4, x4, yM, xM, R2 = ve.parallelkreis(y1, x1, y2, x2, R1, a)

print(f"Ergebnis: y3 = {f3(y3)}, x3 = {f3(x3)}, \
y4 = {f3(y4)}, x4 = {f3(x4)}")
print(f"yM = {f3(yM)}, xM = {f3(xM)}, R2 = {f3(R2)}")
# ************************************************************************
# 64 *****
L2()
print("\n64 *****    Rückwärtsschnitt")
L1()

print("\n1. Beispiel:\n  y1, x1 = 0, 0; y2, x2 = 2, 1; y3, x3 = 3, 3\n\
  alpha = 50; beta = 50")

print("\n\u2794 Aufruf nach Collins: yS, xS = \n\
ve.rueckwaertsschnitt1(y1, x1, y2, x2, y3, x3, alpha, beta)")

y1, x1 = 0, 0
y2, x2 = 2, 1
y3, x3 = 3, 3
alpha = 50
beta = 50
yS, xS = ve.rueckwaertsschnitt1(y1, x1, y2, x2, y3, x3, alpha, beta)
print("\nErgebnis:")
print(f"yS, xS = {f3(yS)}, {f3(xS)}")


print("\n\u2794 Aufruf nach Cassini : yS, xS = \n\
ve.rueckwaertsschnitt2(y1, x1, y2, x2, y3, x3, alpha, beta)")

y1, x1 = 0, 0
y2, x2 = 2, 1
y3, x3 = 3, 3
alpha = 50
beta = 50
yS, xS = ve.rueckwaertsschnitt2(y1, x1, y2, x2, y3, x3, alpha, beta)

print("\nErgebnis:")
print(f"yS, xS = {f3(yS)}, {f3(xS)}")
L1()

print("\n\n2. Beispiel aus: Witte/Schmidt, Vermessungskunde und Grundlagen\n\
der Statistik für das Bauwesen, 3. Auflage, S. 401\n\
y1, x1 = 5496.49, 28245.77; y2, x2 =6035.95, 27926.37;\n\
y3, x3 =5581.83, 27532.55\n\
alpha = 126.3944; beta = 134.6211")
y1, x1 = 5496.49, 28245.77
y2, x2 = 6035.95, 27926.37
y3, x3 = 5581.83, 27532.55
alpha = 126.3944
beta = 134.6211
yS, xS = ve.rueckwaertsschnitt1(y1, x1, y2, x2, y3, x3, alpha, beta)
print("\nErgebnis aus rueckwaertsschnitt1():")
print(f"yS, xS = {f3(yS)}, {f3(xS)}")

yS, xS = ve.rueckwaertsschnitt2(y1, x1, y2, x2, y3, x3, alpha, beta)
print("Ergebnis aus rueckwaertsschnitt2():")
print(f"yS, xS = {f3(yS)}, {f3(xS)}")
L1()

print("\n\n3. Beispiel aus: Jacobs, Trigonometrische und polygonometrische \n\
Berechnungen in den amtlichen Vermessungsvordrucken, 1967, S. 86\n\
y1, x1 = 57103.04, 8759.74; y2, x2 = 58509.73, 8201.94;\n\
y3, x3 = 57246.21, 7413.62\n\
alpha = 127.1445; beta = 142.6091")
y1, x1 = 57103.04, 8759.74
y2, x2 = 58509.73, 8201.94
y3, x3 = 57246.21, 7413.62
alpha = 127.1445
beta = 142.6091
yS, xS = ve.rueckwaertsschnitt1(y1, x1, y2, x2, y3, x3, alpha, beta)
print("\nErgebnis aus rueckwaertsschnitt1():")
print(f"yS, xS = {f3(yS)}, {f3(xS)}")

yS, xS = ve.rueckwaertsschnitt2(y1, x1, y2, x2, y3, x3, alpha, beta)
print("Ergebnis aus rueckwaertsschnitt2():")
print(f"yS, xS = {f3(yS)}, {f3(xS)}")
L1()

print("\n\n4. Beispiel aus: Nds, Erläuterungen und Rechenbeispiele zu den \n\
Vermessungsvordrucken, 1960, S. 29\n\
y1, x1 = 46988.24, 50175.85; y2, x2 = 45947.53, 49900.73;\n\
y3, x3 = 44971.35, 49335.64\n\
alpha = 38.5678; beta = 57.5125")
y1, x1 = 46988.24, 50175.85
y2, x2 = 45947.53, 49900.73
y3, x3 = 44971.35, 49335.64
alpha = 38.5678
beta = 57.5125
yS, xS = ve.rueckwaertsschnitt1(y1, x1, y2, x2, y3, x3, alpha, beta)
print("\nErgebnis aus rueckwaertsschnitt1():")
print(f"yS, xS = {f3(yS)}, {f3(xS)}")

yS, xS = ve.rueckwaertsschnitt2(y1, x1, y2, x2, y3, x3, alpha, beta)
print("Ergebnis aus rueckwaertsschnitt2():")
print(f"yS, xS = {f3(yS)}, {f3(xS)}")

# ************************************************************************
# 65, 66 *****
L2()
print("\n65, 66 *****    Segment, rechtsläufig")
L1()

print("\n1. Beispiel:\n  y1, x1 = 0, 0; y2, x2 = 0, 4; R = 5")
print("\n\u2794 Aufruf: F, s, b = ve.segment(y1, x1, y2, x2, R)")

y1, x1 = 0, 0
y2, x2 = 0, 4
s = 4
R = 5

F, s, b = ve.segment(y1, x1, y2, x2, R)
print("\nErgebnis: Segment F, s, b = ", f2(F), s, b)
L1()

print("\n2. Beispiel:\n  s = 4; R = 5")
print("\n\u2794 Aufruf: F, s, b = ve.segment(s, R)")
F, s, b = ve.segment(s, R)
print("\nErgebnis: Segment F, s, b = ", f2(F), f3(s), f3(b))

# ************************************************************************
# 67 *****
L2()
print("\n67  *****   Fläche, Seitenlängen")
L1()

print("\nBeispiel:\
\nflaeche_polygon = [   # Pktn. (num), y, x, R\
\n1, 0, 0, 5,\
\n2, 0, 3, -6,\
\n3, 4, 3, 0,\
\n4, 2, 0, 0\
]")

print("\n\u2794 Aufruf: F, koord8 = ve.flaeche(flaeche_polygon)")

flaeche_polygon = [
    1, 0, 0, 5,
    2, 0, 3, -6,
    3, 4, 3, 0,
    4, 2, 0, 0
]
F, koord8 = ve.flaeche(flaeche_polygon)
print("\nErgebnis:")
print(tabulate.tabulate(koord8, floatfmt=(".0f", ".3f", ".3f", ".3f", ".3f"),
                        headers=["PktNr", "y", "x", "Radien", "Strecken"]))
print("\nFläche = ", f2(F))

# ************************************************************************
# 68 *****
L2()
print("\n68  *****   Fläche, Seitenlängen (Variante)")
L1()

print("\n1. Beispiel:\
\nflaeche_polygon = [   # Pktn. (num), y, x, R\
\n1, 0, 0, 5,\
\n2, 0, 3, -6,\
\n3, 4, 3, 0,\
\n4, 2, 0, 0\
]")

print("\n\u2794 Aufruf: F, koord8 = ve.flaeche2(flaeche_polygon)")

flaeche_polygon = [
    1, 0, 0, 5,
    2, 0, 3, -6,
    3, 4, 3, 0,
    4, 2, 0, 0
]
F, koord8 = ve.flaeche2(flaeche_polygon)
print("\nErgebnis:")
print(tabulate.tabulate(koord8, floatfmt=(".0f", ".3f", ".3f", ".3f", ".3f"),
                        headers=["PktNr", "y", "x", "Radien", "Strecken"]))

print("\nFläche2 = ", f2(F))

# ************************************************************************
# 69 *****
L2()
print("\n69  *****    Dreieck, Höhe und Höhenfußpunkt")
L1()

print("\n1. Beispiel:\n  a = 5; b = 5; c = 6")

print("\n\u2794 Aufruf: \nh, p, q, alpha, beta, gamma, F = ve.dreieck(a, b, c)")

a = 5
b = 5
c = 6

h, p, q, alpha, beta, gamma, F = ve.dreieck(a, b, c)
print("\nErgebnis: h, p, q, alpha, beta, gamma, F =\n", f3(
    h), f3(p), f3(q), f4(alpha), f4(beta), f4(gamma), f2(F))
L1()

print("\n2. Beispiel: a = 30, b = 40, c = 50")

a = 30
b = 40
c = 50
h, p, q, alpha, beta, gamma, F = ve.dreieck(a, b, c)
print("Ergebnis: h, p, q, alpha, beta, gamma, F =\n", f3(
    h), f3(p), f3(q), f4(alpha), f4(beta), f4(gamma), f2(F))

# ************************************************************************
# 70 *****
L2()
print("\n70  *****    Strecke: Reduktion von wahrer, örtlicher Strecke\
\n             nach UTM")
L1()

print("\n1. Beispiel:\
\n  most = 530\
\n  hoehe =150; undulation = 46.5\
\n  a = 300.1259733148275")

print("\n\u2794 Aufruf: streckeUTM = \
\n           ve.streckenreduktion(a, most, hoehe, undulation)")

most = 530
hoehe = 150
undulation = 46.5
a = 300.1259733148275
streckeUTM = ve.streckenreduktion(a, most, hoehe, undulation)
print("\nErgebnis: streckeUTM = s = ", streckeUTM)

# ************************************************************************
# 71, 72 *****
L2()
print("\n71, 72  *****    Strecke: Reduktion von UTM\n\
                 (Koordinaten bzw. Streckenlänge)\n\
                 in wahre, örtliche Strecke")
L1()

print("\n1. Beispiel:\
\n  most = 530\
\n  hoehe = 150; undulation = 46.5\
\n  y1, x1, y2, x2 = 2000, 2000, 2000, 2300\
\n  s = 300 (UTM-Strecke)\
\n  a = 300.1259733148275 (wahre Strecke)")

print("\n\u2794 Aufruf: streckewahr = \
\n           streckeUTM(y1, x1, y2, x2, most, hoehe, undulation)")

most = 530
hoehe = 150
undulation = 46.5
a = 300.1259733148275
s = 300
y1 = 2000
x1 = 2000
y2 = 2000
x2 = 2300.
streckewahr = ve.streckeUTM(y1, x1, y2, x2, most, hoehe, undulation)
print("\nErgebnis: streckewahr = a =", f3(streckewahr))
L1()

print("\n2. Beispiel:")
print("\n\u2794 Aufruf: streckewahr = \
\n           streckeUTM(s, most, hoehe, undulation)")

streckewahr = ve.streckeUTM(s, most, hoehe, undulation)
print("\nErgebnis: streckewahr = a =", f3(streckewahr))

# ************************************************************************
# 73 *****
L2()
print("\n73  *****    Klotoidenelemente")
L1()
print("\nBeispiel 1:(im lokalen System)\
\n  y1 = 0, x1 = 0\
\n  t1 = 100\
\n  A = 100\
\n  L = 100\
\n  a = 10")

print("\n\u2794 Aufruf: y1, x1, t1, A, L, a = \
\n  klothoidenelemente(x, y, R, sigma_gon, tau_gon,\
\n  xM_lokal, yM_lokal, deltaR, TL, TK, y2, x2, y3, x3, yM, xM)")

y1 = 0
x1 = 0
t1 = 100
A = 100
L = 100
a = 10
x, y, R, sigma_gon, tau_gon, xM_lokal, yM_lokal, \
    deltaR, TL, TK, y2, x2, y3, x3, yM, xM = ve.klothoidenelemente(
        y1, x1, t1, A, L, a)

d = [["x(math.)", f3(x)], ["y(math.)", f3(y)], ["sigma_gon", f4(sigma_gon)], ["tau_gon", f4(tau_gon)],
     ["xM_lokal(math.)", f3(xM_lokal)], ["yM_lokal(math.)", f3(yM_lokal)], [
    "deltaR", f3(deltaR)],
    ["TL", f3(TL)], ["TK", f3(TK)], ["y2(geod.)", f3(y2)], [
    "x2(geod.)", f3(x2)], ["y3(geod.)", f3(y3)], ["x3(geod.)", f3(x3)],
    ["yM(geod.)", f3(yM)], ["xM(geod.)", f3(xM)]]
print("\nErgebnisse:")
print(tabulate.tabulate(d, headers=["\nElemente", " "]))

L1()
print("\nBeispiel 2:\
\n  y1 = 100, x1 = 200\
\n  t1 = 50\
\n  A = 100\
\n  L = 100\
\n  a = 10")

y1 = 100
x1 = 200
t1 = 50
A = 100
L = 100
a = 10
x, y, R, sigma_gon, tau_gon, xM_lokal, yM_lokal, \
    deltaR, TL, TK, y2, x2, y3, x3, yM, xM = ve.klothoidenelemente(
        y1, x1, t1, A, L, a)

d = [["x(math.)", f3(x)], ["y(math.)", f3(y)], ["sigma_gon", f4(sigma_gon)], ["tau_gon", f4(tau_gon)],
     ["xM_lokal(math.)", f3(xM_lokal)], ["yM_lokal(math.)", f3(yM_lokal)], [
    "deltaR", f3(deltaR)],
    ["TL", f3(TL)], ["TK", f3(TK)], ["y2(geod.)", f3(y2)], [
    "x2(geod.)", f3(x2)], ["y3(geod.)", f3(y3)], ["x3(geod.)", f3(x3)],
    ["yM(geod.)", f3(yM)], ["xM(geod.)", f3(xM)]]
print("\nErgebnisse:")
print(tabulate.tabulate(d, headers=["\nElemente", " "]))

# ************************************************************************
# 74 *****
L2()
print("\n74  *****    Klothoide, normal")
L1()

print("\n\u2794 Aufruf: X, Y, R = ve.klothoide(A, L)")

print("\nErgebnisse:")

A = 5000
L = 2500
X, Y, R = ve.klothoide(A, L)
print("Klothoide: A, L, X, Y, R =\n", A, L, X, Y, R)

A = 100
L = 100
X, Y, R = ve.klothoide(A, L)
print("Klothoide: A, L, X, Y, R =\n", A, L, X, Y, R)

A = 260
L = 135.2
X, Y, R = ve.klothoide(A, L)
print("Klothoide: A, L, X, Y, R =\n", A, L, X, Y, R)
L1()

print("\nVariante 2\n\u2794 Aufruf: X, Y, R = ve.klothoide2(A, L)")

print("\nErgebnisse:")
A = 5000
L = 2500
X, Y, R = ve.klothoide2(A, L)
print("Klothoide2:  A, L, X, Y, R =\n", A, L, X, Y, R)

A = 100
L = 100
X, Y, R = ve.klothoide2(A, L)
print("Klothoide2:  A, L, X, Y, R =\n", A, L, X, Y, R)

A = 260
L = 135.2
X, Y, R = ve.klothoide2(A, L)
print("Klothoide2:  A, L, X, Y, R =\n", A, L, X, Y, R)
L1()

print("\nVariante 3\n\u2794 Aufruf: X, Y, R = ve.klothoide3(A, L)")
print("\nErgebnisse: Tschebyschow-Approximation")

A = 5000
L = 2500
X, Y, R = ve.klothoide3(A, L)
print("Klothoide3: Tschebyschow-Approximation A, L, X, Y, R =\n", A, L, X, Y, R)

A = 100
L = 100
X, Y, R = ve.klothoide3(A, L)
print("Klothoide3: Tschebyschow-Approximation A, L, X, Y, R =\n", A, L, X, Y, R)

A = 260
L = 135.2
X, Y, R = ve.klothoide3(A, L)
print("Klothoide3: Tschebyschow-Approximation A, L, X, Y, R =\n", A, L, X, Y, R)

# ************************************************************************
# 75   *****
L2()
print("\n75  *****    Klothoide, mit seitlichem Abstand")
L1()

print("\nBeispiel:\n\
  y1,x1 = 0, 0; t1 = 100; A = 100; L = 100; a = 10")

print("\n\u2794 Aufruf: y3, x3, y2, x2 = ve.klothoide4(y1, x1, t1, A, L, a)")

y1 = 0
x1 = 0
t1 = 100
A = 100
L = 100
a = 10

y3, x3, y2, x2 = ve.klothoide4(y1, x1, t1, A, L, a)
print("\nErgebnisse: y3, x3, y2, x2 = \n", y3, x3, "\n", y2, x2)

# ************************************************************************
# 76 *****
L2()
print("\n76 *****    Klothoide, Punktabstand (Inverse zu Nr. 75)")
L1()

print("\nBeispiel:\n\
  y1,x1 = 0, 0, t1 = 100, y3 = 102.3230, x3 = 7.595579\n\
  A = 100, L = 100")

print("\n\u2794 Aufruf: y2, x2, L, b = ve.klothoide5(y1, x1, t1, A, y3, x3")

y1 = 0
x1 = 0
y3 = 102.3230
x3 = 7.595579
t1 = 100
A = 100

y2, x2, L, a = ve.klothoide5(y1, x1, t1, A, y3, x3)
print("\nErgebnis:\nKlothoide, Fußpunkt, Abstand: y2, x2, L, a =",
      "\n", y2, x2, "\n", L, a)

# ************************************************************************
# 77 *****
L2()
print("\n77 *****    Schnitt Klothoide und Gerade")
L1()

print("\nBeispiel:\n\
  y1,x1 = 0, 0, t1 = 100, y4 = 50, x4 = 0, y5 = 50, x5 = 50, \n\
  yN = 50, xN = 0, A = 100, a = 10")

print("\n\u2794 Aufruf: yS, xS, yF, xF, L =\nve.klothoide_gerade(y1, x1, t1, A, a, y4, x4, y5, x5, yN, xN)")

y1 = 0
x1 = 0
y4 = 50
x4 = 50
y5 = 50
x5 = 0
yN = 50
xN = 0
t1 = 100
A = 100
a = 1

yS, xS, yF, xF, L = ve.klothoide_gerade(
    y1, x1, t1, A, a, y4, x4, y5, x5, yN, xN)
print(f"\nErgebnis:\nSchnittpunkt yS = {f3(yS)}, xS = {f3(xS)}, a = {f2(a)}")
print(f"Fußpunkt Klothoide: yF = {f3(yF)}, xF = {f3(xF)}, L = {f3(L)}")

# ************************************************************************
# 78, 79 *****
L2()
print("\n78, 79 *****    Schnitt Klothoide und Kreis")
L1()

print("\n1. Beispiel:\n\
  y1, x1 = 0, 0, t1 = 100, A = 100, a = -2, yM = 50.024, xM = 14.15,\n\
  R = 15, yN = 55, xN = 5 oder über 2 Kreispunkte und Radius")

print("\n\u2794 Aufruf:  yS, xS, yF, xF, L =\
\n ve.klothoide_kreis(y1, x1, t1, A, a, yM, xM, R, yN, xN)")

y1 = 0
x1 = 0
y4 = 65
x4 = 15
y5 = 55
x5 = 0
yN = 55
xN = 5
yM = 50.024
xM = 14.15
R = 15
t1 = 100
A = 100
a = -2

yS, xS, yF, xF, L = ve.klothoide_kreis(y1, x1, t1, A, a, yM, xM, R, yN, xN)
print(f"\nErgebnis:\nSchnittpunkt yS = {f3(yS)}, xS = {f3(xS)}")
print(f"Fußpunkt Klothoide: yF = {f3(yF)}, xF = {f3(xF)}")
print(f"    L = {f3(L)}, a = {f2(a)}")
L1()
print("\n2. Beispiel yN = 56, yN = 4")
print("\n\u2794 Aufruf:  yS, xS, yF, xF, L, yM, xM  =\
\n ve.klothoide_kreis(y1, x1, t1, A, a, y4, x4, y5, x5, yN, xN)")

yN = 56
xN = 4
yS, xS, yF, xF, L, yM, xM = ve.klothoide_kreis(
    y1, x1, t1, A, a, y4, x4, y5, x5, R, yN, xN)
print(f"\nErgebnis:\nSchnittpunkt yS = {f3(yS)}, xS = {f3(xS)}")
print(f"Fußpunkt Klothoide: yF = {f3(yF)}, xF = {f3(xF)}")
print(f"L = {f3(L)}, a = {f2(a)}, yM = {f3(yM)}, xM = {f2(xM)}")

# ************************************************************************
# 80 *****
L2()
print("\n80 *****    Schnitt Klothoide und Klothoide")
L1()

print("\nBeispiel:\n\
  y1, x1 = 0, 0; t1 = 100, A1 = 100, a1 = 2\n\
  y3, x3 = 1, 1; t2 = 101, A2 = 101, a2 = 2.5\n\
  yN, xN = 30, 0")

print("\n\u2794 Aufruf: yS, xS, y2, x2, L1, y4, x4, L2 =\
\n ve.klothoide_kreis(y1, x1, t1, A, a, y4, x4, y5, x5, yN, xN)")

y1, x1 = 0, 0
t1 = 100
A1 = 100
a1 = 2
y3, x3 = 1, 1
t2 = 101
A2 = 101
a2 = 2.5
yN, xN = 30, 0

yS, xS, y2, x2, L1, y4, x4, L2 = \
    ve.klothoide_klothoide(y1, x1, t1, A1, a1, y3, x3, t2, A2, a2, yN, xN)
print(f"\nErgebnis:\nSchnittpunkt yS = {f3(yS)}, xS = {f3(xS)}")
print("Fußpunkte der Klothoiden:")
print(f"y2 = {f3(y2)}, xF = {f3(x2)}, L1 = {f3(L1)}, a1 = {f2(a1)}")
print(f"y4 = {f3(y4)}, xF = {f3(x4)}, L2 = {f3(L2)}, a2 = {f2(a2)}")

# ************************************************************************



