#!/usr/bin/python 
# -*- coding: utf-8 -*-

# pyvermessung.py 
# für Vermessung und Kataster
# Version 1.02
#
# copyright  2024, Norbert Fuhrmann, 50169 Kerpen
# Version 1.02, 15.11.2024
# www.grenzuntersuchung.de

import sys
from tkinter import messagebox
import numpy as np
#from tabulate import tabulate
from sympy import symbols, Eq, sqrt, solve

# Vermessungstechnische Funktionen, Definitionen:
#
# y = Rechtswert, x = Hochwert (Vermessungstechnik)
# t = Richtungwinkel, von der x-Achse, rechtsläufig
#   0 < t < 100  1. Quadrant
# 100 < t < 200  2. Quadrant
# 200 < t < 300  3. Quadrant
# 300 < t < 400  4. Quadrant
# Vollkreis = 400 gon, alle Winkelangaben in gon

# Klothoiden im lokalen System
# x = x-Achse (Abszisse), y = y-Achse (Ordinate)

RHO = 200. / np.pi
EPSILON = 1e-5
INF = 1e8
MAX_ITER = 200


def fehler(u, v, w):
    dc = {
        0: " ",
        123: "orthogonal",
        4: "4 orthogonal4",
        5: "5 orthogonal5",
        6: "6 richtung1",
        7: "7 richtung2",
        607: "richtung",
        8: "8 richtung3",
        91011: "polar",
        12: "12 polar3",
        13: "13 lot1",
        1314: "lot",
        15: "15 lot3",
        16: "16 teilstrecken",
        17: "17 polarwinkel1",
        18: "18 polarwinkel2",
        19: "19 mittelsenkrechte",
        20: "20 transformation1",
        21: "21 transformation2",
        22: "22 geradenschnitt1",
        23: "23 geradenschnitt2",
        24: "24 geradenschnitt3",
        2224: "22, 24 geradenschnitt",
        222324: "22, 23, 24 geradenschnitt",
        25: "25 geradenausgleich",
        26: "26 parallel",
        27: "27 parallelschnit",
        28: "28 senkrechtschnitt",
        29: "29 senkrecht_parallel",
        30: "30 doppelt_senkrecht",
        31: "31 winkelhalbierende",
        32: "32 kreismitte",
        33: "33 kreis3punkte",
        3233: "32, 33 kreis",
        34: "34, 35 lot_kreis",
        36: "36 kreisbogen",
        37: "37 bogenteilung",
        34: "34, 35 lot_kreis",
        36: "36 kreisbogen",
        361: "ortho",
        37: "37 bogenteilung",
        38: "38 kreis_kreis",
        39: "39 bis 44 kreis_gerade",
        45: "45 richtung_kreis",
        46: "46 tangente1",
        47: "47 tangente1",
        48: "48 tangente2",
        49: "49 tangente3",
        50: "50 tangente4",
        51: "51 tangente5",
        52: "52 tangente6",
        53: "53 tangente7",
        54: "54 tangente8",
        55: "55 tangente9",
        56: "56 tangente10",
        57: "57 tangente11",
        58: "58 tangente12",
        59: "59 tangente13",
        60: "60 tangente14",
        61: "61 tangente15",
        62: "62 tangente16",
        63: "63 parallelkreis",
        64: "64 rueckwaertsschnitt (nach Collins)",
        641: "64 rueckwaertsschnitt (nach Cassini)",
        65: "64 segment",
        66: "66 segment",
        67: "67 flaeche",
        68: "68 flaeche2",
        69: "69 dreieck",
        70: "70 streckenreduktion",
        71: "71 streckeUTM",
        72: "72 streckeUTM",
        73: "73 klothoidenelemente",
        74: "74 klothoide",
        741: "klothoide2",
        742: "klothoide3",
        75: "75 klothoide4",
        76: "76 klothoide5",
        77: "77 klothoide_gerade",
        78: "78 klothoide_kreis",
        79: "79 klothoide_kreis",
        80: "80 klothoide_klothoide",
        81: "81 regula-falsi",
        82: "82regula-falsi",
        100: "Koordinaten des Anfangs- und Endpunktes identisch",
        101: "Keine Lösung",
        102: "Geradenschnitt, kein Kreis",
        103: "Keine Lösung, Kreispunkt links von der Tangente P1, P2",
        104: "Keine Lösung, Kreispunkt rechts von der Tangente P3, P4",
        105: "Keine Lösung, Eingabekoordinaten nicht plausibel",
        106: "Wurzel aus negativer Zahl",
        107: "Anzahl der Parameter nicht zulässig",
        108: "ev. Radien zu klein oder zu groß",
        109: "Kein Schnitt möglich",
        110: "Fehler im internem Programm",
        111: "Teilung nicht möglich, n \u2265 1",
        112: "Geraden parallel oder identisch",
        113: "Punkt auf der falschen Tangentenseite",
        114: "Tangenten passen nicht für eine Lösung zusammen",
        115: "Radien müssen gleiche Vorzeichen haben",
        116: "Radien müssen ungleiche Vorzeichen haben",
        117: "Nehme Programm-Nr. 55",
        118: "Nehme Programm-Nr. 56",
        119: "Geraden identisch",
        120: "Geraden parallel",
        121: "Punkt liegt auf der Tangente",
        122: "Punkt liegt innerhalb eines Kreises oder darauf"}
    messagebox.showerror('Fehler: Keine Lösung',
        'Funktion: ' + dc[u] + '\n' + dc[v] + '\n' + dc[w])

    #raise Exception("Fehler: Funktion: " + dc[u] + '\n' + dc[v] + '\n' + dc[w])
    sys.exit()


def f3(a):          # String mit 3 Stellen nach dem Komma
    b = str(round(a, 3))
    return b


def vorzeichen(a, b):   # Vorzeichen von b auf a übertragen
    if b > 0:
        a = abs(a)
    elif b < 0:
        a = -abs(a)
    else:
        a = 0
    return a


# Orthogonale Punkte

# 0 (intern)
# Richtungswinkel und Entfernung

def RichtEntf(y1, x1, y2, x2, fehlernummer):
    if y1 == y2 and x1 == x2:
        fehler(fehlernummer, 100, 0)
    dx = x2 - x1
    dy = y2 - y1
    s = np.sqrt(dx**2 + dy**2)
    t_gon = np.degrees(np.arctan2(dy, dx)) / 0.9
    if t_gon < 0:
        t_gon += 400
    return t_gon, s

# 1, 2, 3
# Rechter Winkel auf gerader Linie


def orthogonal(y1, x1, y2, x2, ayi, axi = 0, s = -INF):
    try:
        _, sger = RichtEntf(y1, x1, y2, x2, 123)
        if s == -INF:
            s = sger
        o = (y2 - y1) / s
        a = (x2 - x1) / s
        yi = y1 + o * axi + a * ayi
        xi = x1 + a * axi - o * ayi
        return yi, xi, sger
    except BaseException:
        fehler(123, 0, 0)

# 4
# Orthogonale Punkte auf gerader Linie ohne Fehlerverteilung über Array


def orthogonal4(koordinaten):
    try:
        s = np.sqrt((koordinaten[1] - koordinaten[4])**2 +
                    (koordinaten[2] - koordinaten[5])**2)
        koord1, _ = orthogonal5(koordinaten, s)
        return koord1
    except BaseException:
        fehler(4, 0, 0)

# 5
# Orthogonale Punkte auf gerader Linie mit Fehlerverteilung über Array


def orthogonal5(koordinaten, sgem):
    try:
        koord_array = np.array(koordinaten).reshape(-1, 3)
        anzahl = koord_array.shape[0]
        pktnr = koord_array[:, 0]
        y = koord_array[:, 1]
        x = koord_array[:, 2]
        ay = y.copy()
        ax = x.copy()
        ay[0] = 0
        ay[1] = 0
        ax[0] = 0
        ax[1] = sgem
        o = (y[1] - y[0]) / sgem
        a = (x[1] - x[0]) / sgem

        for i in range(2, anzahl):
            y[i] = y[0] + o * ax[i] + a * ay[i]
            x[i] = x[0] + a * ax[i] - o * ay[i]
        pktnr = pktnr.reshape(-1, 1)
        y = y.reshape(-1, 1)
        x = x.reshape(-1, 1)
        ay = ay.reshape(-1, 1)
        ax = ax.reshape(-1, 1)

        koord1 = np.hstack((pktnr, y, x, ay, ax))
        fs = np.sqrt((y[1] - y[0])**2 + (x[1] - x[0])**2) - sgem
        return koord1, fs
    except BaseException:
        fehler(5, 0, 0)

# Richtungswinkel und Entfernung


def richtung1(y1, x1, y2, x2):
    try:
        dy = y2 - y1
        dx = x2 - x1
        t_gon, s = richtung2(dy, dx)
        return t_gon, s
    except BaseException:
        fehler(6, 0, 0)

# 7
# Richtungswinkel aus Koordinatendifferenzen


def richtung2(dy, dx):
    try:
        s = np.hypot(dy, dx)
        t_gon = np.degrees(np.arctan2(dy, dx)) / 0.9
        if t_gon < 0:
            t_gon += 400
        return t_gon, s
    except BaseException:
        fehler(7, 0, 0)


# 6,7
# Richtungswinkel und Entfernung


def richtung(*args):
    try:
        if len(args) == 4:
            y1 = args[0]
            x1 = args[1]
            y2 = args[2]
            x2 = args[3]
            dy = y2 - y1
            dx = x2 - x1
        elif len(args) == 2:
            dy = args[0]
            dx = args[1]
        else:
            fehler(607, 107, 0)
        s = np.sqrt(dx**2 + dy**2)
        t_gon = np.degrees(np.arctan2(dy, dx)) / 0.9
        if t_gon < 0:
            t_gon += 400
        return t_gon, s
    except BaseException:
        fehler(607, 0, 0)


# 8
# Richtungsfunktionen


def richtung3(y1, x1, y2, x2, sgem):
    try:
        dy = y2 - y1
        dx = x2 - x1
        sger = np.sqrt(dy**2 + dx**2)
        sint = dy / sger
        cost = dx / sger
        massstab = sgem / sger
        return sint, cost, sger, massstab
    except BaseException:
        fehler(8, 0, 0)


def polar(*args):
    try:
        y1 = args[0]
        x1 = args[1]
        t1 = args[2]
        if len(args) == 4:
            axi = args[3]
            yi = y1 + axi * np.sin(t1 / RHO)
            xi = x1 + axi * np.cos(t1 / RHO)
            return yi, xi
        elif len(args) == 5:
            ayi = args[3]
            axi = args[4]
            alphai = 0
        elif len(args) == 6:
            alphai = args[3]
            ayi = args[4]
            axi = args[5]
        else:
            fehler(91011, 107, 0)
        t = t1 + alphai
        yF = y1 + axi * np.sin(t / RHO)
        xF = x1 + axi * np.cos(t / RHO)
        yi = yF + ayi * np.cos(t / RHO)
        xi = xF - ayi * np.sin(t / RHO)
        return yi, xi, yF, xF
    except BaseException:
        fehler(91011, 0, 0)


# 12 (Array)
# Polare Punkte mit Anschlusswinkel


def polar4(koordinaten, alpha0):
    try:
        polar_array = np.array(koordinaten).reshape(-1, 3)
        anzahl = polar_array.shape[0]
        pktnr = polar_array[:, 0]
        alphai = polar_array[:, 1]
        axi = polar_array[:, 2]
        y = alphai.copy()
        x = axi.copy()
        t1, s = richtung1(y[0], x[0], y[1], x[1])
        alphai[0] = 0
        alphai[1] = alpha0
        axi[0] = 0
        axi[1] = s
        for i in range(2, anzahl):
            y[i] = y[0] + axi[i] * np.sin((t1 + (alphai[i] - alpha0)) / RHO)
            x[i] = x[0] + axi[i] * np.cos((t1 + (alphai[i] - alpha0)) / RHO)

        pktnr = pktnr.reshape(-1, 1)
        y = y.reshape(-1, 1)
        x = x.reshape(-1, 1)
        alphai = alphai.reshape(-1, 1)
        alphai0 = alphai.copy() - alpha0
        alphai0[0] = 0
        axi = axi.reshape(-1, 1)
        koord2 = np.hstack((pktnr, y, x, alphai, alphai0, axi))
        return koord2
    except BaseException:
        fehler(12, 0, 0)

# 13, 14
# Abstand, Lot von einer Richtung


def lot(y1, x1, y2, x2, yi, xi = -INF):
    try:
        if xi == -INF:
            t1 = y2
            xi = yi
            yi = x2
        else:
            t1, _ = RichtEntf(y1, x1, y2, x2, 1314)
        ti, s = richtung1(y1, x1, yi, xi)
        ayi = s * np.sin((ti - t1) / RHO)
        axi = s * np.cos((ti - t1) / RHO)
        yisp, xisp, yF, xF = polar(y1, x1, t1, -ayi, axi)
        return yF, xF, ayi, axi, yisp, xisp
    except BaseException:
        fehler(1314, 0, 0)

# 13 (intern)
# Abstand, Lot von einer Richtung


def lot1(y1, x1, t1, yi, xi):
    try:
        ti, s = richtung1(y1, x1, yi, xi)
        ayi = s * np.sin((ti - t1) / RHO)
        axi = s * np.cos((ti - t1) / RHO)
        yF = y1 + axi * np.sin(t1 / RHO)
        xF = x1 + axi * np.cos(t1 / RHO)
        return yF, xF, ayi, axi
    except BaseException:
        fehler(13, 110, 0)

# 13 (intern)
# Abstand, Lot von einer Richtung


def lot2(y1, x1, t1, yi, xi):
    try:
        ti, s = richtung1(y1, x1, yi, xi)
        ayi = s * np.sin((ti - t1) / RHO)
        return ayi
    except BaseException:
        fehler(13, 110, 0)

# 15 (Array)
# Abstand, Lot, Lotfußpunkte (Über array)


def lot3(koordinaten):
    try:
        koord_array = np.array(koordinaten).reshape(-1, 3)
        anzahl = koord_array.shape[0]
        pktnr = koord_array[:, 0]
        y = koord_array[:, 1]
        x = koord_array[:, 2]

        ay = x.copy()
        ax = x.copy()
        yF = x.copy()
        xF = x.copy()
        t1, s = richtung1(y[0], x[0], y[1], x[1])
        ay[0] = 0
        ay[1] = 0
        ax[0] = 0
        ax[1] = s
        for i in range(2, anzahl):
            ti, si = richtung1(y[0], x[0], y[i], x[i])
            ay[i] = si * np.sin((ti - t1) / RHO)
            ax[i] = si * np.cos((ti - t1) / RHO)
            yF[i] = y[0] + ax[i] * np.sin(t1 / RHO)
            xF[i] = x[0] + ax[i] * np.cos(t1 / RHO)
        pktnr = pktnr.reshape(-1, 1)
        y = y.reshape(-1, 1)
        x = x.reshape(-1, 1)
        yF = yF.reshape(-1, 1)
        xF = xF.reshape(-1, 1)
        ay = ay.reshape(-1, 1)
        ax = ax.reshape(-1, 1)
        koord3 = np.hstack((pktnr, y, x, yF, xF, ay, ax))
        return koord3
    except BaseException:
        fehler(15, 0, 0)

# 16
# Strecke teilen


def teilstrecken(y1, x1, y2, x2, n):
    try:
        if n < 1:
            fehler(16, 111, 0)
        if y1 == y2 and x1 == x2:
            fehler(16, 100, 0)
        t1, sger = RichtEntf(y1, x1, y2, x2, 16)
        si = sger / (n + 1)
        A = np.empty([n + 2, 5])
        pktnr = A[:, 0]
        y = A[:, 1]
        x = A[:, 2]
        ay = A[:, 3]
        ax = A[:, 4]
        pktnr[0] = 1
        pktnr[1] = 2
        y[0] = y1
        y[1] = y2
        x[0] = x1
        x[1] = x2
        ay[0] = 0
        ay[1] = 0
        ax[0] = 0
        ax[1] = sger
        for i in range(n):
            y[i + 2] = y1 + (i + 1) * si * np.sin(t1 / RHO)  # yi
            x[i + 2] = x1 + (i + 1) * si * np.cos(t1 / RHO)  # xi
            ay[i + 2] = 0
            ax[i + 2] = (i + 1) * si
            pktnr[i + 2] = i + 3
        pktnr = pktnr.reshape(-1, 1)
        y = y.reshape(-1, 1)
        x = x.reshape(-1, 1)
        ay = ay.reshape(-1, 1)
        ax = ax.reshape(-1, 1)

        koord4 = np.hstack((pktnr, y, x, ay, ax))
        return koord4, si, sger
    except BaseException:
        fehler(16, 0, 0)

# 17
# Polarwinkel


def polarwinkel1(y1, x1, y2, x2, y3, x3):
    try:
        if y1 == y2 and x1 == x2:
            fehler(17, 100, 0)
        t2, s2 = richtung1(y1, x1, y2, x2)
        t3, s3 = richtung1(y1, x1, y3, x3)
        alpha = t3 - t2
        if alpha < 0:
            alpha += 400
        return t2, s2, alpha, s3
    except BaseException:
        fehler(17, 0, 0)

# 18 (Array)
# Polarwinkel


def polarwinkel2(koordinaten):
    try:
        koord_array = np.array(koordinaten).reshape(-1, 3)
        anzahl = koord_array.shape[0]
        pktnr = koord_array[:, 0]
        y = koord_array[:, 1]
        x = koord_array[:, 2]
        t = y.copy()
        alpha = y.copy()
        s = y.copy()
        t2, s2 = richtung1(y[0], x[0], y[1], x[1])
        t[0] = 0
        alpha[0] = 0
        s[0] = 0
        t[1] = t2
        alpha[1] = 0
        s[1] = s2
        for i in range(2, anzahl):
            t[i], s[i] = richtung1(y[0], x[0], y[i], x[i])
            alpha[i] = t[i] - t2
            if alpha[i] < 0:
                alpha[i] += 400.
        pktnr = pktnr.reshape(-1, 1)
        y = y.reshape(-1, 1)
        x = x.reshape(-1, 1)
        t = t.reshape(-1, 1)
        alpha = alpha.reshape(-1, 1)
        s = s.reshape(-1, 1)

        koord5 = np.hstack((pktnr, y, x, t, alpha, s))
        return koord5
    except BaseException:
        fehler(18, 0, 0)

# 19
# Strecke halbieren, Mittelsenkrechte


def mittelsenkrechte(y1, x1, y2, x2):
    try:
        tM, s = RichtEntf(y1, x1, y2, x2, 19)
        yM = (y1 + y2) / 2
        xM = (x1 + x2) / 2
        tM += 100
        if tM > 400:
            tM -= 400
        return yM, xM, tM, s / 2  # entspricht sM
    except BaseException:
        fehler(19, 0, 0)

# 20
#  Transformation


def transformation1(yA, xA, yE, xE, ayA, axA, ayE, axE, ayi, axi):
    try:
        _, s = RichtEntf(yA, xA, yE, xE, 20)
        _, sa = RichtEntf(ayA, axA, ayE, axE, 20)
        fs = s - sa
        p = ((axE - axA) * (yE - yA) - (ayE - ayA) * (xE - xA)) / sa / sa
        q = ((ayE - ayA) * (yE - yA) + (axE - axA) * (xE - xA)) / sa / sa
        yi = yA + p * (axi - axA) + q * (ayi - ayA)
        xi = xA + q * (axi - axA) - p * (ayi - ayA)
        return yi, xi, fs
    except BaseException:
        fehler(20, 0, 0)

# 21
#  Transformation  array


def transformation2(transkoordinaten):
    try:
        koord_array = np.array(transkoordinaten).reshape(-1, 5)
        anzahl = koord_array.shape[0]
        pktnr = koord_array[:, 0]
        y = koord_array[:, 1]
        x = koord_array[:, 2]
        ay = koord_array[:, 3]
        ax = koord_array[:, 4]
        sa = np.hypot(ay[1] - ay[0], ax[1] - ax[0])
        s = np.hypot(y[1] - y[0], x[1] - x[0])
        fs = s - sa
        p = ((ax[1] - ax[0]) * (y[1] - y[0]) -
             (ay[1] - ay[0]) * (x[1] - x[0])) / sa / sa
        q = ((ay[1] - ay[0]) * (y[1] - y[0]) +
             (ax[1] - ax[0]) * (x[1] - x[0])) / sa / sa
        for i in range(2, anzahl):
            y[i] = y[0] + p * (ax[i] - ax[0]) + q * (ay[i] - ay[0])
            x[i] = x[0] + q * (ax[i] - ax[0]) - p * (ay[i] - ay[0])

        pktnr = pktnr.reshape(-1, 1)
        y = y.reshape(-1, 1)
        x = x.reshape(-1, 1)
        ay = ay.reshape(-1, 1)
        ax = ax.reshape(-1, 1)
        koord6 = np.hstack((pktnr, y, x, ay, ax))
        return koord6, fs
    except BaseException:
        fehler(21, 0, 0)

# Geradenschnitte

# 22, 23, 24
# Einfacher Geradenschnitt mit alpha


def geradenschnitt(y1, x1, y2, x2, y3, x3, y4 = -INF, x4 = -INF):
    try:
        t1, _ = RichtEntf(y1, x1, y2, x2, 2223)
        t1 /= RHO
        if y4 == -INF and x4 == -INF:
            t1 = y2 / RHO
            t3 = x3 / RHO
            x3 = y3
            y3 = x2
        elif x4 == -INF:
            t3 = y4 / RHO
        else:
            t3 = np.arctan2(y4 - y3, x4 - x3)
        p1 = np.array([y1, x1])
        p2 = np.array([y3, x3])
        A = np.array([[np.sin(t1), -np.sin(t3)], [np.cos(t1), -np.cos(t3)]])
        p2 = p2 - p1
        s1, _ = np.linalg.solve(A, p2)
        yS = y1 + s1 * np.sin(t1)
        xS = x1 + s1 * np.cos(t1)
        alpha = (t3 - t1) * RHO
        if alpha < 0:
            alpha += 400.
        elif alpha == 0 or alpha == 200:
            fehler(222324, 109, 112)
        return yS, xS, alpha
    except BaseException:
        fehler(222324, 109, 112)

# 22 (intern)
# Einfacher Geradenschnitt


def geradenschnitt1(y1, x1, y2, x2, y3, x3, y4, x4):
    try:
        p1 = np.array([y1, x1])
        u1 = np.array([y2 - y1, x2 - x1])
        p2 = np.array([y3, x3])
        u2 = np.array([y4 - y3, x4 - x3])
        kreuzprodukt = np.cross(u1, u2)
        if np.isclose(kreuzprodukt, 0):
            fehler(22, 109, 112)
        A = np.array([[u1[0], u2[0]], [u1[1], u2[1]]])
        p2 = p2 - p1
        t, s = np.linalg.solve(A, p2)
        s = p1 + t * u1
        return s[0], s[1]
    except BaseException:
        fehler(22, 109, 112)

# 23
# Geradenschnitt über zwei Richtungswinkel


def geradenschnitt2(y1, x1, t1, y3, x3, t3):
    try:
        if t1-t3 == 0 or t1-t3 == 200 or t1-t3 == -200:
            fehler(23, 109, 112)
        t1 /= RHO
        t3 /= RHO

        a = np.array([y1, x1])
        b = np.array([y3, x3])
        A = np.array([[np.sin(t1), -np.sin(t3)], [np.cos(t1), -np.cos(t3)]])
        b = b - a
        s1, s3 = np.linalg.solve(A, b)
        yS = y1 + s1 * np.sin(t1)
        xS = x1 + s1 * np.cos(t1)
        return yS, xS
    except:
        fehler(23, 0, 0)

# 25 (Array)
# Geradenausgleich


def geradenausgleich(koordinaten):
    try:
        koord_array = np.array(koordinaten).reshape(-1, 3)
        pktnr = koord_array[:, 0]
        y = koord_array[:, 1]
        x = koord_array[:, 2]
        steigung, schnittpunkt = np.polyfit(y, x, 1)
        # geradengleichung = f'y = {steigung}x + {schnittpunkt}'
        ya = 0
        xa = schnittpunkt
        ye = 1000
        xe = steigung * 1000 + schnittpunkt

        pp = [0, 0]
        yy = [ya, ye]
        xx = [xa, xe]

        ppp = np.hstack((pp, pktnr))
        yyy = np.hstack((yy, y))
        xxx = np.hstack((xx, x))
        koordinaten = np.vstack((ppp, yyy, xxx))
        koordinaten = koordinaten.T

        koord7 = lot3(koordinaten)
        koord7 = koord7[2:, :]

        anfang = koord7[0, 6]
        koord7[:, 6] -= anfang
        return koord7
    except BaseException:
        fehler(25, 0, 0)

# 26
# Parallele zur Geraden


def parallel(y1, x1, y2, x2, a):
    try:
        _, _ = RichtEntf(y1, x1, y2, x2, 26)
        y11, x11, sger = orthogonal(y1, x1, y2, x2, a)
        y21, x21, _ = orthogonal(y2, x2, y1, x1, -a)
        return y11, x11, y21, x21, sger
    except BaseException:
        fehler(26, 0, 0)

# 27
# Parallelschnitt


def parallelschnitt(y1, x1, y2, x2, a1, y3, x3, y4, x4, a3):
    try:
        yy1, xx1, yy2, xx2, _ = parallel(y1, x1, y2, x2, a1)
        yy3, xx3, yy4, xx4, _ = parallel(y3, x3, y4, x4, a3)
        yS, xS, alpha = geradenschnitt(yy1, xx1, yy2, xx2, yy3, xx3, yy4, xx4)
        return yS, xS, alpha
    except BaseException:
        fehler(27, 0, 0)

# 28
# Senkrechtschnitt


def senkrechtschnitt(y1, x1, y2, x2, yi, xi):
    try:
        _, _ = RichtEntf(y1, x1, y2, x2, 28)
        a2 = [y2 - y1, x2 - x1]
        ap = [yi - y1, xi - x1]
        a2_ = a2[0] * a2[0] + a2[1] * a2[1]
        zwi1 = (ap[0] * a2[0] + ap[1] * a2[1]) / a2_
        yS = y1 + zwi1 * a2[0]
        xS = x1 + zwi1 * a2[1]
        return yS, xS
    except BaseException:
        fehler(28, 0, 0)

# 29
# Senkrecht-Parallelschnitt


def senkrecht_parallel(y1, x1, y2, x2, y3, x3, y4, x4, yi, xi, a):
    try:
        _, _ = RichtEntf(y1, x1, y2, x2, 29)
        y31, x31, y41, x41, _ = parallel(y3, x3, y4, x4, a)
        yF, xF = senkrechtschnitt(y1, x1, y2, x2, yi, xi)
        yS, xS = geradenschnitt1(yi, xi, yF, xF, y31, x31, y41, x41)
        return yS, xS
    except BaseException:
        fehler(29, 0, 0)

# 30
# Doppelter Senkrechtschnitt


def doppelt_senkrecht(y1, x1, y2, x2, yi, xi, y3, x3, y4, x4, yj, xj):
    try:
        ti, _ = RichtEntf(y1, x1, y2, x2, 30)
        tj, _ = RichtEntf(y3, x3, y4, x4, 30)
        ti += 100
        tj += 100
        yS, xS, _ = geradenschnitt(yi, xi, ti, yj, xj, tj)
        return yS, xS
    except BaseException:
        fehler(30, 0, 0)

# 31
# Winkelhalbierende


def winkelhalbierende(y1, x1, y2, x2, y3, x3, y4, x4):
    try:
        t1, _ = RichtEntf(y2, x2, y1, x1, 31)
        t2, _ = RichtEntf(y4, x4, y3, x3, 31)
        yS, xS = geradenschnitt1(y1, x1, y2, x2, y3, x3, y4, x4)
        alpha = t1 - t2
        tS = (t1 + t2) / 2
        if tS > 400.:
            tS -= 400.
        return yS, xS, tS, alpha
    except BaseException:
        fehler(31, 0, 0)

# 32 (intern)
# Kreismittelpunkt


def kreismitte(y1, x1, y2, x2, R):
    try:
        _, s = RichtEntf(y2, x2, y1, x1, 32)
        h = np.sqrt(R * R - s * s / 4)
        if np.isnan(h):
            fehler(32, 106, 0)
        if R > 0:
            yM = (y1 + y2) / 2 + (x2 - x1) * h / s
            xM = (x1 + x2) / 2 - (y2 - y1) * h / s
        else:
            yM = (y1 + y2) / 2 - (x2 - x1) * h / s
            xM = (x1 + x2) / 2 + (y2 - y1) * h / s
        return yM, xM
    except BaseException:
        fehler(32, 0, 0)

# 33 (intern)
# Kreis durch 3 Punkte


def kreis3punkte(y1, x1, y2, x2, y3, x3):
    try:
        _, _ = RichtEntf(y1, x1, y2, x2, 33)
        _, _ = RichtEntf(y1, x1, y3, x3, 33)
        _, _ = RichtEntf(y2, x2, y3, x3, 33)
        yi = (y1 + y2) / 2
        xi = (x1 + x2) / 2
        yj = (y3 + y2) / 2
        xj = (x3 + x2) / 2
        yM, xM = doppelt_senkrecht(
            y1, x1, y2, x2, yi, xi, y2, x2, y3, x3, yj, xj)
        R = np.hypot(yM - y1, xM - x1)
        _, _, ay2, _, _, _ = lot(
            y3, x3, y1, x1, y2, x2)  # Tausch
        R = vorzeichen(R, ay2)
        return yM, xM, R
    except BaseException:
        fehler(33, 0, 0)

# 32, 33
# Kreismittelpunkt


def kreis(*args):
    try:
        y1 = args[0]
        x1 = args[1]
        y2 = args[2]
        x2 = args[3]
        if len(args) == 5:
            R = args[4]
            yM, xM = kreismitte(y1, x1, y2, x2, R)
            return yM, xM
        if len(args) == 6:
            y3 = args[4]
            x3 = args[5]
            yM, xM, R = kreis3punkte(y1, x1, y2, x2, y3, x3)
            return yM, xM, R
    except BaseException:
        fehler(3233, 0, 0)

# 34, 35
# Lot auf Kreis


def lot_kreis(y1, x1, y2, x2, y3, x3, y4, x4 = -INF):
    try:
        if x4 == -INF:
            R = np.absolute(y4)
            yM, xM = kreis(y1, x1, y2, x2, R)
            yF, xF, _ = orthogonal(yM, xM, y3, x3, 0, R)
            d = R - np.hypot(yM - y3, xM - x3)
            return yF, xF, d
        else:
            yM, xM, R = kreis(y1, x1, y2, x2, y3, x3)
            yF, xF, _ = orthogonal(yM, xM, y4, x4, 0, np.absolute(R))

            d = np.absolute(R) - np.hypot(yM - y4, xM - x4)

            return yF, xF, d, yM, xM, R
    except BaseException:
        fehler(3435, 0, 0)

# 36
# Kreisbogen


def kreisbogen(y1, x1, y2, x2, R):
    try:
        _, s = RichtEntf(y1, x1, y2, x2, 36)
        h = np.sqrt(R**2 - (s / 2)**2)
        if np.isnan(h):
            fehler(36, 106, 0)
        yM, xM, _ = orthogonal(y1, x1, y2, x2, -h, s / 2)
        alpha_halbe_bogen = np.arcsin(s / 2 / R)
        t = np.tan(alpha_halbe_bogen) * R
        yT, xT, _ = orthogonal(y1, x1, yM, xM, t)
        b = 2 * alpha_halbe_bogen * R
        alpha = 2 * alpha_halbe_bogen * RHO
        return yM, xM, yT, xT, t, s, b, alpha
    except BaseException:
        fehler(36, 0, 0)


def ortho(dye, dxe, dyi, dxi):   # einfache Projektion
    try:
        re, se = richtung2(dye, dxe)
        ri, si = richtung2(dyi, dxi)
        wigon = ri - re
        hi = np.sin(wigon * np.pi / 200.) * si
        ji = np.cos(wigon * np.pi / 200.) * si
        return hi, ji, se
    except BaseException:
        fehler(36, 0, 0)

# 37
#  Bogenteilung


def bogenteilung(y1, x1, y2, x2, R, n):
    try:
        _, _ = RichtEntf(y1, x1, y2, x2, 37)
        yM, xM, _, _, _, s, b, _ = kreisbogen(y1, x1, y2, x2, R)
        teilbogen = b / (n + 1)
        t1, _ = richtung1(yM, xM, y1, x1)
        elemente = np.empty([n + 2, 4])
        for i in range(n + 1):
            elemente[i, 0] = yM + R * \
                np.sin(t1 / RHO - i * teilbogen / R)  # yi
            elemente[i, 1] = xM + R * \
                np.cos(t1 / RHO - i * teilbogen / R)  # xi
            elemente[i, 2], elemente[i, 3], _ = ortho(
                y2 - y1, x2 - x1, elemente[i, 0] - y1, elemente[i, 1] - x1)
        elemente[n + 1, 0] = y2
        elemente[n + 1, 1] = x2
        elemente[n + 1, 2] = 0
        elemente[n + 1, 3] = s
        elemente[0, 0] = y1
        elemente[0, 1] = x1
        elemente[0, 2] = 0
        elemente[0, 3] = 0

        si = np.hypot(elemente[0, 0] - elemente[1, 0],
                      elemente[0, 1] - elemente[1, 1])
        return yM, xM, si, teilbogen, elemente
    except BaseException:
        fehler(37, 0, 0)

# 38
# Kreisbogenschnitt


def kreis_kreis(y1, x1, R1, y2, x2, R2):
    try:
        t12, c = RichtEntf(y1, x1, y2, x2, 38)
        if R1 > R2:
            s2 = (c * c - R1 * R1 + R2 * R2) / (2 * c)
            s1 = c - s2
            a = R1 * R1 - s1 * s1
        else:
            s1 = (c * c - R2 * R2 + R1 * R1) / (2 * c)
            s2 = c - s1
            a = R2 * R2 - s2 * s2
        a = np.sqrt(a)
        if np.isnan(a):
            fehler(38, 106, 108)
        alpha = np.arctan2(a, s1) * RHO
        beta = np.arctan2(a, s2) * RHO
        bogenschnitt = True
    except BaseException:
        fehler(38, 0, 0)

    if bogenschnitt:
        t1S = t12 + alpha
        if t1S >= 400.:
            t1S -= 400.
        t2S = t12 + 200. - beta
        if t2S < 0.:
            t2S += 400.
        if t2S == 0.:
            pass
        elif t2S >= 400.:
            t2S -= 400.
        yF = y2 + (y1 - y2) * s2 / c
        xF = x2 + (x1 - x2) * s2 / c
        yS = yF - (x1 - x2) * a / c
        xS = xF + (y1 - y2) * a / c
        return (yS, xS, yF, xF, s1, s2, a)

# 39 bis 44
# Kreisgeradenschnitt


def kreis_gerade(*args):
    try:
        y1 = args[0]
        x1 = args[1]
        y2 = args[2]
        x2 = args[3]
        y3 = args[4]
        x3 = args[5]
        if len(args) > 6 and len(args) < 12:
            t1, _ = richtung1(y1, x1, y2, x2)
        if len(args) == 6:
            t1 = y2
            yM = x2
            xM = y3
            R = x3
            yF, xF, h, _ = lot1(y1, x1, t1, yM, xM)
            s = np.sqrt(R * R - h * h)
            if np.isnan(s):
                fehler(39, 106, 0)
            yS, xS = polar(yF, xF, t1, s)
            return yS, xS
        elif len(args) == 7:
            yM = y3
            xM = x3
            R = args[6]
            yF, xF, h, _, _, _ = lot(y1, x1, y2, x2, yM, xM)
            s = np.sqrt(R * R - h * h)
            if np.isnan(s):
                fehler(39, 106, 0)
            yS, xS = polar(yF, xF, t1, s)
            return yS, xS
        elif len(args) == 8:
            R = args[6]
            a = args[7]
            yM = y3
            xM = x3
            y11, x11, y21, x21, _ = parallel(y1, x1, y2, x2, a)
            yF, xF, h, _, _, _ = lot(y11, x11, y21, x21, yM, xM)
            s = np.sqrt(R * R - h * h)
            if np.isnan(s):
                fehler(39, 106, 0)
            yS, xS = polar(yF, xF, t1, s)
            return yS, xS
        elif len(args) == 9:
            y4 = args[6]
            x4 = args[7]
            R = args[8]
            yM, xM = kreis(y3, x3, y4, x4, R)
            yF, xF, h, _, _, _ = lot(y1, x1, y2, x2, yM, xM)
            s = np.sqrt(R * R - h * h)
            if np.isnan(s):
                fehler(39, 106, 0)
            yS, xS = polar(yF, xF, t1, s)
            return yS, xS, yM, xM
        elif len(args) == 10:
            y4 = args[6]
            x4 = args[7]
            R = args[8]
            a = args[9]
            yM, xM = kreis(y3, x3, y4, x4, R)
            y11, x11, y21, x21, _ = parallel(y1, x1, y2, x2, a)
            yF, xF, h, _, _, _ = lot(y11, x11, y21, x21, yM, xM)
            s = np.sqrt(R * R - h * h)
            if np.isnan(s):
                fehler(39, 106, 0)
            yS, xS = polar(yF, xF, t1, s)
            return yS, xS, yM, xM
        elif len(args) == 11:
            y4 = args[6]
            x4 = args[7]
            y5 = args[8]
            x5 = args[9]
            a = args[10]
            yM, xM, R = kreis(y3, x3, y4, x4, y5, x5)
            y11, x11, y21, x21, _ = parallel(y1, x1, y2, x2, a)
            yF, xF, h, _, _, _ = lot(y11, x11, y21, x21, yM, xM)
            s = np.sqrt(R * R - h * h)
            if np.isnan(s):
                fehler(39, 106, 0)
            yS, xS = polar(yF, xF, t1, s)
            return yS, xS, yM, xM, R
        else:
            fehler(39, 107, 0)
    except BaseException:
        fehler(39, 0, 0)

# 45
#  Senkrechtschnitt  Kreis


def senkrecht_kreis(y1, x1, y2, x2, yM, xM, R):
    try:
        t1, _ = RichtEntf(y1, x1, y2, x2, 45)
        yS, xS = kreis_gerade(y2, x2, t1 + 100, yM, xM, R)
        return yS, xS
    except BaseException:
        fehler(45, 0, 0)

# 46, 47
#  bewegliche Tangente und Kreismittelpunkt und Radius


def tangente1(*args):
    try:
        y1 = args[0]
        x1 = args[1]
        if len(args) == 5:
            yM = args[2]
            xM = args[3]
            R = args[4]
        elif len(args) == 7:
            y3 = args[2]
            x3 = args[3]
            y4 = args[4]
            x4 = args[5]
            R = args[6]
            yM, xM = kreis(y3, x3, y4, x4, R)
        else:
            fehler(46, 0, 0)
        t1M, s = richtung1(y1, x1, yM, xM)  # Bedingung r < s
        t = np.sqrt(s**2 - R**2)
        if np.isnan(t):
            fehler(46, 106, 0)
        alpha = np.arcsin(R / s) * RHO
        t1T = t1M - alpha  # für +R, -R
        yT, xT = polar(y1, x1, t1T, t)
        if len(args) == 5:
            return yT, xT, t
        if len(args) == 7:
            return yT, xT, t, yM, xM
    except BaseException:
        fehler(46, 0, 0)

# 48
#  feste, tangentiale Gerade und 2 Kreispunkte


def tangente2(y1, x1, y2, x2, y3, x3, y4, x4):
    try:
        _, _, ay3, _, _, _ = lot(y1, x1, y2, x2, y3, x3)
        _, _, ay4, _, _, _ = lot(y1, x1, y2, x2, y4, x4)
        if ay3 * ay4 < 0:
            fehler(48, 0, 0)
        if np.absolute(ay3) > np.absolute(ay4):
            fehler(48, 0, 0)
        y34, x34, tM, _ = mittelsenkrechte(y3, x3, y4, x4)
        if ay3 < 0 and ay4 < 0:
            tM += 200
        t1, _ = richtung1(y1, x1, y2, x2)
        t2 = t1 + 100
        yW, xW = geradenschnitt2(y3, x3, t2, y34, x34, tM)

        # a1 = np.absolute(lot2(y1, x1, t1, yW + x * np.sin(tM/RHO), xW + x * np.cos(tM/RHO)))
        # a2 = np.hypot(y4 - (yW + x * np.sin(tM/RHO)), x4 - (xW + x * np.cos(tM/RHO)))
        # DiffFunc = lambda x: a1 - a2 (für die Bestimmung der Nullstelle, Soll a1 = a2 = R

        def DiffFunc(x): return np.absolute(lot2(y1, x1, t1, yW +
            x * np.sin(tM/RHO), xW + x * np.cos(tM/RHO))) - \
            np.hypot((y4 - yW - x * np.sin(tM/RHO)),(x4 - xW - x * np.cos(tM/RHO)))
        # RechteS = 0   # 2. Lösung
        # LinkeS = -1
        # while DiffFunc(LinkeS)<0:
        #    RechteS = LinkeS
        #    LinkeS *=2

        RechteS = 0.1
        LinkeS = 0
        while DiffFunc(RechteS) < 0:
            LinkeS = RechteS
            RechteS *= 2

        x = regula_falsi_nullstelle(DiffFunc, LinkeS, RechteS)

        yM, xM = polar(yW, xW, tM, x)
        yT, xT, R, t = lot1(y1, x1, t1, yM, xM)

        return yT, xT, t, yM, xM, R
    except BaseException:
        fehler(48, 0, 0)


# 49
#  bewegliche Tangente und 3 Kreispunkte


def tangente3(y1, x1, y3, x3, y4, x4, y5, x5):
    try:
        yM, xM, R = kreis(y3, x3, y4, x4, y5, x5)  # +R Rechtskurve, -R Links
        s = np.hypot(yM - y1, xM - x1)
        t = np.sqrt(s**2 - R**2)
        if np.isnan(t):
            fehler(49, 106, 0)
        h = t * R / s
        p = t**2 / s
        yT, xT, _ = orthogonal(y1, x1, yM, xM, -h, p)
        return yT, xT, t, yM, xM, R
    except BaseException:
        fehler(49, 0, 0)

# 50
#  feste, tangentiale Gerade und Kreispunkt, Radius


def tangente4(y1, x1, y2, x2, y3, x3, R):
    try:
        yM, xM = kreis_gerade(y2, x2, y1, x1, y3, x3, R, -R)
        yT, xT = senkrechtschnitt(y1, x1, y2, x2, yM, xM)
        t = np.hypot(yT - y1, xT - x1)
        return yT, xT, t, yM, xM
    except BaseException:
        fehler(50, 0, 0)

# 51
#  Tangenten mit festen Längen und feste, tangentiale Gerade


def tangente5(y1, x1, y2, x2, y3, x3, y5, x5, links = INF):
    try:
        _, _, a2, _, _, _ = lot(y5, x5, y3, x3, y2, x2)
        if a2 == 0:
            return fehler(51, 102, 0)
        if a2 > 0:
            return fehler(51, 101, 0)
        if links == -1:
            ys, xs, ts, _ = winkelhalbierende(y3, x3, y5, x5, y1, x1, y2, x2,)
        else:
            ys, xs, ts, _ = winkelhalbierende(y1, x1, y2, x2, y5, x5, y3, x3)
        t2, _ = richtung1(y2, x2, y1, x1)

        yM, xM, _ = geradenschnitt(y2, x2, (t2 - 100), ys, xs, ts)
        R = np.hypot((y2 - yM), (x2 - xM))
        y4, x4, R1, _, _, _ = lot(y3, x3, y5, x5, yM, xM)
        if links == -1:
            R = -R
            R1 = -R1
        return y4, x4, yM, xM, R, R1
    except BaseException:
        fehler(51, 0, 0)


# 52
#  Kreis, 3 feste, tangentiale Geraden


def tangente6(y1, x1, y2, x2, y3, x3, y4, x4, y5, x5, y6, x6):
    try:

        _, _, ayunten, _, _, _ = lot(y1, x1, y2, x2, y3, x3)
        _, _, ayoben, _, _, _ = lot(y1, x1, y2, x2, y4, x4)

        if np.absolute(ayunten) < EPSILON and np.absolute(ayoben) < EPSILON:
            fehler(51, 112, 0)
        elif np.absolute(np.absolute(ayunten) - np.absolute(ayoben)) < EPSILON:
            R =  np.absolute(ayunten) / 2
        else:
            yS, xS, tS, _ = winkelhalbierende(y1, x1, y2, x2, y3, x3, y4, x4)
            t56, _ = richtung1(y5, x5, y6, x6)
            ays = lot2(y5, x5, t56, yS, xS)
            if ays > 0:
                fehler(52, 114, 0)
            yA, xA = geradenschnitt1(y1, x1, y2, x2, y5, x5, y6, x6)
            yB, xB = geradenschnitt1(y5, x5, y6, x6, y3, x3, y4, x4)
            _, a = richtung1(yB, xB, yS, xS)
            _, b = richtung1(yA, xA, yS, xS)
            _, c = richtung1(yA, xA, yB, xB)
            s = (a + b + c) / 2
            R = np.sqrt(s * (s - a) * (s - b) * (s - c)) / (s - c)
    
        yM, xM, _ = parallelschnitt(y1, x1, y2, x2, R, y5, x5, y6, x6, R)
        yT1, xT1, _, t1, _, _ = lot(y1, x1, y2, x2, yM, xM)
        yT2, xT2, R1, t2, _, _ = lot(y3, x3, y4, x4, yM, xM)
        yT3, xT3, _, t3, _, _ = lot(y5, x5, y6, x6, yM, xM)
        return yT1, xT1, yT2, xT2, yT3, xT3, yM, xM, t1, t2, t3, R, R1
    except BaseException:
        fehler(52, 0, 0)

        
# 53
#  2 feste, tangentiale Geraden und 1 Kreispunkt


def tangente7(y1, x1, y2, x2, y3, x3, y4, x4, y5, x5):
    try:
        _, _, ay5, _, _, _ = lot(y1, x1, y2, x2, y5, x5)
        if ay5 < 0:
            fehler(53, 103, 0)
        _, _, ay5, _, _, _ = lot(y3, x3, y4, x4, y5, x5)
        if ay5 > 0:
            fehler(53, 104, 0)
            
        _, _, ayunten, _, _, _ = lot(y1, x1, y2, x2, y3, x3)
        _, _, ayoben, _, _, _ = lot(y1, x1, y2, x2, y4, x4)

        if  np.absolute(ayunten) < EPSILON and np.absolute(ayoben) < EPSILON:
            fehler(51, 112, 0)
        elif ayunten * ayoben > 0 and \
               np.absolute(np.absolute(ayunten) - np.absolute(ayoben)) < EPSILON:
            R =  np.absolute(ayunten) / 2         
            tS, _ = richtung1(((y2 + y4) / 2), \
                    ((x2 + x4) / 2), ((y1 + y3) / 2), ((x1 + x3) / 2))
            yS, xS, _, _ = lot1((y2 + y4) / 2, (x2 + x4) / 2, tS, y5, x5)
        else:  
            yS, xS, tS, _ = winkelhalbierende(y1, x1, y2, x2, y3, x3, y4, x4)
        _, _, ay52, _ = lot1(yS, xS, tS, y5, x5)
                
        if ay52 < 0:   # Spiegelung
            _, _, c1, _, y5sp, x5sp = lot(yS, xS, tS, y5, x5)          
            if c1 < 0:
                y5 = y5sp
                x5 = x5sp
        t12, _ = richtung1(y1, x1, y2, x2)    
        yW, xW, _ = geradenschnitt(y5, x5, t12 + 100, yS, xS, tS)
        yT1, xT1, t1, yM, xM, R = regula_falsi_kreis_gerade( \
            y1, x1, t12, yW, xW, tS, y5, x5, yS, xS)
        yT2, xT2, R1, t2, _, _ = lot(y3, x3, y4, x4, yM, xM)

        return yT1, xT1, yT2, xT2, yM, xM, t1, t2, R, R1
    except BaseException:
        fehler(53, 0, 0)

# 54
#  2 feste, tangentiale Geraden und Radius


def tangente8(y1, x1, y2, x2, y3, x3, y4, x4, R):
    try:
        _, _, ayunten, _, _, _ = lot(y1, x1, y2, x2, y3, x3)
        _, _, ayoben, _, _, _ = lot(y1, x1, y2, x2, y4, x4)
        
        if  np.absolute(ayunten) < EPSILON and np.absolute(ayoben) < EPSILON:
            fehler(51, 101, 119)
        elif ayunten * ayoben > 0 and \
               np.absolute(np.absolute(ayunten) - np.absolute(ayoben)) < EPSILON:
            fehler(51, 101, 120)
            
        yM, xM, _ = parallelschnitt(y1, x1, y2, x2, R, y3, x3, y4, x4, -R)
        yT1, xT1 = senkrechtschnitt(y1, x1, y2, x2, yM, xM)
        yT2, xT2 = senkrechtschnitt(y3, x3, y4, x4, yM, xM)
        t1 = np.hypot(yT1 - y1, xT1 - x1)
        t2 = np.hypot(yT2 - y3, xT2 - x3)
        return yT1, xT1, yT2, xT2, yM, xM, t1, t2
    except BaseException:
        fehler(54, 0, 0)

# 55
#  Tangente außen, 2 Kreise


def tangente9(yM1, xM1, R1, yM2, xM2, R2):
    try:
        if R1*R2 < 0:
            fehler(55, 115, 118)
        _, s = RichtEntf(yM1, xM1, yM2, xM2, 55)
        t1 = np.sqrt(s**2 - (R1 - R2)**2)
        if np.isnan(t1):
            fehler(55, 106, 108)
        y1, x1, _ = transformation1(
            yM1, xM1, yM2, xM2, R1, 0, R2, t1, 0, 0)
        y2, x2, _ = transformation1(
            yM1, xM1, yM2, xM2, R1, 0, R2, t1, 0, t1)
        return y1, x1, y2, x2, t1
    except BaseException:
        fehler(55, 0, 0)

# 56
#  Tangenten innen, 2 Kreise


def tangente10(yM1, xM1, R1, yM2, xM2, R2):
    try:
        if R1*R2 > 0:
            fehler(56, 116, 117)
        _, s = RichtEntf(yM1, xM1, yM2, xM2, 56)
        t3 = np.sqrt(s**2 - (np.absolute(R1) + np.absolute(R2))**2)
        if np.isnan(t3):
            fehler(56, 106, 0)
        y3, x3, _ = transformation1(
            yM1, xM1, yM2, xM2, R1, 0, R2, t3, 0, 0)
        y4, x4, _ = transformation1(
            yM1, xM1, yM2, xM2, R1, 0, R2, t3, 0, t3)
        return y3, x3, y4, x4, t3
    except BaseException:
        fehler(56, 0, 0)

# 57
#  Tangential Umkreis 3 Kreise


def tangente11(yM1, xM1, R1, yM2, xM2, R2, R3):
    try:
        _, _ = RichtEntf(yM1, xM1, yM2, xM2, 57)
        R1 = np.absolute(R1)
        R2 = np.absolute(R2)
        if R3 > 0:
            yM3, xM3, _, _, _, _, _ = kreis_kreis(
                yM1, xM1, R3 - R1, yM2, xM2, R3 - R2)
        elif R3 < 0:
            R3 = -R3
            yM3, xM3, _, _, _, _, _ = kreis_kreis(
                yM2, xM2, R3 + R2, yM1, xM1, R3 + R1)
        y1, x1, _ = orthogonal(yM1, xM1, yM3, xM3, 0, R1)
        y2, x2, _ = orthogonal(yM2, xM2, yM3, xM3, 0, R2)  
        return y1, x1, y2, x2, yM3, xM3
    except BaseException:
        fehler(57, 0, 0)

# 58
# Tangential, 2 Kreise, 1 Punkt, Umkreis und Ankreis


def tangente12(yM1, xM1, R1, yM2, xM2, R2, y3, x3):
    try:
        x1, y1, r1 = yM1, xM1, R1
        x2, y2, r2, x_p, y_p = yM2, xM2, R2, y3, x3 
        
        a1 = np.hypot(yM1 - y3, xM1 - x3)
        if a1 - R1 <= 0:
            fehler(101, 122, 0) 
        a2 = np.hypot(yM2 - y3, xM2 - x3) 
        if a2 - R2 <= 0:           
            fehler(101, 122, 0)

        yT1, xT1, yT2, xT2, _ = tangente9(yM1, xM1, R1, yM2, xM2, R2)
        _, _, ay3, _, _, _ = lot(yT1, xT1, yT2, xT2, y3, x3)

        
        x1, y1, r1 = yM1, xM1, R1
        x2, y2, r2, x_p, y_p = yM2, xM2, R2, y3, x3 

        # Symbole für Mittelpunkt und Radius des gesuchten Kreises
        x_m, y_m, r = symbols('x_m y_m r')

        # Gleichung für den Punkt auf dem Kreis
        eq1 = Eq((x_p - x_m)**2 + (y_p - y_m)**2, r**2)

        if ay3 < 0:        # Umkreis
            eq2 = Eq(sqrt((x_m - x1)**2 + (y_m - y1)**2), r - r1)
            eq3 = Eq(sqrt((x_m - x2)**2 + (y_m - y2)**2), r - r2)

        if ay3 >= 0:       # Ankreis
            eq2 = Eq(sqrt((x_m - x1)**2 + (y_m - y1)**2), r + r1)
            eq3 = Eq(sqrt((x_m - x2)**2 + (y_m - y2)**2), r + r2)

        solution = solve([eq1, eq2, eq3], (x_m, y_m, r))
     
        first_solution = solution[0]  # Zugriff auf das erste Tupel
        yM3 =  first_solution[0]
        xM3 =  first_solution[1]
        R3 =  first_solution[2]
        return yM3, xM3, R3
    except BaseException:
        fehler(58, 0, 0)

# 59
#  tangentiale 3 Kreise, 3 Punkte, Umkreis


def tangente13(y1, x1, y2, x2, y3, x3, y4, x4, y5, x5, y6, x6, R3):
    try:
        yM1, xM1, R1 = kreis(y1, x1, y2, x2, y3, x3)
        yM2, xM2, R2 = kreis(y4, x4, y5, x5, y6, x6)
        R3 = np.absolute(R3)
        yM3, xM3, _, _, _, _, _ = kreis_kreis(
            yM1, xM1, R3 - R1, yM2, xM2, R3 - R2)
        y7, x7, _ = orthogonal(yM3, xM3, yM1, xM1, 0, R3)
        y8, x8, _ = orthogonal(yM3, xM3, yM2, xM2, 0, R3)
        return y7, x7, R1, y8, x8, R2, yM3, xM3
    except BaseException:
        fehler(59, 101, 105)

# 60
#  tangentiale 3 Kreise, 3 Punkte, Ankreis


def tangente14(y1, x1, y2, x2, y3, x3, y4, x4, y5, x5, y6, x6, R4):
    try:
        yM1, xM1, R1 = kreis(y1, x1, y2, x2, y3, x3)
        yM2, xM2, R2 = kreis(y4, x4, y5, x5, y6, x6)
        R4 = np.absolute(R4)
        yM4, xM4, _, _, _, _, _ = kreis_kreis(
            yM2, xM2, R4 + R2, yM1, xM1, R4 + R1)
        y9, x9, _ = orthogonal(yM4, xM4, yM1, xM1, 0, R4)
        y10, x10, _ = orthogonal(yM4, xM4, yM2, xM2, 0, R4)
        return y9, x9, R1, y10, x10, R2, yM4, xM4
    except BaseException:
        fehler(60, 101, 105)


# 61
#  tangentiale Anschlussbögen Umkreis, 3 + 2 Punkte (mit lambda-Funktion)
def tangente15(y1, x1, y2, x2, y3, x3, y4, x4, y5, x5):
    try:
        yM1, xM1, R1 = kreis(y1, x1, y2, x2, y3, x3)
        yW, xW, tM, sM = mittelsenkrechte(y4, x4, y5, x5)
        yM = yW
        xM = xW
        t = tM / RHO
        # yM = (yW+x*np.sin(t))
        # xM = (xW+x*np.cos(t))

        def DiffFunc(x): return np.hypot(yM1 - (yW + x * np.sin(t)), xM1 -\
            (xW + x * np.cos(t))) - np.hypot(y5 - (yW + x * np.sin(t)), x5 -\
            (xW + x * np.cos(t))) + R1
        x = regula_falsi_nullstelle(DiffFunc, -INF, INF)
        yM, xM = polar(yW, xW, tM, x)
        R3 = np.hypot(yM - yM1, xM - xM1) + R1
        y7, x7, _ = orthogonal(yM1, xM1, yM, xM, 0, -R1)
        return y7, x7, yM1, xM1, R1, yM, xM, R3
    except BaseException:
        fehler(62, 0, 0)


# 62
#  tangentiale Anschlussbögen Ankreis, 3 + 2 Punkte (mit lambda-Funktion)

def tangente16(y1, x1, y2, x2, y3, x3, y4, x4, y5, x5):
    try:
        yM1, xM1, R1 = kreis(y1, x1, y2, x2, y3, x3)
        yW, xW, tM, _ = mittelsenkrechte(y4, x4, y5, x5)
        yM = yW
        xM = xW
        t = tM / RHO
        # yM = (yW+x*np.sin(t))
        # xM = (xW+x*np.cos(t))
        x = 0
        def DiffFunc(x): return np.hypot(yM1 - (yW + x * np.sin(t)),\
            xM1 - (xW + x * np.cos(t))) - R1\
            - np.hypot(y5 - (yW + x * np.sin(t)), x5 - (xW + x * np.cos(t)))
        x = regula_falsi_nullstelle(DiffFunc, INF, -INF)
        yM, xM = polar(yW, xW, tM, x)
        R4 = np.hypot(yM - yM1, xM - xM1) - R1
        y8, x8, _ = orthogonal(yM1, xM1, yM, xM, 0, R1)
        return y8, x8, yM1, xM1, R1, yM, xM, -R4
    except BaseException:
        fehler(62, 0, 0)


# 63
# Paralleler Kreisbogen

def parallelkreis(y1, x1, y2, x2, R1, a):
    try:
        yM, xM = kreis(y1, x1, y2, x2, R1)
        R2 = R1 - a
        y3, x3, _ = orthogonal(yM, xM, y1, x1, 0, R2)
        y4, x4, _ = orthogonal(yM, xM, y2, x2, 0, R2)
        return y3, x3, y4, x4, yM, xM, R2
    except BaseException:
        fehler(63, 0, 0)

# 64
# Rückwärtsschnitt


def rueckwaertsschnitt1(y1, x1, y2, x2, y3, x3, alpha, beta):
    try:
        _, _ = RichtEntf(y1, x1, y2, x2, 64)
        t1, _ = RichtEntf(y1, x1, y3, x3, 64)  # nach Collins(1671)
        _, _ = RichtEntf(y2, x2, y3, x3, 64)
        yH, xH, _ = geradenschnitt(
            y1, x1, (t1 - beta), y3, x3, (t1 + 200 + alpha))
        yS, xS, _, _, _ = kreis_gerade(
            yH, xH, y2, x2, y1, x1, yH, xH, y3, x3, 0)
        return yS, xS
    except BaseException:
        fehler(64, 0, 0)

# 64
# Rückwärtsschnitt


def rueckwaertsschnitt2(y1, x1, y2, x2, y3, x3, alpha, beta):
    try:
        _, _ = RichtEntf(y1, x1, y2, x2, 641)
        _, _ = RichtEntf(y1, x1, y3, x3, 641)
        _, _ = RichtEntf(y2, x2, y3, x3, 641)
        alpha = alpha / RHO  # Drake, Taschenbuch fürVermessungsingenieure
        beta = beta / RHO    # 8. Aufl., S. 130; nach Cassini (1625-1712)
        x4 = x3 + (y2 - y3) / np.tan(beta)
        x5 = x1 + (y1 - y2) / np.tan(alpha)
        y5 = y1 + (x2 - x1) / np.tan(alpha)
        y4 = y3 + (x3 - x2) / np.tan(beta)
        if (x5 - x4) == 0:
            fehler(64, 0, 0)
        tant54 = (y5 - y4) / (x5 - x4)
        cott54 = 1 / tant54
        xS = (y2 - y5 - (x2 - x5) * tant54 + x2 *
              (tant54 + cott54)) / (tant54 + cott54)
        yS = y2 + (x2 - xS) * cott54
        return yS, xS
    except BaseException:
        fehler(641, 0, 0)

# 65, 66
# Segment, rechtsläufig


def segment(*args):
    try:
        if len(args) == 5:
            y1 = args[0]
            x1 = args[1]
            y2 = args[2]
            x2 = args[3]
            R = args[4]
            s = np.hypot(y2 - y1, x2 - x1)
        elif len(args) == 2:
            s = args[0]
            R = args[1]
        else:
            fehler(65, 107, 0)
        alpha = 2 * np.arcsin(s / 2 / R)    # alpha in rad
        b = alpha * R
        F = (alpha - np.sin(alpha)) * R**2 / 2
        return F, s, b
    except BaseException:
        fehler(65, 0, 0)

# 67
#  Fläche, Seitenlängen


def flaeche(flaeche_polygon):
    try:
        polygon_array = np.array(flaeche_polygon).reshape(-1, 4)
        pktnr = polygon_array[:, 0:1]
        koord = polygon_array[:, 1:3]
        radien = polygon_array[:, 3:4]

        def flaecheF(koord):
            y = koord[:, 0]
            x = koord[:, 1]
            return 0.5 * np.abs(np.dot(y, np.roll(x, 1)) -\
                np.dot(x, np.roll(y, 1)))

        F = flaecheF(koord)

        def strecken(koord, radien):
            anzahl = koord.shape[0]
            strecken = np.zeros(anzahl)
            strecken = strecken.reshape(-1, 1)
            segmentflaechen = 0
            for i in range(anzahl):
                laenge = np.linalg.norm(koord[(i + 1) % anzahl] - koord[i])
                strecken[i] = laenge
                if radien[i] != 0:
                    Fsegment, _, _ = segment(strecken[i], radien[i])
                    segmentflaechen = segmentflaechen + Fsegment
            return strecken, segmentflaechen

        strecken, segmentflaechen = strecken(koord, radien)
        koord8 = np.hstack((pktnr, koord, radien, strecken))
        F += segmentflaechen
        f = F[0]
        return f, koord8
    except BaseException:
        fehler(67, 0, 0)

# 68
#  Fläche, Seitenlängen (Variante)


def flaeche2(flaeche_polygon):
    try:
        polygon_array = np.array(flaeche_polygon).reshape(-1, 4)
        pktnr = polygon_array[:, 0]
        y = polygon_array[:, 1]
        x = polygon_array[:, 2]
        radien = polygon_array[:, 3]
        anzahl = polygon_array.shape[0]
        pktnr = pktnr.reshape(-1, 1)
        y = y.reshape(-1, 1)
        x = x.reshape(-1, 1)
        radien = radien.reshape(-1, 1)
        strecken = np.zeros((anzahl))
        strecken = strecken.reshape(-1, 1)
        F = 0
        for i in range(1, anzahl + 1):
            if i == 1:
                a = x[0] * (y[1] - y[anzahl - 1])
                strecken[0] = np.hypot(x[1] - x[0], y[1] - y[0])
            elif i == anzahl:
                a = x[anzahl - 1] * (y[0] - y[anzahl - 2])
                strecken[anzahl - 1] = np.hypot(x[0] - \
                    x[anzahl - 1], y[0] - y[anzahl - 1])
            else:
                a = x[i - 1] * (y[i] - y[i - 2])
                strecken[i - 1] = np.hypot(x[i] - x[i - 1], y[i] - y[i - 1])
            F = F + a
            if radien[i - 1] != 0:
                Fsegment, _, _ = segment(strecken[i - 1], radien[i - 1])
                F = F + 2 * Fsegment
        koord8 = np.hstack((pktnr, y, x, radien, strecken))
        f = F[0]
        return f / 2, koord8
    except BaseException:
        fehler(68, 0, 0)

# 69
#  Dreieck, Höhe und Höhenfußpunkt


def dreieck(a, b, c):
    try:
        if a > b:
            p = (c**2 + a**2 - b**2) / c / 2
            q = c - p
            h = np.sqrt(b**2 - q**2)
        else:
            q = (c**2 + b**2 - a**2) / c / 2
            p = c - q
            h = np.sqrt(a**2 - p**2)
        if np.isnan(h):
            fehler(69, 106, 0)
        alpha = np.arctan2(h, q) * RHO
        if alpha < 0.:
            alpha = 100. - alpha
        beta = np.arctan2(h, p) * RHO
        if beta < 0.:
            beta = 100. - beta
        gamma = 200 - alpha - beta
        F = c * h / 2
        return h, p, q, alpha, beta, gamma, F
    except BaseException:
        fehler(69, 0, 0)

# 70
#    Strecke: Reduktion von wahrer, örtlicher Strecke nach UTM


def streckenreduktion(s, most, hoehe, undulation):
    try:
        r = 6381.  # Erdradius für NRW in [km]
        korrekturutm = 0.9996 * (1. + (most - 500.)**2 / (2. * r**2))
        korrektur = korrekturutm - 0.9996 * (hoehe + undulation) * 0.001 / r
        streckeUTM = s * korrektur
        return streckeUTM
    except BaseException:
        fehler(70, 0, 0)

# 71, 72
# Strecke: Reduktion von UTM (Koordinaten) in wahre, örtliche Strecke
# streckewahr  = streckeUTM(y1, x1, y2, x2, most, hoehe, undulation)
# streckewahr  = streckeUTM(s, most, hoehe, undulation)


def streckeUTM(*args):
    try:
        if len(args) == 4:
            s = args[0]
            most = args[1]
            hoehe = args[2]
            undulation = args[3]
        elif len(args) == 7:
            y1 = args[0]
            x1 = args[1]
            y2 = args[2]
            x2 = args[3]
            most = args[4]
            hoehe = args[5]
            undulation = args[6]
            s = np.sqrt((y2 - y1)**2 + (x2 - x1)**2)
        else:
            fehler(71, 107, 0)
        r = 6381.  # Erdradius für NRW in [km]
        hoehe += undulation
        reduktion = 0.9996 * (1. + (most - 500.)**2 /
                              (2. * r**2) - (hoehe * 0.001) / r)
        streckewahr = s / reduktion
        return streckewahr
    except BaseException:
        fehler(71, 0, 0)

# 73
#    Klotoidenelemente
# x, y, R, sigma_gon, tau_gon, xM_lokal, yM_lokal,\
#        deltaR, TL, TK, y2, x2, y3, x3, yM, xM = \
# klothoidenelemente(y1, x1, t1, A, L, a)


def klothoidenelemente(y1, x1, t1, A, L, a):
    try:
        x, y, R = klothoide(A, L)
        sigma_gon, SL = richtung2(y, x)
        tau_gon = (L / A)**2 * RHO / 2
        tau = (L / A)**2 / 2
        tau_gon = tau * RHO
        xM_lokal = x - np.sin(tau) * R
        yM_lokal = y + np.cos(tau) * R
        deltaR = yM_lokal - R
        TL = x - y / np.tan(tau)
        TK = y / np.sin(tau)
        y2, x2, y0, x0 = polar(y1, x1, t1, -y, x)
        t23 = t1 - (L / A)**2 / 2 * RHO + 100
        y3, x3, y0, x0 = polar(y2, x2, t23, a, 0)
        yM, xM, y0, x0 = polar(y1, x1, t1, -yM_lokal, xM_lokal)
        return x, y, R, sigma_gon, tau_gon, xM_lokal, yM_lokal, \
            deltaR, TL, TK, y2, x2, y3, x3, yM, xM
    except BaseException:
        fehler(73, 0, 0)

# 74
#    Klotoide, normal
# x, y, R = klothoide(A, L)


def klothoide(A, L):
    try:
        T = (L / A)**2 / 2  # Schnittwinkel in Bogenmaß
        x = 1
        y = T / 3
        a = d = s = 1
        b = 3
        c = -1
        m = T
        while np.absolute(s) > 1.e-13:
            d *= c
            a += 1
            b += 2
            m *= T / a
            s = m * d / b
            x += s
            a += 1
            b += 2
            m *= T / a
            s = m * d / b
            y += s
        return L * x, L * y, A * A / L
    except BaseException:
        fehler(71, 0, 0)

# 74 (intern)
#    Klotoide, normal
# x, y, R = klothoide(A, L)


def klothoide2(A, L):
    l = L / A
    X = L
    k = 0
    ak = L
    absck = 1
    while np.absolute(absck) > 1.e-13:
        k += 2
        bk = 4 * k * (k - 1)
        ak = ak * l * l * l * l * (-1) / bk
        ck = ak / (2 * k + 1)
        X += ck
        absck = ck

    ak = L * l * l / 2
    Y = ak / 3
    k = 1
    absck = 1
    while np.absolute(absck) > 1.e-13:
        k += 2
        bk = 4 * k * (k - 1)
        ak = ak * l * l * l * l * (-1) / bk
        ck = ak / (2 * k + 1)
        Y += ck
        absck = ck
    return X, Y, A * A / L

# 74 (intern)
#    Klotoide, normal
# x, y, R = klothoide(A, L)


def klothoide3(A, L):
    # Näherungslösung aufgrund einer Tschebyschowapproximation
    # Quelle: Gelhaus, Rolf; Anwendungen der Tschebyscheffapproximation
    # gezeigt am Beispiel der Einheitsklothoide;
    # Vermessungswesen und Raumordnung, 1973, S. 479,480
    l = L / A
    ll = l * l * l * l
    X = A * l * (1. + ll * (-.02499999568 + ll * (.0002893494937 +
                 ll * (-.000001668902491 + ll * .000000005663002772))))
    Y = A * l * l * (l / 6 + l * ll * (-.00297617194 + ll *
                     (.00002366817123 + ll * (-.0000001026650462))))
    return X, Y, A * A / L

# 75
#    Klotoide mit seitlichen Abstand


def klothoide4(y1, x1, t1, A, L, a):
    try:
        x, y, _ = klothoide(A, L)
        y2, x2, yF, xF = polar(y1, x1, t1, -y, x)
        t2 = t1 - (L / A)**2 / 2 * RHO + 100
        y3 = y2 + a * np.sin(t2 / RHO)
        x3 = x2 + a * np.cos(t2 / RHO)
        return y3, x3, y2, x2
    except BaseException:
        fehler(75, 0, 0)

# 76
#    Klotoidenabstand


def klothoide5(y1, x1, t1, A, y3, x3):
    try:
        L = np.hypot((y3 - y1), (x3 - x1))
        y2, x2, _, _ = klothoide4(y1, x1, t1, A, L, 0)
        b = np.hypot(y2 - y3, x2 - x3)
        y3ist, x3ist, _, _ = klothoide4(y1, x1, t1, A, L, b)
        e = 1
        n = 0
        while e > EPSILON and n < MAX_ITER:
            tau = RHO * (L / A)**2 / 2
            t2 = t1 - tau + 100
            _, _, ay, ax = lot1(y2, x2, t2, y3, x3)
            L -= ay
            b = ax
            y2, x2, _, _ = klothoide4(y1, x1, t1, A, L, 0)
            y3ist, x3ist, _, _ = klothoide4(y1, x1, t1, A, L, b)
            b = np.hypot(y3 - y2, x3 - x2)
            e = np.hypot(y3 - y3ist, x3 - x3ist)
            n += 1
        return y2, x2, L, b
    except BaseException:
        fehler(76, 0, 0)

# 77
#    Schnitt Klothoide und Gerade


def klothoide_gerade(y1, x1, t1, A, a, y4, x4, y5, x5, yN, xN):
    try:
        L = np.hypot((yN - y1), (xN - x1))
        e = 1
        n = 0
        while e > EPSILON and n < MAX_ITER:
            ySi, xSi, _, _ = klothoide4(y1, x1, t1, A, L, a)
            tau = RHO * (L / A)**2 / 2
            t2 = t1 - tau
            yS, xS, _ = geradenschnitt(y4, x4, y5, x5, ySi, xSi, t2)
            y2, x2, L, _ = klothoide5(y1, x1, t1, A, yS, xS)
            e = np.hypot(ySi - yS, xSi - xS)
            n += 1
        return yS, xS, y2, x2, L
    except BaseException:
        fehler(77, 0, 0)

# 78, 79
#    Schnitt Klothoide und Kreis


def klothoide_kreis(*args):
    try:
        y1 = args[0]
        x1 = args[1]
        t1 = args[2]
        A = args[3]
        a = args[4]
        if len(args) == 10:
            yM = args[5]
            xM = args[6]
            R = args[7]
            yN = args[8]
            xN = args[9]
        elif len(args) == 12:
            y4 = args[5]
            x4 = args[6]
            y5 = args[7]
            x5 = args[8]
            R = args[9]
            yN = args[10]
            xN = args[11]
            yM, xM = kreis(y4, x4, y5, x5, R)
        else:
            fehler(78, 0, 0)
        L = np.hypot((yN - y1), (xN - x1))
        e = 1
        n = 0
        while e > EPSILON and n < MAX_ITER:
            ySi, xSi, _, _ = klothoide4(y1, x1, t1, A, L, a)
            tau = RHO * (L / A)**2 / 2
            t2 = t1 - tau
            yS, xS = kreis_gerade(ySi, xSi, t2, yM, xM, R)
            y2, x2, L, _ = klothoide5(y1, x1, t1, A, yS, xS)
            e = np.hypot(ySi - yS, xSi - xS)
            n += 1
        if len(args) == 10:
            return yS, xS, y2, x2, L
        if len(args) == 12:
            return yS, xS, y2, x2, L, yM, xM
    except ValueError:
        fehler(78, 0, 0)

# 80
#    Schnitt Klothoide und Klothoide


def klothoide_klothoide(y1, x1, t1, A1, a1, y3, x3, t2, A2, a2, yN, xN):
    try:
        L1 = np.hypot((yN - y1), (xN - x1))
        L2 = np.hypot((yN - y3), (xN - x3))
        e = 1
        n = 0
        while e > EPSILON and n < MAX_ITER:
            ySi1, xSi1, _, _ = klothoide4(y1, x1, t1, A1, L1, a1)
            tau1 = RHO * (L1 / A1)**2 / 2
            t21 = t1 - tau1
            ySi2, xSi2, _, _ = klothoide4(y3, x3, t2, A2, L2, a2)
            tau2 = RHO * (L2 / A2)**2 / 2
            t22 = t2 - tau2
            yS, xS, _ = geradenschnitt(ySi1, xSi1, t21, ySi2, xSi2, t22)
            y4, x4, L2, _ = klothoide5(y3, x3, t2, A2, yS, xS)
            y2, x2, L1, _ = klothoide5(y1, x1, t1, A1, yS, xS)
            e = np.hypot(ySi1 - yS, xSi1 - xS) + np.hypot(ySi2 - yS, xSi2 - xS)
            n += 1
        return yS, xS, y2, x2, L1, y4, x4, L2
    except BaseException:
        fehler(80, 0, 0)


# 81 (intern)
#  Regula_falsi_kreis_gerade


def regula_falsi_kreis_gerade(y1, x1, t12, yW, xW, tM, y5, x5, yS, xS):
    try:
        def DiffFunc(x): return np.hypot((y5 - yW - x * np.sin(tM/RHO)),
                                         (x5 - xW - x * np.cos(tM/RHO))) - \
            np.absolute(lot2(y1, x1, t12,
                             yW + x * np.sin(tM/RHO), xW + x * np.cos(tM/RHO)))

        # a1 = np.hypot(y5 - (yW + x * np.sin(tM/RHO)), x5 - (xW + x * np.cos(tM/RHO)))
        # a2 = np.absolute(lot2(y1, x1, t12, yW + x * np.sin(tM/RHO), xW + x * np.cos(tM/RHO)))
        # DiffFunc = lambda x: a1 - a2 (für die Bestimmung der Nullstelle, Soll a1 = a2 = R

        LinkeS = 0  # Schranken für regula falsi
        RechteS = 1  # 1. Lösung

        while DiffFunc(RechteS) < 0:
            LinkeS = RechteS
            RechteS *= 2
        x = regula_falsi_nullstelle(DiffFunc, LinkeS, RechteS)
        yM1, xM1 = polar(yW, xW, tM, x)

        LinkeS = -1  # Schranken für regula falsi
        RechteS = 0  # 2. Lösung

        while DiffFunc(LinkeS) < 0:
            RechteS = LinkeS
            LinkeS *= 2

        x = regula_falsi_nullstelle(DiffFunc, LinkeS, RechteS)
        yM2, xM2 = polar(yW, xW, tM, x)

        sm = np.hypot(yM1 - yS, xM1 - xS)
        sw = np.hypot(yW - yS, xW - xS)
        if sm - sw > 0:             # größere Lösung
            yM = yM1
            xM = xM1
        else:
            yM = yM2
            xM = xM2
        yT1, xT1, R, t1 = lot1(y1, x1, t12, yM, xM)

        return yT1, xT1, t1, yM, xM, R
    except BaseException:
        fehler(52, 0, 0)


# 82 (intern)
#  Regula_falsi_nullstelle (mit lambda-Funktion)


def regula_falsi_nullstelle(Funktion, LinkeS, RechteS):
    if Funktion(LinkeS) > 0 and Funktion(RechteS) < 0:
        Temp = RechteS
        RechteS = LinkeS
        LinkeS = Temp
    i = 0
    a = 1
    #print("   Regula falsi \u2794 x = Variable, a = f(a1(x)) - f(a2(x))")
    #print("   linke Schranke < x > rechte Schranke \u21D4 a-links < a > a-rechts")
    while abs(a) > EPSILON and i < MAX_ITER:
        aLS = Funktion(LinkeS)
        aRS = Funktion(RechteS)
        x = (aRS * LinkeS - aLS * RechteS) / (aRS - aLS)
        a = Funktion(x)

        i += 1
        #print(f"{i}.: {LinkeS:.5f} < {x:.5f} < {RechteS:.5f} \
        #\u21D4 {aLS:.5f} < {a:.5f} < {aRS:.5f}")
        if a < 0:
            LinkeS, aLS = x, a
        elif a > 0:
            RechteS, aRS = x, a
    return x



